import{a as n,d as s}from"./chunk-LOP76GWT.js";import{a as t,b as r}from"./chunk-4DX65HLL.js";import"./chunk-Q2CF2JQV.js";import"./chunk-LCZQRCKX.js";import"./chunk-MFW36WEU.js";import"./chunk-7PFZXDIW.js";import"./chunk-YKFXM3J7.js";import"./chunk-AVRBEEAA.js";import"./chunk-4ERZBM5I.js";import"./chunk-DJ546A6R.js";import"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-AJ7ODGYR.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import{cc as i,dc as e}from"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import"./chunk-WL5U2YIT.js";import{e as a}from"./chunk-ADEKKGI2.js";var h,p=a(()=>{r();s();e();h=[{path:"",canActivate:[t],loadComponent:()=>import("./chunk-53AJRN4U.js").then(o=>o.NotificationsComponent),children:[{path:"user-subscriptions",canActivate:[t,n],data:{permissions:[i.NotificationsUserView]},loadComponent:()=>import("./chunk-FXF4B4IG.js").then(o=>o.UserSubscriptionDashboardComponent)},{path:"subscriptions",canActivate:[t,n],data:{permissions:[i.NotificationsSubscriptionsView]},loadComponent:()=>import("./chunk-NZVQW5ZT.js").then(o=>o.SubscriptionDashboardComponent)},{path:"groups",canActivate:[t,n],data:{permissions:[i.NotificationsSubscriberGroupView]},loadComponent:()=>import("./chunk-OJIRDE6H.js").then(o=>o.SubscriberGroupDashboardComponent)},{path:"subscribers",canActivate:[t,n],data:{permissions:[i.NotificationsSubscriberView]},loadComponent:()=>import("./chunk-CT6BBPNL.js").then(o=>o.SubscriberDashboardComponent)},{path:"notification-preferences-dashboard",loadComponent:()=>import("./chunk-HYA7YTR4.js").then(o=>o.NotificationPreferencesDashboardComponent)},{path:"",loadComponent:()=>import("./chunk-DZQGSLJH.js").then(o=>o.NotificationsDashboardComponent)}]}]});p();export{h as NOTIFICATIONS_ROUTES};
