import{f as c,h as v}from"./chunk-ZBM6BFOI.js";import{Hc as p,Jb as l,Sb as a,Za as d,be as u}from"./chunk-WL5U2YIT.js";import{e as h}from"./chunk-ADEKKGI2.js";var D,I=h(()=>{u();v();D=(()=>{let i=class i{constructor(t,e){this.tooltip=t,this.elementRef=e,this.elementIsContainedInADiv=!1}setTooltipState(){let t=this.elementRef.nativeElement,e=t.parentElement;if(!e){this.tooltip._tooltipOptions.disabled=!0;return}let n=window.getComputedStyle(e),r=e.clientWidth-parseInt(n.paddingLeft,10)-parseInt(n.paddingRight,10),s=this.elementIsContainedInADiv?t.scrollWidth:t.offsetWidth,f=t.scrollWidth>t.offsetWidth,m=s>r;f||m?this.tooltip._tooltipOptions.disabled=!1:this.tooltip._tooltipOptions.disabled=!0}};i.\u0275fac=function(e){return new(e||i)(l(c),l(d))},i.\u0275dir=a({type:i,selectors:[["","pTooltip","","dvlsTextOverflowTooltipDirective",""]],hostBindings:function(e,n){e&1&&p("mouseenter",function(s){return n.setTooltipState(s)})},inputs:{elementIsContainedInADiv:"elementIsContainedInADiv"}});let o=i;return o})()});export{D as a,I as b};
