import{b as n,c as m}from"./chunk-YBNTOQCK.js";import{Jb as a,Tb as s,be as c}from"./chunk-WL5U2YIT.js";import{e as o}from"./chunk-ADEKKGI2.js";var l,p=o(()=>{c();m();l=(()=>{let t=class t{constructor(r){this.translatorService=r}transform(r,i){return this.translatorService.translateEnum(i,r)}};t.\u0275fac=function(i){return new(i||t)(a(n,16))},t.\u0275pipe=s({name:"translateEnum",type:t,pure:!0});let e=t;return e})()});export{l as a,p as b};
