import{be as p,g as s,na as n,ta as o}from"./chunk-WL5U2YIT.js";import{e as m}from"./chunk-ADEKKGI2.js";var c,R=m(()=>{n();p();c=(()=>{let e=class e{constructor(){this.importRdmRequest=new s,this.importKeePassRequest=new s,this.importRdxRequest=new s,this.importCsvRequest=new s}importRdm(t){this.importRdmRequest.next(t)}importKeePass(t){this.importKeePassRequest.next(t)}importRdx(t){this.importRdxRequest.next(t)}importCsv(t){this.importCsvRequest.next(t)}};e.\u0275fac=function(r){return new(r||e)},e.\u0275prov=o({token:e,factory:e.\u0275fac,providedIn:"root"});let i=e;return i})()});export{c as a,R as b};
