import{c as g,d as v,e as m,f as u}from"./chunk-YQYH6YEK.js";import{Jb as t,Qb as a,be as f,mc as r,oc as s,xc as d,yc as c,zc as l}from"./chunk-WL5U2YIT.js";import{e as h}from"./chunk-ADEKKGI2.js";function b(o,e){o&1&&(d(0,"div",0),l(1,"div",1),c())}var x,L=h(()=>{v();f();u();x=(()=>{let e=class e{constructor(i){this.loadingService=i,this.isLoading=!1}ngOnInit(){this.loadingService.addReceiver(this),this.loadingService.isWorking().subscribe(i=>{(!i.isLoading||i.mode===g.Local&&i.receiver===this)&&(this.isLoading=i.isLoading)})}ngAfterContentChecked(){this.show=this.isLoading}ngOnDestroy(){this.loadingService.removeReceiver(this)}};e.\u0275fac=function(n){return new(n||e)(t(m))},e.\u0275cmp=a({type:e,selectors:[["sd-loading-bar"]],decls:1,vars:1,consts:[[1,"loading-bar"],[1,"loading-bar-progress"]],template:function(n,p){n&1&&r(0,b,2,0,"div",0),n&2&&s(p.show?0:-1)},styles:[`@keyframes slide{0%{left:-33%}to{left:100%}}.loading-bar{position:absolute;margin:0;padding:0;top:0;left:0;right:0;z-index:99999;background-color:orange;opacity:0;overflow:hidden;transition:opacity 1s ease}.loading-bar-progress{width:33%;margin:0;padding:0;z-index:99998;position:relative;background-color:orange;height:4px;animation-name:slide;animation-duration:2s;animation-timing-function:linear;animation-iteration-count:infinite}.navigation-tree-holder .loading-bar{position:absolute!important}.navigation-tree-holder .loading-bar-progress{height:2px}
`],encapsulation:2});let o=e;return o})()});export{x as a,L as b};
