import{s as c,t as p}from"./chunk-HTXYTVN4.js";import{Jb as a,Tb as s,be as o}from"./chunk-WL5U2YIT.js";import{e as n}from"./chunk-ADEKKGI2.js";var l,m=n(()=>{o();l=(()=>{let t=class t{constructor(){this.urlRegex=/(https?:\/\/[^\s<]+[^\s<.,])/g}transform(e){return e.replace(this.urlRegex,i=>`<a href="${i}" target="_blank" rel="noopener noreferrer" class="text-[var(--text-action)] underline">${i}</a>`)}};t.\u0275fac=function(i){return new(i||t)},t.\u0275pipe=s({name:"linkify",type:t,pure:!0});let r=t;return r})()});var x,f=n(()=>{o();p();x=(()=>{let t=class t{constructor(e){this.sanitized=e}transform(e){return this.sanitized.bypassSecurityTrustHtml(e)}};t.\u0275fac=function(i){return new(i||t)(a(c,16))},t.\u0275pipe=s({name:"safeHtml",type:t,pure:!0});let r=t;return r})()});export{l as a,m as b,x as c,f as d};
