import{a as n,b as f}from"./chunk-RGGXLS4X.js";import{Jb as r,Tb as c,be as a}from"./chunk-WL5U2YIT.js";import{e as s}from"./chunk-ADEKKGI2.js";var l,m=s(()=>{a();f();l=(()=>{let e=class e{constructor(i){this.fileService=i}transform(i){return this.fileService.getHumanFriendlyFileSize(i)}};e.\u0275fac=function(o){return new(o||e)(r(n,16))},e.\u0275pipe=c({name:"fileSize",type:e,pure:!0});let t=e;return t})()});export{l as a,m as b};
