import{a as U,b as nt}from"./chunk-UFLBGB26.js";import{a as R,b as rt}from"./chunk-ERBABQHD.js";import"./chunk-KLRBWJIJ.js";import"./chunk-W6QAIWTK.js";import"./chunk-AQH4BMGD.js";import"./chunk-NQ2C7QQR.js";import"./chunk-4CERJ67S.js";import"./chunk-OGIVSRCZ.js";import{a as G,b as it}from"./chunk-3E7FAEEN.js";import"./chunk-DJLFA677.js";import"./chunk-NEKDTWKR.js";import"./chunk-JZBEKAHY.js";import"./chunk-GPOUKG47.js";import"./chunk-VTHDUROI.js";import"./chunk-NC2262CC.js";import"./chunk-ANAFRJKG.js";import{a as q,b as et}from"./chunk-N6V36G77.js";import"./chunk-YVVVIZWY.js";import"./chunk-A22EQSF3.js";import"./chunk-THQOQSZV.js";import"./chunk-4BLCQKUP.js";import"./chunk-J5QU44UY.js";import"./chunk-7YSPVYHZ.js";import"./chunk-4ERZBM5I.js";import"./chunk-DJ546A6R.js";import"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import{a as $,b as tt}from"./chunk-6POW7SSJ.js";import{cb as O,w as L,x as z,y as H,zb as x}from"./chunk-V2ECYACM.js";import{C as E,E as N,g as A,i as I,n as M}from"./chunk-JPHJ3OD7.js";import{g as B,h as Z}from"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-6YAACY5H.js";import"./chunk-AJ7ODGYR.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import{Ma as j,Na as Y}from"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import"./chunk-HTXYTVN4.js";import{b as Q,c as X}from"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import{Ac as C,Ad as k,Bc as b,Dc as F,Ea as f,Fa as g,Hc as y,J as m,Jb as d,Nc as P,Oc as D,Pc as w,Qb as h,Sa as J,Tc as T,Ub as v,be as K,ia as l,id as V,tc as o,uc as s,vc as u,wc as S,x as c,yb as p,zd as _}from"./chunk-WL5U2YIT.js";import{e as W}from"./chunk-ADEKKGI2.js";var ot,Pt,st=W(()=>{J();N();it();Y();tt();rt();Z();H();nt();x();K();X();et();H();N();ot=["currentForm"],Pt=(()=>{let i=class i extends G{constructor(t,e){super(),this.translatorService=t,this.pamSettingsService=e,this.titleHeader=[{title:this.translatorService.translate("lblAdministration")},{title:this.translatorService.translate("lblPrivilegedAccessManagement"),link:"/administration/pam/"},{title:this.translatorService.translate("lblDefaultSettings")}],this.settings=new j,this.isFormLoaded=!1}get isDirty(){return this.currentForm?this.isFormLoaded&&this.currentForm.dirty:!1}getComponentTitle(){return"lblDefaultSettings"}ngOnInit(){super.ngOnInit()}ngAfterViewInit(){this.getSettings()}save(){return this.onSubmit().subscribe(()=>this.setFormPristine())}cancelChange(){return!1}rejectChange(){return!0}validateChange(){return this.onSubmit()}onSubmit(){return this.pamSettingsService.setSettings(this.settings).pipe(l(this.destroyed$),m(t=>!!t),c(t=>!!t))}getSettings(){this.pamSettingsService.getSettings(!0).pipe(l(this.destroyed$),m(t=>!!t)).subscribe(t=>{this.settings=t,this.setFormPristine(),this.isFormLoaded=!0})}setFormPristine(){setTimeout(()=>{this.currentForm?.form?.markAsPristine(),this.currentForm?.form?.updateValueAndValidity()})}};i.\u0275fac=function(e){return new(e||i)(d(Q),d(q))},i.\u0275cmp=h({type:i,selectors:[["dvls-pam-settings-dashboard"]],viewQuery:function(e,r){if(e&1&&P(ot,5),e&2){let n;D(n=w())&&(r.currentForm=n.first)}},features:[v],decls:8,vars:9,consts:[["currentForm","ngForm"],[3,"titlePage"],["header-right",""],["variant","icon","showDelay","500","tooltipPosition","bottom","icon","di dvl-icon-save",3,"onClick","dvlTooltip","disabled"],["autocomplete","off","novalidate","",1,"full-height"],[3,"settings","form","mdColSize"]],template:function(e,r){if(e&1){let n=F();s(0,"dvl-page-wrapper-v2",1),C(1,2),s(2,"dvl-button",3),_(3,"translate"),y("onClick",function(){return f(n),g(r.save())}),u(),b(),s(4,"form",4,0)(6,"p-fieldset"),S(7,"dps-pam-settings",5),u()()()}if(e&2){let n=T(5);o("titlePage",r.titleHeader),p(2),o("dvlTooltip",V(k(3,7,"lblSave")))("disabled",!r.isDirty),p(5),o("settings",r.settings)("form",n)("mdColSize",12)}},dependencies:[R,O,B,z,L,E,M,A,I,U,$],encapsulation:2});let a=i;return a})()});st();export{Pt as PamSettingsDashboardComponent};
