import{Sb as i,be as n,g as e,na as c}from"./chunk-WL5U2YIT.js";import{e as s}from"./chunk-ADEKKGI2.js";var m,d=s(()=>{c();n();m=(()=>{let t=class t{constructor(){this.destroyed$=new e}ngOnDestroy(){this.destroyed$.next(!0)}};t.\u0275fac=function(o){return new(o||t)},t.\u0275dir=i({type:t});let r=t;return r})()});export{m as a,d as b};
