import{a as O,b as V,c as W,d as B}from"./chunk-3BAJ7JGB.js";import{a as v,b as j}from"./chunk-SM7EQ7ST.js";import{c as U,d as M}from"./chunk-RWCAFOHA.js";import{$g as T,Gk as R,Hk as Q,We as p,Xe as b,Ye as m,Ze as y,_g as w,af as D,ah as z,bf as F,bh as C,cf as h,df as N}from"./chunk-BPZQKZKD.js";import{c as g,d as E}from"./chunk-6B6CBPYV.js";import{b as S,c as k}from"./chunk-YBNTOQCK.js";import{Sa as P,be as I,ka as i,ta as G,x as r,xa as d}from"./chunk-WL5U2YIT.js";import{e as A}from"./chunk-ADEKKGI2.js";var f,x=A(()=>{E();V();f=class l extends O{toQueryString(){let n=[];return n.push(super.toQueryString()),this.groupId!==null&&this.groupId.toString()&&n.push("groupId="+encodeURIComponent(this.groupId.toString())),this.hideExistingUsers!==null&&this.hideExistingUsers.toString()&&n.push("hideExistingUsers="+encodeURIComponent(this.hideExistingUsers.toString())),n.join("&")}constructor(n=null){super(n),this.clone=()=>new l(this),this.groupId=g.manageDefaultValue(n,"groupId",""),this.hideExistingUsers=g.manageDefaultValue(n,"hideExistingUsers",!1)}}});var oe,H=A(()=>{j();P();T();b();y();N();F();B();C();x();I();k();M();Q();oe=(()=>{let n=class n extends v{constructor(t,e,s){super(t,e),this.assetService=s}getAdDomains(t){return this.assetService.GetAllDomains(t).pipe(i(e=>this.handleGetApiResult(e)),r(e=>this.returnWhenSuccessful(e,()=>e.data.map(s=>new m(s)))))}getAdUser(t,e){return this.assetService.GetAdUser(t,e).pipe(i(s=>this.handleApiResult(s,"UserNotFoundOnDomain")),r(s=>this.returnWhenSuccessful(s,()=>s.data?new w(s.data):null)))}getAdUserProfile(t,e){return this.assetService.GetAdUserProfile(t,e).pipe(i(s=>this.handleApiResult(s,"UserNotFoundOnDomain")),r(s=>this.returnWhenSuccessful(s,()=>s.data?new z(s.data):null)))}getAdUsers(t,e,s){return this.assetService.GetAllDomainUsers(t.join(","),e,s).pipe(i(a=>this.handleGetApiResult(a)),r(a=>this.returnWhenSuccessful(a,()=>a.data?a.data.map(c=>new h(c)):null)))}getAdUserGroup(t,e){return this.assetService.GetAdGroup(t,e).pipe(i(s=>this.handleApiResult(s,"GroupNotFoundOnDomain")),r(s=>this.returnWhenSuccessful(s,()=>s.data)))}getAdUserGroups(t,e){return this.assetService.GetAllDomainGroups(t.join(","),e).pipe(i(s=>this.handleGetApiResult(s)),r(s=>this.returnWhenSuccessful(s,()=>s.data.map(a=>new p(a)))))}getAzureDomains(){return this.assetService.GetAllAzureDomains().pipe(i(t=>this.handleGetApiResult(t)),r(t=>this.returnWhenSuccessful(t,()=>t.data.map(e=>new m(e)))))}getAzureUsers(t){return this.assetService.GetAzureDomainUsers(t,null).pipe(i(e=>this.handleGetApiResult(e)),r(e=>this.returnWhenSuccessful(e,()=>e.data?.items?e.data.items.map(s=>new h(s)):null)))}getPagedAzureUsers(t,e,s,a,c,u){let o=new f;return o.pageSize=e,o.nextPageToken=s||null,o.filter=a,o.sortOrder=c,o.hideExistingUsers=u,this.assetService.GetAzureDomainUsers(t,o)}getAzureUser(t){return this.assetService.GetAzureDomainUser(t).pipe(i(e=>this.handleGetApiResult(e)),r(e=>this.returnWhenSuccessful(e,()=>e.data?new D(e.data):null)))}getAzureUserGroups(){return this.assetService.GetAzureDomainGroups(null).pipe(i(t=>this.handleGetApiResult(t)),r(t=>this.returnWhenSuccessful(t,()=>t.data?.items.map(e=>new p(e)))))}getPagedAzureUserGroups(t,e,s,a,c=!1){let u=new W;return u.pageSize=t,u.nextPageToken=e||null,u.filter=s,u.sortOrder=a,u.hideExistingUsers=c,this.assetService.GetAzureDomainGroups(u)}getAzureGroupMembers(t){return this.assetService.GetAzureGroupsMember(t).pipe(i(e=>this.handleGetApiResult(e)),r(e=>this.returnWhenSuccessful(e,()=>e.data.map(s=>new h(s)))))}getAzureUserMemberOf(t){return this.assetService.GetAzureUserMemberOf(t).pipe(i(e=>this.handleGetApiResult(e)),r(e=>this.returnWhenSuccessful(e,()=>e.data.map(s=>new p(s)))))}getOktaDomains(){return this.assetService.GetOktaDomain().pipe(i(t=>this.handleGetApiResult(t)),r(t=>this.returnWhenSuccessful(t,()=>t.data.map(e=>new m(e)))))}getOktaUserGroups(){return this.assetService.GetOktaGroups(null).pipe(i(t=>this.handleGetApiResult(t)),r(t=>this.returnWhenSuccessful(t,()=>t.data.map(e=>new p(e)))))}getOktaUsers(t){return this.assetService.GetAllOktaUsers(t).pipe(i(e=>this.handleGetApiResult(e)),r(e=>this.returnWhenSuccessful(e,()=>e.data?e.data.map(s=>new h(s)):null)))}getPingOneDomains(){return this.assetService.GetPingOneDomain().pipe(i(t=>this.handleGetApiResult(t)),r(t=>this.returnWhenSuccessful(t,()=>t.data.map(e=>new m(e)))))}getPingOneUsers(t,e){return this.assetService.GetAllPingOneUsers(t,e).pipe(i(s=>this.handleGetApiResult(s)),r(s=>this.returnWhenSuccessful(s,()=>s.data?s.data.map(a=>new h(a)):null)))}getPingOneUserGroups(){return this.assetService.GetPingOneGroups(null).pipe(i(t=>this.handleGetApiResult(t)),r(t=>this.returnWhenSuccessful(t,()=>t.data.map(e=>new p(e)))))}};n.\u0275fac=function(e){return new(e||n)(d(S),d(U),d(R))},n.\u0275prov=G({token:n,factory:n.\u0275fac,providedIn:"root"});let l=n;return l})()});export{oe as a,H as b};
