import{a as M,b as x}from"./chunk-4UDPUFFO.js";import{a as h,b as v}from"./chunk-AE2RVXWX.js";import{B as f,K as u,k as d}from"./chunk-LDWBA6DZ.js";import{Bd as g,Qb as o,Yc as m,Zc as c,be as T,tc as a,uc as r,vc as p,yb as s,zd as l}from"./chunk-WL5U2YIT.js";import{e as y}from"./chunk-ADEKKGI2.js";var U,P=y(()=>{u();x();v();T();u();U=(()=>{let e=class e{constructor(){this.systemUserTags=M}};e.\u0275fac=function(t){return new(t||e)},e.\u0275cmp=o({type:e,selectors:[["sd-user-tag-chip"]],inputs:{VMTag:"VMTag"},decls:5,vars:5,consts:[[1,"chip-container",3,"ngClass"],[1,"chip-label"]],template:function(t,i){t&1&&(r(0,"div",0)(1,"div",1)(2,"span"),m(3),l(4,"translateEnum"),p()()()),t&2&&(a("ngClass",i.VMTag.theme),s(3),c(g(4,2,i.VMTag.name,i.systemUserTags)))},dependencies:[f,d,h],styles:["[_nghost-%COMP%]{margin:0 5px}[_nghost-%COMP%]   .chip-container[_ngcontent-%COMP%]{cursor:default;display:inline-flex;align-items:center;flex:0 0 auto;border-radius:4px;line-height:24px}[_nghost-%COMP%]   .chip-container[_ngcontent-%COMP%]   .chip-label[_ngcontent-%COMP%]{font-size:14px;padding:0 .5em}"]});let n=e;return n})()});export{U as a,P as b};
