import{be as u,g as o,na as n,ta as i}from"./chunk-WL5U2YIT.js";import{e as c}from"./chunk-ADEKKGI2.js";var p,a=c(()=>{n();u();p=(()=>{let t=class t{constructor(){this.viewRequestSource=new o,this.viewRequest=this.viewRequestSource.asObservable()}open(r){this.viewRequestSource.next(r)}};t.\u0275fac=function(s){return new(s||t)},t.\u0275prov=i({token:t,factory:t.\u0275fac,providedIn:"root"});let e=t;return e})()});export{p as a,a as b};
