import{a as y,b as P}from"./chunk-WRJTHBJD.js";import{a as b,b as I}from"./chunk-ZVUXF5PM.js";import{a as U,b as w}from"./chunk-IKZ22DPI.js";import{f as T,g as D,h as O}from"./chunk-ZBM6BFOI.js";import{Db as m,Hc as d,Qb as u,Wa as l,Xc as v,Yc as f,_c as C,be as k,id as g,jd as h,tc as o,uc as r,vc as p,wc as c,yb as n}from"./chunk-WL5U2YIT.js";import{e as M}from"./chunk-ADEKKGI2.js";var G,S=M(()=>{k();w();O();I();P();k();O();G=(()=>{let i=class i{constructor(){this.usernameClick=new m}ngOnChanges(a){let t=e=>/^\s+$/.test(e.fullName)?"":e.fullName;a.user&&this.user&&(this.username=t(this.user)||this.user.name,this.avatarSettings={gravatar:this.user.iconUrl,size:24,icon:"",name:this.user.fullName?.trim()?t(this.user):this.user.name})}onUsernameClick(){this.enableUsernameClick&&this.usernameClick&&this.usernameClick.emit(this.outputData)}};i.\u0275fac=function(t){return new(t||i)},i.\u0275cmp=u({type:i,selectors:[["dvls-col-username"]],inputs:{avatarSettings:"avatarSettings",username:"username",tooltip:"tooltip",outputData:"outputData",enableUsernameClick:"enableUsernameClick",user:"user"},outputs:{usernameClick:"usernameClick"},features:[l],decls:4,vars:8,consts:[[1,"username-container"],[3,"settings"],["tooltipPosition","bottom","dvlsTextOverflowTooltipDirective","","dvlsTooltipPositionAdjustment","",2,"padding-left","5px",3,"click","elementIsContainedInADiv","pTooltip"]],template:function(t,e){t&1&&(r(0,"div",0),c(1,"sd-avatar",1),r(2,"span",2),d("click",function(){return e.onUsernameClick()}),f(3),p()()),t&2&&(n(),o("settings",e.avatarSettings),n(),v(h("username-label ",e.enableUsernameClick?"cursor-pointer no-underline text-[var(--text-action)]":"")),o("pTooltip",g(e.tooltip||e.username))("elementIsContainedInADiv",!0),n(),C(" ",e.username," "))},dependencies:[U,D,T,b,y],styles:[".username-container[_ngcontent-%COMP%]{display:flex;align-items:center}.username-container[_ngcontent-%COMP%]   .username-label[_ngcontent-%COMP%]{overflow:hidden;text-overflow:ellipsis}"]});let s=i;return s})()});export{G as a,S as b};
