import{C as r,I as s}from"./chunk-HTXYTVN4.js";import"./chunk-LDWBA6DZ.js";import{Qb as n,be as m,wc as i}from"./chunk-WL5U2YIT.js";import{e as p}from"./chunk-ADEKKGI2.js";var d,a=p(()=>{s();m();d=(()=>{let e=class e{};e.\u0275fac=function(o){return new(o||e)},e.\u0275cmp=n({type:e,selectors:[["ng-component"]],decls:1,vars:0,template:function(o,f){o&1&&i(0,"router-outlet")},dependencies:[r],encapsulation:2});let t=e;return t})()});a();export{d as AssetPamAdministrationComponent};
