var x=Object.create;var m=Object.defineProperty,y=Object.defineProperties,z=Object.getOwnPropertyDescriptor,A=Object.getOwnPropertyDescriptors,B=Object.getOwnPropertyNames,q=Object.getOwnPropertySymbols,C=Object.getPrototypeOf,s=Object.prototype.hasOwnProperty,u=Object.prototype.propertyIsEnumerable;var p=(a,b)=>(b=Symbol[a])?b:Symbol.for("Symbol."+a),D=a=>{throw TypeError(a)};var t=(a,b,c)=>b in a?m(a,b,{enumerable:!0,configurable:!0,writable:!0,value:c}):a[b]=c,E=(a,b)=>{for(var c in b||={})s.call(b,c)&&t(a,c,b[c]);if(q)for(var c of q(b))u.call(b,c)&&t(a,c,b[c]);return a},F=(a,b)=>y(a,A(b));var G=(a=>typeof require<"u"?require:typeof Proxy<"u"?new Proxy(a,{get:(b,c)=>(typeof require<"u"?require:b)[c]}):a)(function(a){if(typeof require<"u")return require.apply(this,arguments);throw Error('Dynamic require of "'+a+'" is not supported')});var H=(a,b)=>{var c={};for(var d in a)s.call(a,d)&&b.indexOf(d)<0&&(c[d]=a[d]);if(a!=null&&q)for(var d of q(a))b.indexOf(d)<0&&u.call(a,d)&&(c[d]=a[d]);return c};var I=(a,b)=>()=>(a&&(b=a(a=0)),b);var J=(a,b)=>()=>(b||a((b={exports:{}}).exports,b),b.exports),K=(a,b)=>{for(var c in b)m(a,c,{get:b[c],enumerable:!0})},v=(a,b,c,d)=>{if(b&&typeof b=="object"||typeof b=="function")for(let f of B(b))!s.call(a,f)&&f!==c&&m(a,f,{get:()=>b[f],enumerable:!(d=z(b,f))||d.enumerable});return a};var L=(a,b,c)=>(c=a!=null?x(C(a)):{},v(b||!a||!a.__esModule?m(c,"default",{value:a,enumerable:!0}):c,a)),M=a=>v(m({},"__esModule",{value:!0}),a);var N=(a,b,c)=>new Promise((d,f)=>{var g=e=>{try{i(c.next(e))}catch(k){f(k)}},h=e=>{try{i(c.throw(e))}catch(k){f(k)}},i=e=>e.done?d(e.value):Promise.resolve(e.value).then(g,h);i((c=c.apply(a,b)).next())}),w=function(a,b){this[0]=a,this[1]=b},O=(a,b,c)=>{var d=(i,e,k,l)=>{try{var n=c[i](e),o=(e=n.value)instanceof w,r=n.done;Promise.resolve(o?e[0]:e).then(j=>o?d(i==="return"?i:"next",e[1]?{done:j.done,value:j.value}:j,k,l):k({value:j,done:r})).catch(j=>d("throw",j,k,l))}catch(j){l(j)}},f=(i,e,k,l)=>h[i]=n=>(e=new Promise((o,r,j)=>(j=()=>d(i,n,o,r),g?g.then(j):j())),l=()=>g===k&&(g=0),g=k=e.then(l,l),e),g,h={};return c=c.apply(a,b),h[p("asyncIterator")]=()=>h,f("next"),f("throw"),f("return"),h},P=a=>{var b=a[p("asyncIterator")],c=!1,d,f={};return b==null?(b=a[p("iterator")](),d=g=>f[g]=h=>b[g](h)):(b=b.call(a),d=g=>f[g]=h=>{if(c){if(c=!1,g==="throw")throw h;return h}return c=!0,{done:!1,value:new w(new Promise(i=>{var e=b[g](h);e instanceof Object||D("Object expected"),i(e)}),1)}}),f[p("iterator")]=()=>f,d("next"),"throw"in b?d("throw"):f.throw=g=>{throw g},"return"in b&&d("return"),f};export{E as a,F as b,G as c,H as d,I as e,J as f,K as g,L as h,M as i,N as j,w as k,O as l,P as m};
