import{a as k,b as T}from"./chunk-6POW7SSJ.js";import{a as D,b as F}from"./chunk-QGVT6DPT.js";import{K as B,k as y}from"./chunk-LDWBA6DZ.js";import{Ad as c,Jc as s,Qb as h,Ub as v,Vc as I,Xa as g,Yc as l,Zc as r,be as S,mc as x,oc as b,qd as _,tc as u,uc as a,vc as o,wc as C,yb as n,zd as p}from"./chunk-WL5U2YIT.js";import{e as E}from"./chunk-ADEKKGI2.js";function w(e,i){if(e&1&&(a(0,"div",0)(1,"label",3),l(2),p(3,"translate"),o(),a(4,"span",4),l(5),o()()),e&2){let t=s();n(),u("ngClass",_(5,j,t.highlight)),n(),r(c(3,3,t.label)),n(3),r(t.value)}}function M(e,i){if(e&1&&(a(0,"div",1)(1,"label",5),l(2),p(3,"translate"),o(),C(4,"div",6),a(5,"span",7),l(6),o()()),e&2){let t=s();n(2),r(c(3,2,t.label)),n(4),r(t.value)}}function P(e,i){if(e&1&&(a(0,"div",8)(1,"label",9),l(2),p(3,"translate"),o(),a(4,"span",10),l(5),o()()),e&2){let t=s();I("border-b",t.divider)("border-brand-300",t.divider)("mb-2",t.divider),n(2),r(c(3,8,t.label)),n(3),r(t.value)}}var j,H,N=E(()=>{B();F();T();S();j=e=>({"data-label-highlight":e});H=(()=>{let i=class i extends D{constructor(){super(...arguments),this.highlight=!1,this.divider=!1,this.stacked=!1}};i.\u0275fac=(()=>{let m;return function(d){return(m||(m=g(i)))(d||i)}})(),i.\u0275cmp=h({type:i,selectors:[["dvls-diagnostic-information"]],inputs:{label:"label",value:"value",highlight:"highlight",divider:"divider",stacked:"stacked"},features:[v],decls:3,vars:1,consts:[[1,"form-group"],[1,"flex","items-center","gap-3","mb-2"],[1,"flex","items-center","justify-between","gap-8",3,"border-b","border-brand-300","mb-2"],[3,"ngClass"],[1,"font-medium"],[1,"shrink-0","font-semibold","data-label-highlight"],[1,"flex-1","border-t","border-brand-300","self-center"],[1,"font-semibold"],[1,"flex","items-center","justify-between","gap-8"],[1,"shrink-0"],[1,"text-right"]],template:function(f,d){f&1&&x(0,w,6,7,"div",0)(1,M,7,4,"div",1)(2,P,6,10,"div",2),f&2&&b(d.stacked?0:d.highlight?1:2)},dependencies:[y,k],encapsulation:2});let e=i;return e})()});export{H as a,N as b};
