import{c as t,d}from"./chunk-6B6CBPYV.js";import{e as a}from"./chunk-ADEKKGI2.js";var n,s=a(()=>{d();n=class i{toQueryString(){let e=[];return this.displayName!==null&&this.displayName.toString()&&e.push("displayName="+encodeURIComponent(this.displayName.toString())),this.externalId!==null&&this.externalId.toString()&&e.push("externalId="+encodeURIComponent(this.externalId.toString())),this.id!==null&&this.id.toString()&&e.push("id="+encodeURIComponent(this.id.toString())),this.name!==null&&this.name.toString()&&e.push("name="+encodeURIComponent(this.name.toString())),this.providerId!==null&&this.providerId.toString()&&e.push("providerId="+encodeURIComponent(this.providerId.toString())),e.join("&")}constructor(e=null){this.clone=()=>new i(this),this.displayName=t.manageDefaultValue(e,"displayName",""),this.externalId=t.manageDefaultValue(e,"externalId",""),this.id=t.manageDefaultValue(e,"id",void 0),this.name=t.manageDefaultValue(e,"name",""),this.providerId=t.manageDefaultValue(e,"providerId",void 0)}}});export{n as a,s as b};
