import{a as i,b as j}from"./chunk-A22EQSF3.js";import{D as s,E as b,n as d,o as F}from"./chunk-I7GW4F3B.js";import{a as g,b as v}from"./chunk-QGVT6DPT.js";import{r as S,t as y}from"./chunk-HTXYTVN4.js";import{b as T,c as D}from"./chunk-YBNTOQCK.js";import{J as n,Sa as f,Sb as l,Ub as h,be as p,ia as m,ya as c}from"./chunk-WL5U2YIT.js";import{e as u}from"./chunk-ADEKKGI2.js";var M,C=u(()=>{p();y();j();F();D();v();f();b();p();M=(()=>{let e=class e extends g{constructor(){super(),this.defaultPageSize=c(s).webSettingsSnapshot?.defaultPageSize??20,this.errorSummaryMessages=[],this.dateFormatToDisplay="",this.timeFormatToDisplay="",this.dateTimeFormatToDisplay="",this.BASE_TITLE="Devolutions Server - ",this.titleService=i.injector.get(S),this.storageService=i.injector.get(d)}ngOnInit(){i.injector.get(s).webSettingsChanged.pipe(m(this.destroyed$),n(a=>!!a)).subscribe(a=>this.onWebSettingsChanged(a));let t=i.injector.get(T).translate(this.getComponentTitle());this.setTitle(t)}initErrorSummary(){this.errorSummaryMessages=[]}onWebSettingsChanged(r){let t=i.injector.get(s);this.defaultPageSize=r.defaultPageSize,this.dateFormatToDisplay=t.displayDateFormat,this.timeFormatToDisplay=t.displayTimeFormat,this.dateTimeFormatToDisplay=t.displayDateTimeFormat}setTitle(r){this.titleService.setTitle(this.BASE_TITLE+r)}};e.\u0275fac=function(t){return new(t||e)},e.\u0275dir=l({type:e,features:[h]});let o=e;return o})()});export{M as a,C as b};
