import{be as l,ta as i}from"./chunk-WL5U2YIT.js";import{e as r}from"./chunk-ADEKKGI2.js";var f,c=r(()=>{l();f=(()=>{let t=class t{clear(){this.provider=null,this.scanConfig=null,this.accounts=null,this.folderId=null}};t.\u0275fac=function(n){return new(n||t)},t.\u0275prov=i({token:t,factory:t.\u0275fac,providedIn:"root"});let o=t;return o})()});export{f as a,c as b};
