import{E as m,l as e,m as d}from"./chunk-JPHJ3OD7.js";import{Jb as n,Sb as s,be as l}from"./chunk-WL5U2YIT.js";import{e as c}from"./chunk-ADEKKGI2.js";var p,a=c(()=>{l();m();p=(()=>{let o=class o{constructor(t,i){this.control=t,this.modelGroup=i}ngOnInit(){(this.modelGroup?.control??this.sdAddToForm?.control)?.addControl(this.control.name,this.control.control)}ngOnDestroy(){(this.modelGroup?.control??this.sdAddToForm?.control)?.removeControl(this.control.name)}};o.\u0275fac=function(i){return new(i||o)(n(d),n(e,8))},o.\u0275dir=s({type:o,selectors:[["","sdAddToForm",""]],inputs:{sdAddToForm:"sdAddToForm"}});let r=o;return r})()});export{p as a,a as b};
