import{be as u,g as i,na as e,ta as a}from"./chunk-WL5U2YIT.js";import{e as c}from"./chunk-ADEKKGI2.js";var w,m,f=c(()=>{e();u();w=(()=>{let n=class n{constructor(){this.viewRequest=new i}view(r){this.viewRequest.next(r)}};n.\u0275fac=function(o){return new(o||n)},n.\u0275prov=a({token:n,factory:n.\u0275fac,providedIn:"root"});let t=n;return t})(),m=(function(t){return t[t.VaultConnection=0]="VaultConnection",t[t.PamCredential=1]="PamCredential",t[t.OtpTemplate=2]="OtpTemplate",t[t.PasswordList=3]="PasswordList",t})(m||{})});export{w as a,m as b,f as c};
