import{b as o,c as m}from"./chunk-YBNTOQCK.js";import{Jb as n,Sa as p,Tb as u,be as l,g as s,ia as a,na as h}from"./chunk-WL5U2YIT.js";import{e as c}from"./chunk-ADEKKGI2.js";var D,f=c(()=>{h();p();l();m();D=(()=>{let e=class e{constructor(t){this.translatorService=t,this.update=!0,this.currentValue="",this.onDestroy$=new s,this.lastKeyValue="",t.updatedLang$.pipe(a(this.onDestroy$)).subscribe(()=>{this.update=!0})}ngOnDestroy(){this.onDestroy$.next()}transform(t,r=[]){return(!this.update||!t)&&this.lastKeyValue===t?this.currentValue:(this.lastKeyValue=t,this.currentValue=this.translatorService.translate(t,r),this.update=!!r,this.currentValue)}};e.\u0275fac=function(r){return new(r||e)(n(o,16))},e.\u0275pipe=u({name:"translate",type:e,pure:!1});let i=e;return i})()});export{D as a,f as b};
