import{e as l}from"./chunk-ADEKKGI2.js";var o,c=l(()=>{o=(function(i){return i[i.Error=0]="Error",i[i.Success=1]="Success",i[i.AccessDenied=2]="AccessDenied",i[i.InvalidData=3]="InvalidData",i[i.AlreadyExists=4]="AlreadyExists",i[i.MaximumReached=5]="MaximumReached",i[i.NotFound=6]="NotFound",i[i.LicenseExpired=7]="LicenseExpired",i[i.Unknown=8]="Unknown",i[i.TwoFactorTypeNotConfigured=9]="TwoFactorTypeNotConfigured",i[i.WebApiRedirectToLogin=10]="WebApiRedirectToLogin",i[i.DuplicateLoginEmail=11]="DuplicateLoginEmail",i})(o||{});(function(i){function a(){return"SaveResult"}i.getClass=a;function n(t){let e="";return typeof i.getClass=="function"&&(e=i.getClass()),e+"_"+i[t]}i.getEnumKey=n})(o||(o={}))});var f,g=l(()=>{s();f=class i{toQueryString(){let a=[];return this.additionalData!==null&&this.additionalData.toString()&&a.push("additionalData="+encodeURIComponent(this.additionalData.toString())),this.currentPage!==null&&this.currentPage.toString()&&a.push("currentPage="+encodeURIComponent(this.currentPage.toString())),this.pageSize!==null&&this.pageSize.toString()&&a.push("pageSize="+encodeURIComponent(this.pageSize.toString())),this.totalCount!==null&&this.totalCount.toString()&&a.push("totalCount="+encodeURIComponent(this.totalCount.toString())),this.totalPage!==null&&this.totalPage.toString()&&a.push("totalPage="+encodeURIComponent(this.totalPage.toString())),a.join("&")}constructor(a=null){this.clone=()=>new i(this),this.additionalData=u.manageDefaultValue(a,"additionalData",null),this.currentPage=u.manageDefaultValue(a,"currentPage",0),this.data=a&&a.data?a.data:[],this.pageSize=u.manageDefaultValue(a,"pageSize",0),this.totalCount=u.manageDefaultValue(a,"totalCount",0),this.totalPage=u.manageDefaultValue(a,"totalPage",0)}}});var u,s=l(()=>{g();u=class{static manageDefaultDictionaryValue(a,n,t){if(a==null)return{};if(a[n]===void 0||a[n]===null)return{};let e=a[n],d={};for(let r of Object.keys(e))d[r]=e[r];return d}static manageDefaultDictionaryValueType(a,n,t){if(n==null)return{};if(n[t]===void 0||n[t]===null)return{};let e=n[t],d={};for(let r of Object.keys(e))d[r]=new a(e[r]);return d}static manageDefaultArrayValue(a,n,t){if(a==null)return[];if(a[n]===void 0||a[n]===null)return[];for(let e=0;e<a[n].length;e++){let d=a[n][e];d==null&&(a[n][e]=t)}return[...a[n]]}static manageDefaultArrayValueType(a,n,t){if(n==null)return[];if(n[t]===void 0||n[t]===null)return[];let e=[];for(let d of n[t])e.push(new a(d));return e}static manageDefaultValue(a,n,t){return a==null||a[n]===void 0||a[n]===null?t:a[n]}static manageDefaultValueType(a,n,t,e){return n==null||n[t]===void 0||n[t]===null?e:new a(n[t])}static handleServiceResult(a,n){n&&n.data&&(n.data=new a(n.data))}static handleServiceMultipleResult(a,n){if(n&&n.data){let t=n.data;n.data=[];for(let e of t)n.data.push(new a(e))}}static handleServicePagedResult(a,n){return n&&n.data&&(n.data=new f(n.data),n.data?.data&&(n.data.data=n.data?.data.map(t=>new a(t)))),n}static handleServicePagedResult2(a,n){return n&&(n=new f(n),n.data&&(n.data=n.data.map(t=>new a(t)))),n}static handleServiceArrayResult(a,n){if(n==null)return[];let t=[];for(let e of n)t.push(new a(e));return t}}});export{o as a,c as b,u as c,s as d};
