import{be as c,g as o,na as p,ta as l}from"./chunk-WL5U2YIT.js";import{e as i}from"./chunk-ADEKKGI2.js";var n,a=i(()=>{n=(function(e){return e[e.AddToExisting=0]="AddToExisting",e[e.ReplaceAllWith=1]="ReplaceAllWith",e[e.FindAndRemoveThese=2]="FindAndRemoveThese",e})(n||{});(function(e){function t(){return"BatchEditAction"}e.getClass=t;function f(r){let s="";return typeof e.getClass=="function"&&(s=e.getClass()),s+"_"+e[r]}e.getEnumKey=f})(n||(n={}))});var h,v=i(()=>{p();a();c();h=(()=>{let t=class t{constructor(){this.viewRequestSource=new o,this.viewRequest=this.viewRequestSource.asObservable()}view(r){this.viewRequestSource.next(r)}getBatchEditSelectedMembers(r,s,u){switch(s){case n.AddToExisting:return[...new Set([...r,...u])];case n.ReplaceAllWith:return u;case n.FindAndRemoveThese:return r.filter(m=>!u.includes(m));default:return[]}}};t.\u0275fac=function(s){return new(s||t)},t.\u0275prov=l({token:t,factory:t.\u0275fac,providedIn:"root"});let e=t;return e})()});export{n as a,a as b,h as c,v as d};
