import{a as p,b as d}from"./chunk-NEKDTWKR.js";import{$a as S,_a as m}from"./chunk-THQOQSZV.js";import{O as u,Sa as v,be as f,g as i,na as h,r as a,ta as o,xa as c}from"./chunk-WL5U2YIT.js";import{e as n}from"./chunk-ADEKKGI2.js";var I,b=n(()=>{h();v();f();S();d();I=(()=>{let e=class e{constructor(r,s){this.pamAssetServices=r,this.errorService=s}getJob(r){return this.handleError(this.pamAssetServices.AccountDiscoveryResults_GetScan(r))}getLastJobs(){return this.handleError(this.pamAssetServices.AccountDiscoveryResults_GetLastScans())}handleError(r,s=null){return r.pipe(u(l=>(this.errorService.handleError(l),a(s))))}};e.\u0275fac=function(s){return new(s||e)(c(m),c(p))},e.\u0275prov=o({token:e,factory:e.\u0275fac,providedIn:"root"});let t=e;return t})()});var g,q=n(()=>{h();f();g=(()=>{let e=class e{constructor(){this.viewRequestSource=new i,this.refreshRequestSource=new i,this.viewRequest=this.viewRequestSource.asObservable(),this.refreshRequest=this.refreshRequestSource.asObservable()}openDialog(r){this.viewRequestSource.next(r)}refresh(){this.refreshRequestSource.next()}};e.\u0275fac=function(s){return new(s||e)},e.\u0275prov=o({token:e,factory:e.\u0275fac,providedIn:"root"});let t=e;return t})()});export{I as a,b,g as c,q as d};
