import{D as n,E as h}from"./chunk-I7GW4F3B.js";import{D as o,I as f}from"./chunk-HTXYTVN4.js";import{be as u,ta as c,xa as s}from"./chunk-WL5U2YIT.js";import{e as a}from"./chunk-ADEKKGI2.js";var S,m=a(()=>{u();h();f();S=(()=>{let t=class t{constructor(i,r){this.currentUserService=i,this.router=r}canActivate(i,r){return!this.currentUserService.isAdministrator&&!this.currentUserService.accessSnapshot.hasAccessPam?(this.router.navigate(["/connections"]),!1):!0}};t.\u0275fac=function(r){return new(r||t)(s(n),s(o))},t.\u0275prov=c({token:t,factory:t.\u0275fac,providedIn:"root"});let e=t;return e})()});export{S as a,m as b};
