import{a as b,b as x}from"./chunk-U66OQZ4A.js";import{a as v,b as M}from"./chunk-RII6H6UF.js";import"./chunk-MOK7XOAA.js";import"./chunk-RWCAFOHA.js";import"./chunk-6B6CBPYV.js";import{a as g,b as w}from"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import{B as f,I}from"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import{Db as d,J as a,Jb as n,Qb as h,Sa as C,T as c,Ub as u,be as m,ia as l,x as r,ya as p}from"./chunk-WL5U2YIT.js";import{e as S}from"./chunk-ADEKKGI2.js";var O,y=S(()=>{m();C();w();M();m();I();x();O=(()=>{let t=class t extends g{constructor(i,e){super(),this.activatedRoute=i,this.navigationService=e,this.sizeChange=new d,this.webSessionIcon="",this.jetUrl="",this.webClientSessionService=p(v)}ngAfterViewInit(){this.subscribeToRoute()}subscribeToRoute(){this.activatedRoute.paramMap.pipe(c(1)).subscribe(i=>{this.sessionId=i.get("sessionId"),this.sessionId||this.initializePlaceholderSession(this.sessionId)})}initializePlaceholderSession(i){this.webClientSessionService.getAllWebSessions().pipe(l(this.destroyed$),r(e=>e.filter(o=>o.sessionId===i)),a(e=>e.length===0)).subscribe(()=>{this.navigationService.navigateToRoot()})}getComponentTitle(){return"lblWebApplication"}};t.\u0275fac=function(e){return new(e||t)(n(f),n(b))},t.\u0275cmp=h({type:t,selectors:[["ng-component"]],outputs:{sizeChange:"sizeChange"},features:[u],decls:0,vars:0,template:function(e,o){},styles:['[_nghost-%COMP%]{background:var(--connection-view-default-background-color) url("./media/session_background-PMMLASQV.png");display:flex;height:100%;width:100%;flex-direction:column}.session-container[_ngcontent-%COMP%]{display:flex;flex-direction:column;height:100%}']});let s=t;return s})()});y();export{O as WebClientPlaceholderComponent};
