import{K as F,k as b}from"./chunk-LDWBA6DZ.js";import{Jc as s,Qb as v,Yc as u,Zc as O,_c as P,be as w,mc as g,oc as m,qc as p,rc as d,rd as f,sc as _,tc as C,uc as o,vc as a,wc as y,yb as i}from"./chunk-WL5U2YIT.js";import{e as M}from"./chunk-ADEKKGI2.js";var l,E=M(()=>{l=(function(e){return e[e.Error=0]="Error",e[e.Warning=1]="Warning",e})(l||{})});function S(e,n){if(e&1&&(o(0,"li",3),u(1),a()),e&2){let t=n.$implicit,r=s(4);C("ngClass",f(2,h,r.isWarning,r.isError)),i(),P(" ",t," ")}}function k(e,n){if(e&1&&(o(0,"span")(1,"ul"),d(2,S,2,5,"li",3,p),a()()),e&2){let t=s().$implicit;i(2),_(t.subMessages)}}function W(e,n){if(e&1&&(o(0,"span")(1,"p",0),y(2,"i",1),o(3,"label",2),u(4),a()(),g(5,k,4,0,"span"),a()),e&2){let t=n.$implicit,r=s(2);i(),C("ngClass",f(3,h,r.isWarning,r.isError)),i(3),O(t.message),i(),m(t.subMessages.length>0?5:-1)}}function I(e,n){if(e&1&&(o(0,"span"),d(1,W,6,6,"span",null,p),a()),e&2){let t=s();i(),_(t.messages)}}var h,j,T=M(()=>{E();F();w();h=(e,n)=>({warning:e,error:n});j=(()=>{let n=class n{constructor(){this.messages=[],this.type=l.Error}get isWarning(){return this.type===l.Warning}get isError(){return this.type===l.Error}};n.\u0275fac=function(c){return new(c||n)},n.\u0275cmp=v({type:n,selectors:[["sd-message-summary"]],inputs:{messages:"messages",type:"type"},decls:1,vars:1,consts:[[1,"dvl-form-message-summary",3,"ngClass"],[1,"di","dvl-icon-notification"],[1,"message-label"],[3,"ngClass"]],template:function(c,x){c&1&&g(0,I,3,0,"span"),c&2&&m((x.messages==null?null:x.messages.length)>0?0:-1)},dependencies:[b],styles:["ul[_ngcontent-%COMP%]{margin-left:15px;padding-left:20px;margin-top:5px}.message-label[_ngcontent-%COMP%]{align-self:center;margin-left:5px}li[_ngcontent-%COMP%]{line-height:1.5em}li.error[_ngcontent-%COMP%]{color:rgba(var(--status-banner-error-color-rgb),1)}li.warning[_ngcontent-%COMP%]{color:orange}p[_ngcontent-%COMP%]{padding:10px 16px;margin:0;display:flex}p.error[_ngcontent-%COMP%]{background:var(--message-error-background-color)}p.error[_ngcontent-%COMP%]   .message-label[_ngcontent-%COMP%], p.error[_ngcontent-%COMP%]   .dvl-icon[_ngcontent-%COMP%]{color:var(--message-error-color)}p.warning[_ngcontent-%COMP%]{background:var(--message-warn-background-color)}p.warning[_ngcontent-%COMP%]   .message-label[_ngcontent-%COMP%], p.warning[_ngcontent-%COMP%]   .dvl-icon[_ngcontent-%COMP%]{color:var(--message-warn-color)}"]});let e=n;return e})()});export{j as a,T as b};
