import{t as l,u as m,v as f}from"./chunk-ZBM6BFOI.js";import{Kc as d,Lc as p,Qb as i,be as v,mc as o,oc as a,uc as r,vc as s,wc as c}from"./chunk-WL5U2YIT.js";import{e as C}from"./chunk-ADEKKGI2.js";function _(n,e){n&1&&(r(0,"div",0),c(1,"p-progressSpinner"),s())}function D(n,e){n&1&&p(0)}var y,M,L=C(()=>{f();v();f();y=["*"];M=(()=>{let e=class e{};e.\u0275fac=function(t){return new(t||e)},e.\u0275cmp=i({type:e,selectors:[["sd-data-loader"]],inputs:{isLoading:"isLoading"},ngContentSelectors:y,decls:2,vars:1,consts:[[1,"loading-container"]],template:function(t,u){t&1&&(d(),o(0,_,2,0,"div",0)(1,D,1,0)),t&2&&a(u.isLoading?0:1)},dependencies:[m,l],styles:[".loading-container[_ngcontent-%COMP%]{height:100%;display:flex;align-items:center;justify-content:center}"]});let n=e;return n})()});export{M as a,L as b};
