import{Tb as i,be as p}from"./chunk-WL5U2YIT.js";import{e as a}from"./chunk-ADEKKGI2.js";var n,f=a(()=>{p();n=(()=>{let r=class r{transform(t){return t==null?{}:{"transition-colors":!0,"text-sensitive":t>10&&t<=20,"animate-pulse":t<=10,"text-error":t<=10}}};r.\u0275fac=function(s){return new(s||r)},r.\u0275pipe=i({name:"animateOtp",type:r,pure:!0});let e=r;return e})()});export{n as a,f as b};
