import{be as n,g as r,na as s,ta as c}from"./chunk-WL5U2YIT.js";import{e as a}from"./chunk-ADEKKGI2.js";var u,f=a(()=>{s();n();u=(()=>{let t=class t{constructor(){this.showCertificateDialogSource=new r,this.showCertificateDialogObservable=this.showCertificateDialogSource.asObservable()}show(i,o){this.showCertificateDialogSource.next({certificate:i,acceptFunction:o})}};t.\u0275fac=function(o){return new(o||t)},t.\u0275prov=c({token:t,factory:t.\u0275fac,providedIn:"root"});let e=t;return e})()});export{u as a,f as b};
