import{E as f,c as o}from"./chunk-JPHJ3OD7.js";import{Sb as n,be as c,od as u,sa as l}from"./chunk-WL5U2YIT.js";import{e as s}from"./chunk-ADEKKGI2.js";var r,m=s(()=>{r=class{constructor(){this.emailPattern=/^[a-zA-Z0-9.!#$%&’*+/=?^_`{|}~-]+@[a-zA-Z0-9-]+(?:\.[a-zA-Z0-9-]+)+$/}validate(e){return this.emailPattern.test(this.extractEmail(e))}extractEmail(e){let a=e.lastIndexOf("<"),t=e.lastIndexOf(">");return a>=0&&t>=a?e.substring(a+1,t-1):e}}});var z,p=s(()=>{f();c();m();c();z=(()=>{let e=class e{constructor(){this.emailHelper=new r}validate(t){return!t.value||t.value.length===0||this.emailHelper.validate(t.value)?null:{email:{valid:!1}}}};e.\u0275fac=function(d){return new(d||e)},e.\u0275dir=n({type:e,selectors:[["sd-input-email"],["","sdValidateEmail","","ngModel",""]],features:[u([{provide:o,useExisting:l(()=>e),multi:!0}])]});let i=e;return i})()});export{z as a,p as b};
