import{a as u,b as w}from"./chunk-Y3SKC4HP.js";import{Tb as p,be as a,ya as l}from"./chunk-WL5U2YIT.js";import{a as o,b as s,e as b}from"./chunk-ADEKKGI2.js";var C,y=b(()=>{a();w();a();C=(()=>{let e=class e{constructor(){this.helper=l(u)}transform(i,t=0,c=[],m=[],f=!1,h=null,d=null){return this.helper.initComboEnum(i,c,f,!1,t,h,d).map(n=>s(o({},n),{disabled:m.includes(n.value)}))}};e.\u0275fac=function(t){return new(t||e)},e.\u0275pipe=p({name:"getSelectItemsFromEnum",type:e,pure:!0});let r=e;return r})()});export{C as a,y as b};
