import{Ta as p,Ua as c,be as h,o as l,p as d,ta as g}from"./chunk-WL5U2YIT.js";import{e as a}from"./chunk-ADEKKGI2.js";var i,u=a(()=>{i=(function(e){return e[e.log=0]="log",e[e.warning=1]="warning",e[e.error=2]="error",e})(i||{})});var f,n,G=a(()=>{d();h();u();h();f=(()=>{let r=class r{log(s,t){}warn(s,t){}error(s,t){}printGroup(s,t){}};r.\u0275fac=function(t){return new(t||r)},r.\u0275prov=g({token:r,factory:r.\u0275fac,providedIn:"root"});let e=r;return e})(),n=class extends f{constructor(){super(),this.groupList=[],this.buildLogFactory()}log(r,o){this.logMessage(r,i.log,o)}warn(r,o){this.logMessage(r,i.warning,o)}error(r,o){this.logMessage(r,i.error,o)}printGroup(r,o){r=r||this.lastGroupName;let s=this.findGroup(r);s&&(console.group(o),s.messages.forEach(t=>{this.printMessage(t.message,t.type)}),console.groupEnd(),this.groupList.splice(this.groupList.findIndex(t=>t.label===r)))}logMessage(r,o=i.log,s){s?(this.lastGroupName=s,this.addMessageToGroup(r,s,o)):this.printMessage(r,o)}printMessage(r,o=i.log){this.logFactory[o](r)}addMessageToGroup(r,o,s=i.log){o=o||this.lastGroupName;let t=this.findGroup(o);t=t||{label:o,messages:[]},t.messages.push({message:r,type:s}),this.groupList.push(t)}findGroup(r){return this.groupList.find(o=>o.label===r)}buildLogFactory(){this.logFactory={},this.logFactory[i.log]=r=>{console.log(r)},this.logFactory[i.error]=r=>{console.error(r)},this.logFactory[i.warning]=r=>{console.warn(r)}}};l([p("environment"),c()],n.prototype,"environment",void 0)});export{f as a,n as b,G as c};
