import{a as p}from"./chunk-YBNTOQCK.js";import{Tb as i,be as a}from"./chunk-WL5U2YIT.js";import{e as m,h as n}from"./chunk-ADEKKGI2.js";var o,u,s=m(()=>{o=n(p());a();u=(()=>{let t=class t{transform(e){return e?o.default.utc(e).local().fromNow():""}};t.\u0275fac=function(f){return new(f||t)},t.\u0275pipe=i({name:"fromNow",type:t,pure:!1});let r=t;return r})()});export{u as a,s as b};
