import{a as M,b as $}from"./chunk-6POW7SSJ.js";import{a as k,b as z}from"./chunk-QGVT6DPT.js";import{K as P,k as B}from"./chunk-LDWBA6DZ.js";import{Ad as x,Db as S,Dc as E,Ea as D,Fa as V,Hc as I,Jc as d,Qb as b,Ub as T,Xa as h,Yc as c,Zc as f,_c as C,be as F,mc as s,oc as r,qc as m,rc as _,rd as R,sc as y,tc as w,uc as l,vc as o,wc as p,yb as n,zd as g}from"./chunk-WL5U2YIT.js";import{e as O}from"./chunk-ADEKKGI2.js";function H(e,i){e&1&&(l(0,"div",6),c(1),g(2,"translate"),o()),e&2&&(n(),f(x(2,1,"lblHideDetails")))}function N(e,i){e&1&&(l(0,"div",6),c(1),g(2,"translate"),o()),e&2&&(n(),f(x(2,1,"lblShowDetails")))}function U(e,i){if(e&1){let t=E();l(0,"div",4),I("click",function(){D(t);let u=d();return V(u.toggleDetails())}),l(1,"div",5),s(2,H,3,3,"div",6),s(3,N,3,3,"div",6),l(4,"div"),p(5,"i",7),o()()()}if(e&2){let t=d();n(2),r(t.detailsVisible?2:-1),n(),r(t.detailsVisible?-1:3),n(2),w("ngClass",R(3,j,t.detailsVisible,!t.detailsVisible))}}function q(e,i){if(e&1&&(l(0,"li",8)(1,"div",9),p(2,"i",10),c(3),o()()),e&2){let t=i.$implicit;n(3),C(" ",t," ")}}function A(e,i){if(e&1&&(l(0,"ul",3),_(1,q,4,1,"li",8,m),o()),e&2){let t=d();n(),y(t.roleDisplayValues)}}function G(e,i){if(e&1&&(l(0,"li",8)(1,"div",9),p(2,"i",11),c(3),o()()),e&2){let t=i.$implicit;n(3),C(" ",t," ")}}function J(e,i){if(e&1&&(l(0,"ul",3),_(1,G,4,1,"li",8,m),o()),e&2){let t=d();n(),y(t.userDisplayValues)}}function K(e,i){if(e&1&&(l(0,"li",8)(1,"div",9),p(2,"i",12),c(3),o()()),e&2){let t=i.$implicit;n(3),C(" ",t," ")}}function L(e,i){if(e&1&&(l(0,"ul",3),_(1,K,4,1,"li",8,m),o()),e&2){let t=d();n(),y(t.applicationsDisplayValues)}}function Q(e,i){if(e&1&&(l(0,"li",8)(1,"div",9),p(2,"i",13),c(3),o()()),e&2){let t=i.$implicit;n(3),C(" ",t," ")}}function W(e,i){if(e&1&&(l(0,"ul",3),_(1,Q,4,1,"li",8,m),o()),e&2){let t=d();n(),y(t.vaultDisplayValues)}}var j,oe,X=O(()=>{F();z();P();$();F();j=(e,i)=>({"dvl-icon-arrow-up":e,"dvl-icon-arrow-down":i});oe=(()=>{let i=class i extends k{constructor(){super(...arguments),this.userDisplayValues=[],this.roleDisplayValues=[],this.applicationsDisplayValues=[],this.vaultDisplayValues=[],this.detailsVisible=!1,this.detailsVisibleChange=new S}toggleDetails(){this.detailsVisibleChange?.emit(!this.detailsVisible)}};i.\u0275fac=(()=>{let v;return function(a){return(v||(v=h(i)))(a||i)}})(),i.\u0275cmp=b({type:i,selectors:[["dvls-connection-security-right-details"]],inputs:{userDisplayValues:"userDisplayValues",roleDisplayValues:"roleDisplayValues",applicationsDisplayValues:"applicationsDisplayValues",vaultDisplayValues:"vaultDisplayValues",detailsVisible:"detailsVisible"},outputs:{detailsVisibleChange:"detailsVisibleChange"},features:[T],decls:7,vars:5,consts:[[2,"width","100%"],[2,"display","flex","padding-right","16px","cursor","pointer","justify-content","flex-end"],[2,"display","flex","margin-left","11px","border-left","var(--dialog-menu-border-color) 1px solid"],[2,"margin","0 0 5px"],[2,"display","flex","padding-right","16px","cursor","pointer","justify-content","flex-end",3,"click"],[2,"display","flex","align-items","center","font-size","11px"],[1,"details-label"],[1,"dvl-icon","caret-icon",3,"ngClass"],[1,"username-display"],[2,"display","flex","align-items","center"],[1,"di","dvl-icon-roles","detail-icon"],[1,"di","dvl-icon-entry-SampleUser","detail-icon"],[1,"di","dvl-icon-entry-session-command-line","detail-icon"],[1,"di","dvl-icon-vault","detail-icon"]],template:function(u,a){u&1&&(l(0,"div",0),s(1,U,6,6,"div",1),l(2,"div",2),s(3,A,3,0,"ul",3),s(4,J,3,0,"ul",3),s(5,L,3,0,"ul",3),s(6,W,3,0,"ul",3),o()()),u&2&&(n(),r(a.roleDisplayValues!=null&&a.roleDisplayValues.length||a.userDisplayValues!=null&&a.userDisplayValues.length||a.applicationsDisplayValues!=null&&a.applicationsDisplayValues.length||a.vaultDisplayValues!=null&&a.vaultDisplayValues.length?1:-1),n(2),r(a.detailsVisible?3:-1),n(),r(a.detailsVisible?4:-1),n(),r(a.detailsVisible?5:-1),n(),r(a.detailsVisible?6:-1))},dependencies:[B,M],styles:[".username-display[_ngcontent-%COMP%]{padding:5px 10px;width:100%;white-space:nowrap;overflow:hidden;text-overflow:ellipsis;font-size:12px;margin:0}.label[_ngcontent-%COMP%]{align-items:center}.caret-icon[_ngcontent-%COMP%]{font-size:20px;color:var(--fieldset-title-color)}.detail-icon[_ngcontent-%COMP%]{font-size:16px;padding-right:2px}.details-label[_ngcontent-%COMP%]{color:var(--fieldset-title-color)}"]});let e=i;return e})()});export{oe as a,X as b};
