import{Mi as s,Ni as t}from"./chunk-BPZQKZKD.js";import{e}from"./chunk-ADEKKGI2.js";var a,i=e(()=>{t();a=class extends s{updatePasswordDisplayValue(){if(this.repositorySettings.masterPasswordHash||this.password){this.passwordDisplayValue="\u25CF\u25CF\u25CF\u25CF\u25CF\u25CF";return}this.passwordDisplayValue=""}getImage(){return this.imageBytes&&this.imageBytes.length>0?"data:image/png;base64,"+this.imageBytes:this.imageName?this.imageName:""}}});export{a,i as b};
