import{a as j,c as P}from"./chunk-VM2L5ERO.js";import{a as $,b as N}from"./chunk-6POW7SSJ.js";import{d as F,e as L,i as T,j as z}from"./chunk-AGRQYW7D.js";import{Ad as D,Kc as g,Lc as h,Od as I,Qb as o,Ub as b,Xa as p,Yc as y,Zc as x,be as n,od as w,ta as c,tc as d,uc as f,vc as m,wc as v,ya as u,yb as r,zd as M}from"./chunk-WL5U2YIT.js";import{e as s}from"./chunk-ADEKKGI2.js";var A,R,V,C,S,k=s(()=>{n();n();z();L();A=["*"],R=({dt:e})=>`
.p-iftalabel {
    display: block;
    position: relative;
}

.p-iftalabel label {
    position: absolute;
    pointer-events: none;
    top: ${e("iftalabel.top")};
    transition-property: all;
    transition-timing-function: ease;
    line-height: 1;
    font-size: ${e("iftalabel.font.size")};
    font-weight: ${e("iftalabel.font.weight")};
    inset-inline-start: ${e("iftalabel.position.x")};
    color: ${e("iftalabel.color")};
    transition-duration: ${e("iftalabel.transition.duration")};
}

.p-iftalabel .p-inputtext,
.p-iftalabel .p-textarea,
.p-iftalabel .p-select-label,
.p-iftalabel .p-multiselect-label-container,
.p-iftalabel .p-autocomplete-input-multiple,
.p-iftalabel .p-cascadeselect-label,
.p-iftalabel .p-treeselect-label,
.p-iftalabel .p-datepicker-input,
.p-iftalabel .p-inputmask,
.p-iftalabel .p-autocomplete .p-inputtext,
.p-iftalabel .p-inputnumber .p-inputtext,
.p-iftalabel .p-password .p-inputtext,
.p-iftalabel > .p-iconfield .p-inputtext {
    padding-top: ${e("iftalabel.input.padding.top")};
}

.p-iftalabel:has(.ng-invalid.ng-dirty) label {
    color: ${e("iftalabel.invalid.color")};
}

.p-iftalabel:has(input:focus) label,
.p-iftalabel:has(input:-webkit-autofill) label,
.p-iftalabel:has(textarea:focus) label,
.p-iftalabel:has(.p-inputwrapper-focus) label {
    color: ${e("iftalabel.focus.color")};
}

.p-iftalabel .p-inputicon {
    top: ${e("iftalabel.input.padding.top")};
    transform: translateY(25%);
    margin-top: 0;
}

/*.p-iftalabel .p-placeholder,
.p-iftalabel input::placeholder,
.p-iftalabel .p-inputtext::placeholder {
    opacity: 0;
    transition-property: all;
    transition-timing-function: ease;
}

.p-iftalabel .p-focus .p-placeholder,
.p-iftalabel input:focus::placeholder,
.p-iftalabel .p-inputtext:focus::placeholder {
    opacity: 1;
    transition-property: all;
    transition-timing-function: ease;
}*/
`,V={root:"p-iftalabel"},C=(()=>{class e extends F{name="iftalabel";theme=R;classes=V;static \u0275fac=(()=>{let i;return function(t){return(i||(i=p(e)))(t||e)}})();static \u0275prov=c({token:e,factory:e.\u0275fac})}return e})(),S=(()=>{class e extends T{_componentStyle=u(C);static \u0275fac=(()=>{let i;return function(t){return(i||(i=p(e)))(t||e)}})();static \u0275cmp=o({type:e,selectors:[["p-iftalabel"],["p-iftaLabel"],["p-ifta-label"]],hostAttrs:[1,"p-iftalabel"],features:[w([C]),b],ngContentSelectors:A,decls:1,vars:0,template:function(l,t){l&1&&(g(),h(0))},encapsulation:2,changeDetection:0})}return e})()});var le,Y=s(()=>{n();N();k();P();n();le=(()=>{let a=class a{constructor(){this.previewText=I("")}};a.\u0275fac=function(t){return new(t||a)},a.\u0275cmp=o({type:a,selectors:[["dvls-ssh-jit-template-preview"]],inputs:{previewText:[1,"previewText"]},decls:5,vars:4,consts:[[1,"mt-2"],["pSize","small","pTextarea","","disabled","","id","preview","rows","4",1,"resize-none","w-full",3,"value"],["for","preview",1,"!p-0"]],template:function(t,B){t&1&&(f(0,"p-iftalabel",0),v(1,"textarea",1),f(2,"label",2),y(3),M(4,"translate"),m()()),t&2&&(r(),d("value",B.previewText()),r(2),x(D(4,2,"lblPreview")))},dependencies:[S,j,$],encapsulation:2});let e=a;return e})()});export{le as a,Y as b};
