import{a as f,b}from"./chunk-DJ546A6R.js";import{D as p,E as g}from"./chunk-I7GW4F3B.js";import{c,d as I}from"./chunk-RWCAFOHA.js";import{Gk as m,Hk as S}from"./chunk-BPZQKZKD.js";import{b as n,c as j}from"./chunk-YBNTOQCK.js";import{Sa as h,be as d,ta as o,x as a,xa as i}from"./chunk-WL5U2YIT.js";import{e as v}from"./chunk-ADEKKGI2.js";var B,T=v(()=>{b();h();d();j();I();g();S();B=(()=>{let e=class e extends f{constructor(t,r,l,u){super(t,r,l),this.assetService=u}getTimezones(t=!1){return this.getCache(t,this.getTimezonesInternal())}getTimezonesInternal(){return this.assetService.GetTimezones().pipe(a(t=>t.data.map(r=>({label:r.DisplayName,value:r.Id}))))}};e.\u0275fac=function(r){return new(r||e)(i(n),i(c),i(p),i(m))},e.\u0275prov=o({token:e,factory:e.\u0275fac,providedIn:"root"});let s=e;return s})()});export{B as a,T as b};
