import{a as d,b as g}from"./chunk-MOK7XOAA.js";import{a as c,b as f,c as s,d as m}from"./chunk-RWCAFOHA.js";import{D as n,I as l}from"./chunk-HTXYTVN4.js";import{be as v,ta as a,xa as i}from"./chunk-WL5U2YIT.js";import{e as h}from"./chunk-ADEKKGI2.js";var w,I=h(()=>{f();v();l();g();m();w=(()=>{let r=class r{constructor(t,o,p){this.router=t,this.longOperationIndicatorService=o,this.errorService=p}navigate(t){this.longOperationIndicatorService.showIndicator("standard"),this.router.navigateByUrl(t).then(()=>this.longOperationIndicatorService.hideIndicator("standard"),()=>{this.errorService.pushError(new c({errorType:"client",exceptionMessage:"navigation error",fatal:!1,message:`could not navigate to ${t}`})),this.longOperationIndicatorService.hideIndicator("standard")})}navigateToRoot(){this.router.navigateByUrl("/")}};r.\u0275fac=function(o){return new(o||r)(i(n),i(d),i(s))},r.\u0275prov=a({token:r,factory:r.\u0275fac,providedIn:"root"});let e=r;return e})()});export{w as a,I as b};
