import{a,b as U}from"./chunk-RJ7GQMQE.js";import{a as i,b as f}from"./chunk-3ETX22XM.js";import{a as c,b as u}from"./chunk-4ERZBM5I.js";import{Cc as e,Dc as m}from"./chunk-BPZQKZKD.js";import{be as h,ta as n}from"./chunk-WL5U2YIT.js";import{e as d}from"./chunk-ADEKKGI2.js";var t,v=d(()=>{u();t=(()=>{let r=class r{static getBuiltInTemplateIcon(l){switch(l?.toLowerCase()){case c.ciscoBuiltInTemplateId:return r.cisco;case c.mySqlUserBuiltInTemplateId:return r.mySQL;case c.oracleBuiltInTemplateId:return r.oracle;default:return null}}};r.domainUser="dvl-icon-entry-domain",r.localUser="dvl-icon-entry-session-ssh",r.sqlServer="dvl-icon-sql",r.windowsLocalAccount="dvl-icon-logo-microsoft",r.azureADUser="dvl-icon-entra-id",r.awsIAMUser="dvl-icon-aws",r.sshKey="dvl-icon-ssh-key-dashboard",r.postgreSQL="dvl-icon-entry-PgAdminIII",r.mongoDb="dvl-icon-mongodb",r.certificate="dvl-icon-entry-certificate",r.standalone="dvl-icon-cal",r.cisco="dvl-icon-cisco",r.mySQL="dvl-icon-mysql",r.oracle="dvl-icon-oracle";let o=r;return o})()});var q,p=d(()=>{U();m();f();v();h();q=(()=>{let r=class r{getByCredentialType(l,s){switch(l){case e.DomainUser:return s===a.Provider?i.domainUser:t.domainUser;case e.LocalUser:return s===a.Provider?i.localUser:t.localUser;case e.Certificate:return t.certificate;case e.SqlServer:return s===a.Provider?i.sqlServer:t.sqlServer;case e.WindowsLocalAccount:return i.windowsLocalAccount;case e.AzureADUser:return s===a.Provider?i.azureADUser:t.azureADUser;case e.AWSIAMUser:return s===a.Provider?i.awsIAMUser:t.awsIAMUser;case e.Standalone:return t.standalone;case e.SshKey:return i.sshKey;case e.PostgreSQL:return s===a.Provider?i.postgreSQL:t.postgreSQL;case e.MongoDb:return s===a.Provider?i.mongoDb:t.mongoDb;default:return"dvl-icon-credentials-bold"}}};r.\u0275fac=function(s){return new(s||r)},r.\u0275prov=n({token:r,factory:r.\u0275fac,providedIn:"root"});let o=r;return o})()});export{q as a,p as b};
