import{m as c,q as h}from"./chunk-HTXYTVN4.js";import{Db as s,be as a,ta as n,xa as o}from"./chunk-WL5U2YIT.js";import{e as p}from"./chunk-ADEKKGI2.js";var j,m=p(()=>{a();a();h();j=(()=>{let t=class t{constructor(i){this.httpClient=i,this.viewSessions=new s,this.route="api/gateway"}terminateSession(i,r){return this.httpClient.post(`${this.route}/${r}/session/${i}/terminate`,{})}};t.\u0275fac=function(r){return new(r||t)(o(c))},t.\u0275prov=n({token:t,factory:t.\u0275fac,providedIn:"root"});let e=t;return e})()});export{j as a,m as b};
