import{a as f,b as d}from"./chunk-NZJHSGMO.js";import{a as U}from"./chunk-AX7GEE3B.js";import{D as u,E as I,j as o,k as T}from"./chunk-I7GW4F3B.js";import{q as l,r as S}from"./chunk-SM7EQ7ST.js";import{be as c,ta as a,wa as s,ya as e}from"./chunk-WL5U2YIT.js";import{e as p,h as g}from"./chunk-ADEKKGI2.js";var h,y,P,L=p(()=>{c();T();I();h=g(U());d();S();y=new Set(["hu-HU"]),P=new s("Toast UI Editor Options",{providedIn:"root",factory(){let{culture:r}=e(u).currentUserSnapshot,{isDarkTheme:t}=e(l),m=o.getBCP47Value(o.fromValue(r),o.DEFAULT_LOCALE);return{initialEditType:"wysiwyg",plugins:[[f,{highlighter:h.default}]],usageStatistics:!1,height:"100%",autofocus:!0,theme:t?"dark":"light",previewStyle:"vertical",language:y.has(m)?"en-US":m}}})});var O,D,E=p(()=>{c();O={ar:()=>import("./chunk-3Y7K3N2F.js"),"cs-cz":()=>import("./chunk-JRF7UAEC.js"),"de-de":()=>import("./chunk-Z6ZKGZD4.js"),"es-es":()=>import("./chunk-LDMPCHTT.js"),"fi-fi":()=>import("./chunk-NOPRXTE3.js"),"fr-fr":()=>import("./chunk-ZE25VOWB.js"),"gl-es":()=>import("./chunk-A23AXT2J.js"),"hr-hr":()=>import("./chunk-3OVZXXYI.js"),"it-it":()=>import("./chunk-JG3J2YHV.js"),"ja-jp":()=>import("./chunk-V4WK263R.js"),"ko-kr":()=>import("./chunk-ULIDRJLD.js"),"nb-no":()=>import("./chunk-OZ52US7Z.js"),"nl-nl":()=>import("./chunk-WPBHZKKF.js"),"pl-pl":()=>import("./chunk-ME4UDNBD.js"),"pt-br":()=>import("./chunk-DQJRT7TY.js"),"ru-ru":()=>import("./chunk-5IJOQIGL.js"),"sv-se":()=>import("./chunk-4BI33OBH.js"),"tr-tr":()=>import("./chunk-3EBZTMPC.js"),"uk-ua":()=>import("./chunk-WLLQKUW4.js"),"zh-cn":()=>import("./chunk-2Q6TDXM4.js"),"zh-tw":()=>import("./chunk-XT7KANSS.js")},D=(()=>{let t=class t{dynamicallyImportToastUILanguage(n){let i=n.toLowerCase();return O[i]?.()??Promise.resolve(null)}};t.\u0275fac=function(i){return new(i||t)},t.\u0275prov=a({token:t,factory:t.\u0275fac,providedIn:"root"});let r=t;return r})()});export{P as a,L as b,D as c,E as d};
