import{a as O,b as q}from"./chunk-ERBABQHD.js";import{a as D,b as z}from"./chunk-R5HXMUGB.js";import"./chunk-AQH4BMGD.js";import"./chunk-OGIVSRCZ.js";import{a as M,b as Q}from"./chunk-3E7FAEEN.js";import"./chunk-GPOUKG47.js";import"./chunk-A22EQSF3.js";import"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import{a as y,b as w}from"./chunk-6POW7SSJ.js";import{cb as _,zb as j}from"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import{q as b,r as P,s as k}from"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import{D as h,I as A}from"./chunk-HTXYTVN4.js";import{b as S,c as B}from"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import{Ad as u,Cc as C,Hc as m,Jb as r,Qb as g,Ub as v,be as T,id as c,tc as a,uc as n,vc as p,wc as f,yb as s,zd as d}from"./chunk-WL5U2YIT.js";import{e as x}from"./chunk-ADEKKGI2.js";var U,E=x(()=>{Q();q();k();w();j();T();B();z();A();k();U=(()=>{let e=class e extends M{constructor(l,t,i){super(),this.translatorService=l,this.pamOnboardingSharedDataService=t,this.router=i,this.titleHeader=[{title:this.translatorService.translate("lblAdministration")},{title:this.translatorService.translate("lblPrivilegedAccessManagement"),link:"/administration/pam/"},{title:this.translatorService.translate("lblPamQuickStart")}]}getComponentTitle(){return"lblPamQuickStart"}ngOnInit(){super.ngOnInit(),this.pamOnboardingSharedDataService.clear()}onContinueClick(){this.router.navigate(["/administration/pam/quickstart/setup"])}};e.\u0275fac=function(t){return new(t||e)(r(S),r(D),r(h))},e.\u0275cmp=g({type:e,selectors:[["ng-component"]],features:[v],decls:9,vars:9,consts:[[3,"titlePage"],["header-right",""],["severity","info",3,"text"],[1,"page-container"],[1,"di","dvl-icon-quick-start","onboarding-icon",3,"click"],["size","md","variant","primary",3,"onClick","label"]],template:function(t,i){t&1&&(n(0,"dvl-page-wrapper-v2",0),C(1,1),n(2,"div"),f(3,"p-message",2),d(4,"translate"),n(5,"div",3)(6,"i",4),m("click",function(){return i.onContinueClick()}),p(),n(7,"dvl-button",5),d(8,"translate"),m("onClick",function(){return i.onContinueClick()}),p()()()()),t&2&&(a("titlePage",i.titleHeader),s(3),a("text",c(u(4,5,"PAMQuickStart_Intro_Details"))),s(4),a("label",c(u(8,7,"lblContinue"))))},dependencies:[O,P,b,_,y],styles:[".page-container[_ngcontent-%COMP%]{padding-top:20px;display:flex;flex-direction:column;align-items:center}.onboarding-icon[_ngcontent-%COMP%]{font-size:300px}[_nghost-%COMP%]     .continue-button{width:200px!important;height:60px!important}"]});let o=e;return o})()});E();export{U as PamOnboardingIntroPageComponent};
