import{a as g,b as W}from"./chunk-6YYTBF6E.js";import{a as u,b as A}from"./chunk-ERBABQHD.js";import"./chunk-AQH4BMGD.js";import{a as w,b as y}from"./chunk-R4AL7VPU.js";import{a as p,b as T}from"./chunk-L3D6TWWP.js";import"./chunk-ZVUXF5PM.js";import"./chunk-OGIVSRCZ.js";import"./chunk-GPOUKG47.js";import"./chunk-FRJ6A5YK.js";import"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-6POW7SSJ.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import{m as b,n as N}from"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import"./chunk-HTXYTVN4.js";import{b as v,c as k}from"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import{Qb as l,Sa as D,T as s,be as h,tc as r,uc as c,vc as d,wc as m,ya as o,yb as a}from"./chunk-WL5U2YIT.js";import{e as f}from"./chunk-ADEKKGI2.js";var j,C=f(()=>{h();k();A();W();T();y();D();N();h();j=(()=>{let e=class e{constructor(){this.hasAccessToOnBoarding=!1,this.translateService=o(v),this.whatsNewService=o(p),this.onboardingService=o(w),this.serverInformationService=o(b),this.sections=[]}ngOnInit(){this.initMenu(),this.onboardingService.getSteps().pipe(s(1)).subscribe(t=>{this.hasAccessToOnBoarding=(t||[]).length>0,this.initMenu()})}initMenu(){this.sections=[{label:this.translateService.translate("lblAppsAndCompanionTools"),items:[{label:this.translateService.translate("DevolutionsWorkspace"),icon:"dvl-icon-logo-workspace",command:()=>window.open("https://redirection.devolutions.com/5e01e501-7b16-48b8-a058-9b914a20307d","_blank")},{label:this.translateService.translate("DevolutionsPowerShell"),icon:"dvl-icon-logo-hub-cli",command:()=>window.open("https://redirection.devolutions.com/Devolutions.PowerShell","_blank")},{label:this.translateService.translate("DevolutionsGateway"),icon:"dvl-icon-logo-gateway",command:()=>window.open("https://redirection.devolutions.com/ea6ea152-743a-4025-b358-ce9b5debc910","_blank")},{label:this.translateService.translate("lblApiDocumentation"),icon:"dvl-icon-documentation-group-2",link:"/api-documentation"},{label:"im the design system",icon:"dvl-icon-tools",link:"/ui/design-system",condition:()=>this.serverInformationService.isFeatureFlagEnabled("designSystem")}]},{label:this.translateService.translate("lblSupportCenter"),items:[{label:this.translateService.translate("lblDocumentation"),icon:"dvl-icon-logo-knowledge-base",command:()=>window.open("https://docs.devolutions.net/server/overview/devolutions-server","_blank")},{label:this.translateService.translate("lblForum"),icon:"dvl-icon-logo-forum",command:()=>window.open("https://redirection.devolutions.com/forum-dvls","_blank")},{label:this.translateService.translate("lblTipsAndTricks"),icon:"dvl-icon-tools",command:()=>window.open("https://redirection.devolutions.com/f230985a-67cd-433e-894f-8885786cec67","_blank")}]},{label:this.translateService.translate("lblReleaseNews"),items:[{label:this.translateService.translate("lblReleaseNotes"),icon:"dvl-icon-new-year",command:()=>this.showWhatsNewDashboard("releaseNotes")},{label:this.translateService.translate("lblWhatsNew"),icon:"dvl-icon-news",command:()=>this.showWhatsNewDashboard("whatsNews")},{label:this.translateService.translate("lblProductInsights"),icon:"dvl-icon-idea",command:()=>this.showWhatsNewDashboard("productInsights")}]},{label:this.translateService.translate("lblHowTos"),items:[{label:this.translateService.translate("lblOnboarding"),icon:"dvl-icon-onboarding-wizard",command:()=>this.onboardingService.toggleOnboarding(),condition:()=>this.hasAccessToOnBoarding}]}]}getComponentTitle(){return"lblHelpAndTools"}showWhatsNewDashboard(t){this.whatsNewService.toggleWhatsNew(!0,t)}};e.\u0275fac=function(n){return new(n||e)},e.\u0275cmp=l({type:e,selectors:[["ng-component"]],decls:2,vars:1,consts:[["titlePage","lblHelpAndTools"],[3,"sections"]],template:function(n,S){n&1&&(c(0,"dvl-page-wrapper-v2",0),m(1,"dvl-menu-dashboard",1),d()),n&2&&(a(),r("sections",S.sections))},dependencies:[u,g],encapsulation:2});let i=e;return i})()});C();export{j as ToolsDashboardComponent};
