import{b as l,c as f}from"./chunk-YBNTOQCK.js";import{Jb as n,Sa as u,Tb as o,be as h,g as s,ia as a,na as c}from"./chunk-WL5U2YIT.js";import{e as p}from"./chunk-ADEKKGI2.js";var O,m=p(()=>{c();u();h();f();O=(()=>{let r=class r{constructor(t){this.translatorService=t,this.destroy$=new s,this.translatorService.updatedLang$.pipe(a(this.destroy$)).subscribe(()=>{this.translate()})}ngOnDestroy(){this.destroy$.next()}transform(t){return this.defaultOptions=JSON.parse(JSON.stringify(t)),this.options=t,this.translate()}translate(){return this.options?this.options.map(t=>(Object.prototype.hasOwnProperty.call(t,"label")&&(t.label=this.translatorService.translate(this.defaultOptions.find(i=>i.value===t.value).label)),t)):[]}};r.\u0275fac=function(i){return new(i||r)(n(l,16))},r.\u0275pipe=o({name:"translateOptions",type:r,pure:!0});let e=r;return e})()});export{O as a,m as b};
