import{q as m,r as C}from"./chunk-SM7EQ7ST.js";import{a as p,b as M}from"./chunk-QGVT6DPT.js";import{Jb as c,Qb as l,Ub as g,Xc as o,be as v,jd as h,xc as s,yb as i,yc as b,zc as d}from"./chunk-WL5U2YIT.js";import{e as u}from"./chunk-ADEKKGI2.js";var k,O=u(()=>{M();v();C();k=(()=>{let r=class r extends p{constructor(t){super(),this.themeService=t}ngOnInit(){this.theme=this.themeService.currentTheme==="light"?"light":"dark"}};r.\u0275fac=function(e){return new(e||r)(c(m))},r.\u0275cmp=l({type:r,selectors:[["dvls-risk-level"]],inputs:{riskLevel:"riskLevel"},features:[g],decls:5,vars:5,consts:[[1,"bar","high"],[1,"bar","mid"],[1,"bar","low"]],template:function(e,a){e&1&&(s(0,"div")(1,"div"),d(2,"span",0)(3,"span",1)(4,"span",2),b()()),e&2&&(o(a.theme),i(),o(h("bars ",a.riskLevel)))},styles:["*[_ngcontent-%COMP%]{box-sizing:border-box}.light[_ngcontent-%COMP%], .dark[_ngcontent-%COMP%]{display:inline-block;padding:5px;margin-right:15px}.light[_ngcontent-%COMP%]{--neutral-color: 0, 0, 0;--border-color-tertiary: rgba(var(--neutral-color), .08);--bars-background-color: rgba(var(--neutral-color), .05);--bar-border-color: var(--border-color-tertiary);--bar-background-color: rgba(var(--neutral-color), .02)}.dark[_ngcontent-%COMP%]{--neutral-color: 255, 255, 255;--bars-background-color: rgba(var(--neutral-color), .15);--bar-border-color: var(--border-color-tertiary);--border-color-tertiary: rgba(var(--neutral-color), .1)}.bars[_ngcontent-%COMP%]{width:26px;height:26px;--bar-height: 6px;background:var(--bars-background-color);padding:3px 5px;border-radius:4px;display:flex;justify-content:space-between;align-items:flex-end;flex-direction:row-reverse}.bars.is-low[_ngcontent-%COMP%]   .low[_ngcontent-%COMP%], .bars.is-low[_ngcontent-%COMP%]   .low[_ngcontent-%COMP%] ~ .bar[_ngcontent-%COMP%]{--bar-background-color: #fde400}.bars.is-medium[_ngcontent-%COMP%]   .mid[_ngcontent-%COMP%], .bars.is-medium[_ngcontent-%COMP%]   .mid[_ngcontent-%COMP%] ~ .bar[_ngcontent-%COMP%]{--bar-background-color: #fd8900}.bars.is-high[_ngcontent-%COMP%]   .high[_ngcontent-%COMP%], .bars.is-high[_ngcontent-%COMP%]   .high[_ngcontent-%COMP%] ~ .bar[_ngcontent-%COMP%]{--bar-background-color: #fd0f00}.bar[_ngcontent-%COMP%]{width:4px;background-color:var(--bar-background-color);border:2px solid var(--bar-border-color);border-radius:2px}.bar.low[_ngcontent-%COMP%]{height:var(--bar-height)}.bar.mid[_ngcontent-%COMP%]{height:calc(var(--bar-height) * 2)}.bar.high[_ngcontent-%COMP%]{height:calc(var(--bar-height) * 3)}"]});let n=r;return n})()});export{k as a,O as b};
