import{a as n,b as e}from"./chunk-4DX65HLL.js";import"./chunk-Q2CF2JQV.js";import"./chunk-LCZQRCKX.js";import"./chunk-MFW36WEU.js";import"./chunk-7PFZXDIW.js";import"./chunk-YKFXM3J7.js";import"./chunk-AVRBEEAA.js";import"./chunk-4ERZBM5I.js";import"./chunk-DJ546A6R.js";import"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import"./chunk-WL5U2YIT.js";import{e as t}from"./chunk-ADEKKGI2.js";var m,p=t(()=>{e();m=[{path:":repositoryId/:connectionId",canActivate:[n],loadComponent:()=>import("./chunk-42ESVCCK.js").then(o=>o.WebClientComponent),children:[{path:":sessionId",loadComponent:()=>import("./chunk-RPT56CYT.js").then(o=>o.WebClientPlaceholderComponent)},{path:"ard",loadComponent:()=>import("./chunk-UXEO7IDS.js").then(o=>o.WebClientArdComponent)},{path:"rdp",loadComponent:()=>import("./chunk-RE2PWLQ3.js").then(o=>o.WebClientRdpComponent)},{path:"vnc",loadComponent:()=>import("./chunk-JMNWJ6CI.js").then(o=>o.WebClientVncComponent)},{path:"ssh",loadComponent:()=>import("./chunk-GYKFDZKX.js").then(o=>o.WebClientSshShellComponent)},{path:"telnet",loadComponent:()=>import("./chunk-RZRNV434.js").then(o=>o.WebClientTelnetComponent)},{path:"powershell",loadComponent:()=>import("./chunk-N3WAVJCQ.js").then(o=>o.WebClientPowerShellComponent)}]}]});p();export{m as WEB_CLIENT_ROUTES};
