import{j as a,k as V,l as p,m as A,n as g,o as F}from"./chunk-I7GW4F3B.js";import{a as o,b as y}from"./chunk-AJ7ODGYR.js";import{m as l,q as v}from"./chunk-HTXYTVN4.js";import{b as m,c as H}from"./chunk-YBNTOQCK.js";import{be as R,ta as c,xa as i}from"./chunk-WL5U2YIT.js";import{e as C,f as U,h as j}from"./chunk-ADEKKGI2.js";var h=U(($,f)=>{var L=["login","login-success","message"];f.exports=L});var b,k,T=C(()=>{y();V();b=j(h());H();R();v();F();A();k=(()=>{let s=class s extends m{constructor(t,e,r){super(t,e),this.baseUrlService=r}translate(t,e){return e!==null?super.translate(t,this.escapeValuesToInclude(e)):super.translate(t)}getTranslationUrl(){let t=this.storageService.get().culture,e=a.getLanguageFilename(a.fromValue(t)),r="./assets/translations/",u=this.baseUrlService.getCurrentRoute().substring(1);return b.indexOf(u)>-1&&(r="./assets/translations",r+=`${this.baseUrlService.getCurrentRoute()}/`),`${r+o.i18nPath+e}.json`}getCustomTranslationUrl(){let t=["fr","de","en_US"],e=this.storageService.get().culture,r=a.getLanguageFilename(a.fromValue(e));return t.some(S=>S===r)||(r="en_US"),`${"./assets/translations/custom/"+o.i18nPath+r}.json`}escapeHtmlTags(t){return t.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/"/g,"&quot;").replace(/'/g,"&#039;")}escapeValuesToInclude(t){return t&&(Array.isArray(t)?t.map(e=>typeof e=="string"?this.escapeHtmlTags(e):e):typeof t=="string"?this.escapeHtmlTags(t):t)}};s.\u0275fac=function(e){return new(e||s)(i(l),i(g),i(p))},s.\u0275prov=c({token:s,factory:s.\u0275fac,providedIn:"root"});let n=s;return n})()});export{k as a,T as b};
