import{a as M,b as O,c as S}from"./chunk-Z3FSQ5UV.js";import{a as y,b as I}from"./chunk-QGVT6DPT.js";import{K as B,k as h,q as P}from"./chunk-LDWBA6DZ.js";import{Jc as l,Qb as C,Ub as z,Uc as f,Xa as b,Xc as x,be as A,jd as p,mc as o,oc as r,qd as _,tb as u,tc as d,uc as v,vc as m,wc as c,yb as n}from"./chunk-WL5U2YIT.js";import{e as w}from"./chunk-ADEKKGI2.js";function k(a,e){if(a&1&&c(0,"ngx-avatars",1),a&2){let i=l();d("name",i.name)("size",i.avatarSize)("textSizeRatio",2.25)("initialsSize",3)}}function T(a,e){a&1&&c(0,"i",2)}function F(a,e){if(a&1&&(v(0,"span",3),c(1,"img",6),m()),a&2){let i=l();n(),d("src",p("data:image/png;base64,",i.imageBytes),u)}}function D(a,e){if(a&1&&c(0,"i",7),a&2){let i=l();x(p("repo-icon di dvl-icon-",i.imageIcon.icon)),d("ngStyle",_(4,V,i.imageIcon.color))}}function E(a,e){if(a&1&&(v(0,"div",5),c(1,"i",8)(2,"i",9),m()),a&2){let i=l();d("ngClass",i.size)}}var V,q,H=w(()=>{I();S();B();A();S();V=a=>({color:a});q=(()=>{let e=class e extends y{constructor(){super(...arguments),this.isPam=!1,this.isPrivate=!1,this.avatarSize=28}get cssAvatarSize(){return`${this.avatarSize}px`}};e.\u0275fac=(()=>{let g;return function(t){return(g||(g=b(e)))(t||e)}})(),e.\u0275cmp=C({type:e,selectors:[["dvls-vault-avatar"]],hostVars:2,hostBindings:function(s,t){s&2&&f("--avatar-size",t.cssAvatarSize)},inputs:{imageIcon:"imageIcon",imageBytes:"imageBytes",isPam:"isPam",isPrivate:"isPrivate",name:"name",avatarSize:"avatarSize",size:"size"},features:[z],decls:6,vars:5,consts:[[1,"avatar-container"],[3,"name","size","textSizeRatio","initialsSize"],[1,"repo-private-icon","di","dvl-icon-user-vault"],[1,"repo-custom-image-container"],[3,"class","ngStyle"],[1,"avatar-badge",3,"ngClass"],["alt","",1,"repo-custom-image",3,"src"],[3,"ngStyle"],[1,"avatar-badge-icon","avatar-badge-border","di","dvl-icon-pam"],[1,"avatar-badge-icon","di","dvl-icon-pam"]],template:function(s,t){s&1&&(v(0,"div",0),o(1,k,1,4,"ngx-avatars",1),o(2,T,1,0,"i",2),o(3,F,2,2,"span",3),o(4,D,1,6,"i",4),o(5,E,3,1,"div",5),m()),s&2&&(n(),r(!t.isPrivate&&!t.imageBytes&&!t.imageIcon?1:-1),n(),r(t.isPrivate?2:-1),n(),r(t.imageBytes?3:-1),n(),r(t.imageIcon?4:-1),n(),r(t.isPam?5:-1))},dependencies:[O,M,P,h],styles:['[_nghost-%COMP%]{--badge-icon-size: 16px;--badge-border-width: 4px}.tiny[_ngcontent-%COMP%]{--badge-icon-size: 10px;--badge-border-width: 3px}.small[_ngcontent-%COMP%]{--badge-icon-size: 15px}.medium[_ngcontent-%COMP%]{--badge-icon-size: 16px}.repo-custom-image-container[_ngcontent-%COMP%]{display:flex;align-items:center;justify-content:center;width:var(--avatar-size, 28px);height:var(--avatar-size, 28px)}.repo-custom-image[_ngcontent-%COMP%]{max-width:var(--avatar-size, 28px);max-height:var(--avatar-size, 28px)}.repo-icon[_ngcontent-%COMP%]{font-size:var(--avatar-size, 28px)}.avatar-container[_ngcontent-%COMP%]{position:relative;display:inline-block}.avatar-badge-icon[_ngcontent-%COMP%]{font-size:var(--badge-icon-size)}.avatar-badge[_ngcontent-%COMP%]{position:absolute;bottom:calc(var(--badge-border-width) * -1);right:calc(var(--badge-border-width) * -1);color:rgb(var(--base-color-rgb))}.avatar-badge[_ngcontent-%COMP%], .avatar-badge-icon[_ngcontent-%COMP%]{width:var(--badge-icon-size);height:var(--badge-icon-size)}.avatar-badge-icon[_ngcontent-%COMP%]:not(.avatar-badge-border){width:calc(var(--badge-icon-size) - var(--badge-border-width));height:calc(var(--badge-icon-size) - var(--badge-border-width));font-size:calc(var(--badge-icon-size) - var(--badge-border-width))}.avatar-badge-icon[_ngcontent-%COMP%]{transform:translate(-50%,-50%);font-size:var(--badge-icon-size);position:absolute;top:50%;left:50%}.avatar-badge-border[_ngcontent-%COMP%]{color:var(--side-panel-background-color)}.avatar-badge-border.dvl-icon-role-owner[_ngcontent-%COMP%], .avatar-badge-border.dvl-icon-role-admin[_ngcontent-%COMP%]{text-shadow:0 -2px 0 var(--side-panel-background-color),0 -1px var(--side-panel-background-color)}.avatar-badge-border.dvl-icon-pam[_ngcontent-%COMP%]:after{width:calc(var(--badge-icon-size) - 5px);height:calc(var(--badge-icon-size) - 5px);position:absolute;inset:0;margin:auto;background-color:var(--side-panel-background-color);border-radius:50%;content:""}']});let a=e;return a})()});export{q as a,H as b};
