import{be as l,g as r,na as c,ta as o}from"./chunk-WL5U2YIT.js";import{e as a}from"./chunk-ADEKKGI2.js";var h,n=a(()=>{c();l();h=(()=>{let e=class e{constructor(){this.visibleRequestSource=new r,this.dialogErrorSource=new r,this.visibleRequest=this.visibleRequestSource.asObservable(),this.dialogError=this.dialogErrorSource.asObservable()}toggleDialog(){this.visibleRequestSource.next()}sendValue(i){this.dialogErrorSource.next(i),this.toggleDialog()}};e.\u0275fac=function(s){return new(s||e)},e.\u0275prov=o({token:e,factory:e.\u0275fac,providedIn:"root"});let t=e;return t})()});export{h as a,n as b};
