import{a as o,b as n}from"./chunk-VT6VEUJB.js";import{a as t,b as m}from"./chunk-4DX65HLL.js";import"./chunk-Q2CF2JQV.js";import"./chunk-LCZQRCKX.js";import"./chunk-MFW36WEU.js";import"./chunk-7PFZXDIW.js";import"./chunk-YKFXM3J7.js";import"./chunk-AVRBEEAA.js";import"./chunk-4ERZBM5I.js";import"./chunk-DJ546A6R.js";import"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import"./chunk-WL5U2YIT.js";import{e as a}from"./chunk-ADEKKGI2.js";var i,p=a(()=>{m();n();i=[{path:"",canActivate:[t,o],children:[{path:"",loadComponent:()=>import("./chunk-VZDK4FYD.js").then(r=>r.CheckoutListComponent)}]}]});p();export{i as CHECKOUT_ROUTES};
