import{a as c,b as f}from"./chunk-3E7FAEEN.js";import"./chunk-A22EQSF3.js";import"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import{C as p,I as d}from"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import{Qb as o,Ub as i,be as a,uc as r,vc as s,wc as l}from"./chunk-WL5U2YIT.js";import{e as u}from"./chunk-ADEKKGI2.js";var v,g=u(()=>{f();d();a();v=(()=>{let e=class e extends c{constructor(){super()}getComponentTitle(){return"lblConfiguration"}};e.\u0275fac=function(n){return new(n||e)},e.\u0275cmp=o({type:e,selectors:[["ng-component"]],features:[i],decls:2,vars:0,consts:[[1,"full-height","full-width"]],template:function(n,h){n&1&&(r(0,"div",0),l(1,"router-outlet"),s())},dependencies:[p],styles:["[_nghost-%COMP%]   ul[_ngcontent-%COMP%]{list-style-type:none;padding:0}[_nghost-%COMP%]   .page-content[_ngcontent-%COMP%]{width:82%;display:flex}"]});let t=e;return t})()});g();export{v as ConfigurationComponent};
