import{a as v,b as k}from"./chunk-6YYTBF6E.js";import{a as f,b as C}from"./chunk-ERBABQHD.js";import"./chunk-AQH4BMGD.js";import"./chunk-ZVUXF5PM.js";import{a as u,b as T}from"./chunk-4CERJ67S.js";import"./chunk-OGIVSRCZ.js";import"./chunk-3E7FAEEN.js";import"./chunk-GPOUKG47.js";import"./chunk-FRJ6A5YK.js";import"./chunk-A22EQSF3.js";import"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-6POW7SSJ.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import"./chunk-HTXYTVN4.js";import{b,c as g}from"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import{Jb as a,Qb as l,Ub as c,be as S,tc as o,uc as p,vc as m,wc as d,yb as r}from"./chunk-WL5U2YIT.js";import{e as h}from"./chunk-ADEKKGI2.js";var w,y=h(()=>{T();C();k();S();g();w=(()=>{let e=class e extends u{constructor(i){super(),this.translateService=i,this.titleHeader=[{title:"lblAdministration",link:"/administration"},{title:"lblNotifications"}],this.sections=[]}ngOnInit(){super.ngOnInit(),this.createSectionsTemplate();let i=this.sectionsTemplate.filter(t=>t.items.some(n=>n.condition()));i.forEach(t=>t.items=t.items.filter(n=>n.condition())),this.sections=i}getComponentTitle(){return"lblNotifications"}createSectionsTemplate(){this.sectionsTemplate=[{label:this.translateService.translate("lblNotifications"),items:[{label:this.translateService.translate("lblSubscribers"),icon:"dvl-icon-notifications-subscriber",link:"subscribers",condition:()=>!0},{label:this.translateService.translate("lblSubscriberGroups"),icon:"dvl-icon-notifications-subscriber-group",link:"groups",condition:()=>!0},{label:this.translateService.translate("lblSubscriptions"),icon:"dvl-icon-notifications-bold",link:"subscriptions",condition:()=>!0},{label:this.translateService.translate("lblUserSubscriptions"),icon:"dvl-icon-user-bold",link:"user-subscriptions",condition:()=>!0}]}]}};e.\u0275fac=function(t){return new(t||e)(a(b))},e.\u0275cmp=l({type:e,selectors:[["ng-component"]],features:[c],decls:2,vars:2,consts:[[3,"titlePage"],[3,"sections"]],template:function(t,n){t&1&&(p(0,"dvl-page-wrapper-v2",0),d(1,"dvl-menu-dashboard",1),m()),t&2&&(o("titlePage",n.titleHeader),r(),o("sections",n.sections))},dependencies:[f,v],encapsulation:2});let s=e;return s})()});y();export{w as NotificationsDashboardComponent};
