import{a as c,b as l}from"./chunk-AJ7ODGYR.js";import{D as s,I as p}from"./chunk-HTXYTVN4.js";import{be as u,ta as n,xa as a}from"./chunk-WL5U2YIT.js";import{e as m}from"./chunk-ADEKKGI2.js";var y,h=m(()=>{l();u();p();y=(()=>{let t=class t{constructor(r){this.router=r}navigateToDocumentation(r,o=null,f=!1){let i=`${c.location}connections/documentation/${r}`;f?(o&&(i+=`?page=${o}`),window.open(i)):this.router.navigate([i],{queryParams:{page:o}})}};t.\u0275fac=function(o){return new(o||t)(a(s))},t.\u0275prov=n({token:t,factory:t.\u0275fac,providedIn:"root"});let e=t;return e})()});export{y as a,h as b};
