import{D as c,I as l}from"./chunk-HTXYTVN4.js";import{be as h,h as i,na as u,ta as o,xa as a}from"./chunk-WL5U2YIT.js";import{e as s}from"./chunk-ADEKKGI2.js";var p,m=s(()=>{u();h();l();p=(()=>{let t=class t{constructor(e){this.router=e,this.navigationTreeRequest=new i(null),this.currentPamAccountSubject=new i(null),this.navigationTree=this.navigationTreeRequest.asObservable(),this.currentPamAccount=this.currentPamAccountSubject.asObservable()}navigateTree(e){this.navigationTreeRequest.next(e)}navigateToPamEntry(e,n=null){this.router.navigateByUrl(`connections/${e}/${n??e}`)}};t.\u0275fac=function(n){return new(n||t)(a(c))},t.\u0275prov=o({token:t,factory:t.\u0275fac,providedIn:"root"});let r=t;return r})()});export{p as a,m as b};
