import{d as C,e as A,i as F,j as G}from"./chunk-AGRQYW7D.js";import{Ia as r,La as S}from"./chunk-5E3JCGAH.js";import{B as h,K as B}from"./chunk-LDWBA6DZ.js";import{Kc as f,Lc as y,Qb as p,Rb as u,Ub as c,Vc as m,Wc as g,Xa as i,Xc as M,be as I,jc as l,od as v,ta as s,ua as a,ya as d}from"./chunk-WL5U2YIT.js";import{e as j}from"./chunk-ADEKKGI2.js";var b,x,D,H,O,N=j(()=>{B();I();I();S();G();A();b=["*"],x={root:"p-inputgroupaddon"},D=(()=>{class e extends C{name="inputgroupaddon";classes=x;static \u0275fac=(()=>{let t;return function(o){return(t||(t=i(e)))(o||e)}})();static \u0275prov=s({token:e,factory:e.\u0275fac})}return e})(),H=(()=>{class e extends F{style;styleClass;_componentStyle=d(D);get hostStyle(){return this.style}static \u0275fac=(()=>{let t;return function(o){return(t||(t=i(e)))(o||e)}})();static \u0275cmp=p({type:e,selectors:[["p-inputgroup-addon"],["p-inputGroupAddon"]],hostVars:7,hostBindings:function(n,o){n&2&&(l("data-pc-name","inputgroupaddon"),g(o.hostStyle),M(o.styleClass),m("p-inputgroupaddon",!0))},inputs:{style:"style",styleClass:"styleClass"},features:[v([D]),c],ngContentSelectors:b,decls:1,vars:0,template:function(n,o){n&1&&(f(),y(0))},dependencies:[h],encapsulation:2})}return e})(),O=(()=>{class e{static \u0275fac=function(n){return new(n||e)};static \u0275mod=u({type:e});static \u0275inj=a({imports:[H,r,r]})}return e})()});export{H as a,O as b,N as c};
