import{j as F,k as P}from"./chunk-6PLZSWB7.js";import{a as B,b as O,f as E}from"./chunk-DFU4A362.js";import{a as x,b as N}from"./chunk-6POW7SSJ.js";import{cb as V,zb as M}from"./chunk-V2ECYACM.js";import{Ad as r,Dc as _,Ea as d,Fa as m,Hc as f,Pd as b,Qb as w,Rc as h,Sc as S,Yc as v,_c as g,be as D,tc as p,uc as i,vc as l,wc as y,ya as s,yb as t,zd as o}from"./chunk-WL5U2YIT.js";import{e as I}from"./chunk-ADEKKGI2.js";var T,G,Q=I(()=>{D();E();N();P();M();D();T=["footer"],G=(()=>{let n=class n{constructor(){this.ref=s(O,{optional:!0}),this.config=s(B,{optional:!0}),this.licensesService=s(F),this.footerInstance=b.required("footer")}onContactSales(){this.licensesService.openContactSalesWindow(),this.ref?.close(null)}onClose(){this.ref?.close(null)}};n.\u0275fac=function(e){return new(e||n)},n.\u0275cmp=w({type:n,selectors:[["dvls-now-on-free-version-dialog"]],viewQuery:function(e,a){e&1&&h(a.footerInstance,T,5),e&2&&S()},decls:16,vars:15,consts:[["footer",""],[1,"now-on-free-version-dialog-content"],["src","./assets/images/maurice-transparent.png",1,"h-[150px]","mx-auto",3,"alt"],[1,"now-on-free-version-message"],[1,"p-dialog-footer"],[2,"margin-right","auto"],["variant","secondary",3,"onClick","label"]],template:function(e,a){if(e&1){let C=_();i(0,"div",1),y(1,"img",2),o(2,"translate"),i(3,"p",3),v(4),o(5,"translate"),l(),i(6,"p",3),v(7),o(8,"translate"),l()(),i(9,"div",4,0)(11,"div",5)(12,"dvl-button",6),o(13,"translate"),f("onClick",function(){return d(C),m(a.onContactSales())}),l()(),i(14,"dvl-button",6),o(15,"translate"),f("onClick",function(){return d(C),m(a.onClose())}),l()()}e&2&&(t(),p("alt",r(2,5,"lblIllustration")),t(3),g(" ",r(5,7,"lblNowOnFreeVersionBody1")," "),t(3),g(" ",r(8,9,"lblNowOnFreeVersionBody2")," "),t(5),p("label",r(13,11,"lblContactSales")),t(2),p("label",r(15,13,"lblClose")))},dependencies:[V,x],styles:[".now-on-free-version-dialog-content[_ngcontent-%COMP%]{padding:1rem 0;text-align:center}.now-on-free-version-dialog-content[_ngcontent-%COMP%]   .now-on-free-version-message[_ngcontent-%COMP%]{margin:0 0 16px;line-height:1.5}"]});let c=n;return c})()});export{G as a,Q as b};
