import{Da as n,La as d}from"./chunk-5E3JCGAH.js";import{b as c,c as u}from"./chunk-YBNTOQCK.js";import{be as f,ta as a,xa as r}from"./chunk-WL5U2YIT.js";import{e as l}from"./chunk-ADEKKGI2.js";var S,h=l(()=>{f();d();u();S=(()=>{let s=class s{constructor(t,e){this.toastService=t,this.translationService=e}successfulOperation(t,e){this.feedback("success",t,e)}failedOperation(t,e){this.feedback("error",t,e)}feedback(t,e,i){this.toastService.add({key:"globalToast",severity:t,summary:e,detail:i,closable:!0})}testConnectionFeedback(t,e,i){t?this.testConnectionSuccessful(e,i):this.testConnectionFailed(e,i)}testConnectionSuccessful(t,e){let i=this.translationService.translate("ConnectionSuccessful");t&&(i=`${t} ${i}`),this.successfulOperation(i,e)}testConnectionFailed(t,e){let i=this.translationService.translate("ConnectionFailed");t&&(i=`${t} ${i}`),this.failedOperation(i,e)}};s.\u0275fac=function(e){return new(e||s)(r(n),r(c))},s.\u0275prov=a({token:s,factory:s.\u0275fac,providedIn:"root"});let o=s;return o})()});export{S as a,h as b};
