import{be as a,g as s,na as u,ta as i}from"./chunk-WL5U2YIT.js";import{e as o}from"./chunk-ADEKKGI2.js";var q,n=o(()=>{u();a();q=(()=>{let e=class e{constructor(){this.editRequestSource=new s,this.createRequestSource=new s,this.editRequest=this.editRequestSource.asObservable(),this.createRequest=this.createRequestSource.asObservable()}edit(t){return this.editRequestSource.next(t),this}create(t){return this.createRequestSource.next(t),this}};e.\u0275fac=function(c){return new(c||e)},e.\u0275prov=i({token:e,factory:e.\u0275fac,providedIn:"root"});let r=e;return r})()});export{q as a,n as b};
