import{c as d,d as I}from"./chunk-DUQZGOF7.js";import{D as p,E as U}from"./chunk-I7GW4F3B.js";import{J as m,Sa as f,T as n,be as u,ta as o,x as c,xa as s}from"./chunk-WL5U2YIT.js";import{e as a}from"./chunk-ADEKKGI2.js";var v,l=a(()=>{f();u();U();v=(()=>{let r=class r{constructor(t){this.currentUserService=t}getCurrentUser(){return this.currentUserService.currentUserChanged.pipe(m(t=>!!t),n(1),c(t=>({id:this.currentUserService.currentUserId,name:t.userName,isAdministrator:this.currentUserService.isAdministrator})))}};r.\u0275fac=function(i){return new(i||r)(s(p))},r.\u0275prov=o({token:r,factory:r.\u0275fac,providedIn:"root"});let e=r;return e})()});var C,S=a(()=>{u();l();C=(()=>{let r=class r{constructor(t){this.dpsCurrentUserService=t}resolve(t,i){return this.dpsCurrentUserService.getCurrentUser()}};r.\u0275fac=function(i){return new(i||r)(s(v))},r.\u0275prov=o({token:r,factory:r.\u0275fac,providedIn:"root"});let e=r;return e})()});var F,b=a(()=>{f();u();I();F=(()=>{let r=class r{constructor(t){this.userService=t}resolve(t){return this.userService.getUserSummaries().pipe(n(1),c(()=>!0))}};r.\u0275fac=function(i){return new(i||r)(s(d))},r.\u0275prov=o({token:r,factory:r.\u0275fac,providedIn:"root"});let e=r;return e})()});export{C as a,S as b,F as c,b as d};
