import{be as a,ta as e}from"./chunk-WL5U2YIT.js";import{e as i}from"./chunk-ADEKKGI2.js";var s,c=i(()=>{a();s=(()=>{let t=class t{};t.\u0275fac=function(o){return new(o||t)},t.\u0275prov=e({token:t,factory:t.\u0275fac,providedIn:"root"});let r=t;return r})()});export{s as a,c as b};
