import{a as X,b as re}from"./chunk-6XELTT3Q.js";import{a as Q,b as te}from"./chunk-4EHH4FUQ.js";import{a as K,b as ie}from"./chunk-6POW7SSJ.js";import{q as U,r as z,s as J}from"./chunk-V2ECYACM.js";import{C as k,E as G,a as A,b as D,f as P,i as O,m as L,w as W,y as j}from"./chunk-JPHJ3OD7.js";import{b as H,c as ee}from"./chunk-YBNTOQCK.js";import{Ad as p,Dc as V,Ea as h,Fa as f,Hc as y,Jb as v,Qb as E,Tc as q,Vc as I,Xc as x,Yc as m,Zc as F,_c as b,b as c,be as B,cd as S,dd as w,ed as R,jc as _,mc as g,na as $,oc as C,od as N,sa as T,tc as M,uc as o,vc as s,yb as n,zd as u}from"./chunk-WL5U2YIT.js";import{e as Z}from"./chunk-ADEKKGI2.js";function ae(r,a){r&1&&(o(0,"div",3),m(1),u(2,"translate"),s()),r&2&&(n(),b(" ",p(2,1,"TheEmailIsInvalid")," "))}function ne(r,a){r&1&&(o(0,"div",3),m(1),u(2,"translate"),s()),r&2&&(n(),b(" ",p(2,1,"TheEmailIsRequired")," "))}var Te,le=Z(()=>{B();G();$();J();re();ie();te();B();G();ee();J();Te=(()=>{let a=class a{constructor(e,l){this.translatorService=l,this.labelName="lblEmail",this.isRequired=!1,this.styleClass="",this.disabled=!1,this.maxlength=null,this.autoFocus=!1,this.placeholder="",this.invalidCharacterMessage=this.translatorService.translate("TheNameCanNotContainsTheInvalidCharacter","\\"),this.innerValue="",this.onModelChange=c,this.onModelTouched=c,this.parent=e}get value(){return this.innerValue}set value(e){e!==null&&e!==this.innerValue&&(this.writeValue(e),this.onModelChange(e))}isFormSubmitted(){return this.parent.submitted}onInputBlur(e){this.onModelTouched()}registerOnChange(e){this.onModelChange=e}registerOnTouched(e){this.onModelTouched=e}writeValue(e){this.innerValue=e}};a.\u0275fac=function(l){return new(l||a)(v(O,9),v(H))},a.\u0275cmp=E({type:a,selectors:[["sd-input-email"]],inputs:{labelName:"labelName",isRequired:"isRequired",styleClass:"styleClass",disabled:"disabled",maxlength:"maxlength",autoFocus:"autoFocus",placeholder:"placeholder",value:"value"},features:[N([{provide:A,useExisting:T(()=>a),multi:!0}])],decls:9,vars:20,consts:[["emailModel","ngModel"],[1,"block","text-xs","font-normal","py-1.5","pr-[3px]","text-left","text-[var(--text-400)]"],["pInputText","","name","email","sdValidateEmail","","sdAutoFocusInput","",3,"ngModelChange","blur","disabled","required","ngModel","maxlength","autoFocus","placeholder"],[1,"dvl-form-error"]],template:function(l,t){if(l&1){let i=V();o(0,"div"),u(1,"translate"),o(2,"label",1),m(3),u(4,"translate"),s(),o(5,"input",2,0),R("ngModelChange",function(d){return h(i),w(t.value,d)||(t.value=d),f(d)}),y("blur",function(d){return h(i),f(t.onInputBlur(d))}),s(),g(7,ae,3,3,"div",3),g(8,ne,3,3,"div",3),s()}if(l&2){let i=q(6);I("form-error",i.errors&&i.errors.email||i.invalid),_("data-error",i.errors&&i.errors.email?p(1,16,"TheEmailIsRequired"):t.invalidCharacterMessage),n(2),I("required",t.isRequired),n(),F(p(4,18,t.labelName)),n(2),x(t.styleClass),M("disabled",t.disabled)("required",t.isRequired),S("ngModel",t.value),M("maxlength",t.maxlength)("autoFocus",t.autoFocus)("placeholder",t.placeholder),n(2),C(i.errors&&i.errors.email?7:-1),n(),C(t.isRequired&&i.invalid&&(i.dirty||i.touched)&&(i!=null&&i.errors.required)?8:-1)}},dependencies:[k,D,P,W,j,L,z,U,X,Q,K],encapsulation:2});let r=a;return r})()});export{Te as a,le as b};
