import{a as r,b as m}from"./chunk-JFZLN2FV.js";import{Jb as c,Sb as u,Za as s,be as l,o,p as f}from"./chunk-WL5U2YIT.js";import{e as a}from"./chunk-ADEKKGI2.js";var t,e,p=a(()=>{f();m();l();t=class t{constructor(i){this.el=i,this.autoFocus=!0}ngAfterViewInit(){this.autoFocus&&this.focusInput()}focusInput(){this.el.nativeElement.focus(),this.autoSelect&&this.el.nativeElement.select()}};t.\u0275fac=function(n){return new(n||t)(c(s))},t.\u0275dir=u({type:t,selectors:[["","sdAutoFocusInput",""]],inputs:{autoFocus:"autoFocus",autoSelect:"autoSelect"}});e=t;o([r()],e.prototype,"focusInput",null)});export{e as a,p as b};
