import{ij as i,jj as B}from"./chunk-BPZQKZKD.js";import{be as a,ta as u}from"./chunk-WL5U2YIT.js";import{e}from"./chunk-ADEKKGI2.js";var o,r=e(()=>{o=(()=>{let t=class t{toQueryString(){return""}constructor(s=null){this.clone=()=>new t(this)}};t.connectionStatusArchivedID="{333FB448-F180-448E-BE46-4773AD0F1679}",t.connectionStatusBrokenID="{3B07FDA8-FF2A-428B-8D96-24D77365A47E}",t.connectionStatusDefaultID="{B299F468-BC24-43cb-9417-4FEDFC813E7C}",t.connectionStatusDisabledID="{380B6ED9-94F9-4e1e-B4F6-72714B9D44CD}",t.connectionStatusExpiredID="{7B926104-9C7E-4c91-BDAC-DFCCC36B8D70}",t.connectionStatusLockedID="{DE4018E0-38E4-416b-AB4E-DEA6B754C711}",t.connectionStatusPendingApprovalID="{6240196F-F8B0-42BA-A256-C5B5B130CE3B}",t.connectionStatusRootEnforceDefaultID="{5E97362E-44C9-4082-B85A-353AC7C3A982}}",t.connectionStatusWarningID="{123A44CB-7EDC-4ecb-926B-031793668148}",t.logStatusDefaultID="{3B6C0824-BB78-4d01-A2C0-00549E9D034A}",t.logStatusNoChargeID="{57228922-D7C5-44b4-9975-53FAA747D3E2}",t.logStatusPaidID="{810D29EC-97BE-45bf-8252-88B8C5DC9B27}",t.logStatusStarredID="{F913F5B7-4022-4802-A726-A9798EE6F8DD}",t.logStatusToBillID="{86A84E83-8B66-4688-BA06-AC079185AEBE}",t.logStatusToVerifyID="{45B108AD-30D5-4516-A3CC-914D5FC148D4}";let c=t;return c})()});var p,E=e(()=>{B();r();a();p=(()=>{let t=class t{constructor(){this.guidToEnumMap=new Map([[o.connectionStatusDefaultID,i.Default],[o.connectionStatusExpiredID,i.Expired],[o.connectionStatusBrokenID,i.Broken],[o.connectionStatusLockedID,i.Locked],[o.connectionStatusDisabledID,i.Disabled],[o.connectionStatusWarningID,i.Warning],[o.connectionStatusArchivedID,i.Archived],[o.connectionStatusPendingApprovalID,i.PendingApproval]])}mapGuidToEnum(s){return this.guidToEnumMap.get(s)??i.Default}mapEnumToGuid(s){return this.enumToGuidMap||(this.enumToGuidMap=new Map(Array.from(this.guidToEnumMap.entries()).map(([D,n])=>[n,D]))),this.enumToGuidMap.get(s)??""}setDefaultStatus(s){return this.mapEnumToGuid(s.value)}getDefaultStatus(s){return this.mapGuidToEnum(s)}};t.\u0275fac=function(D){return new(D||t)},t.\u0275prov=u({token:t,factory:t.\u0275fac,providedIn:"root"});let c=t;return c})()});export{o as a,r as b,p as c,E as d};
