import{a as h,b as x}from"./chunk-SM7EQ7ST.js";import{c as l,d as f}from"./chunk-RWCAFOHA.js";import{Gk as m,Hk as P}from"./chunk-BPZQKZKD.js";import{b as u,c as y}from"./chunk-YBNTOQCK.js";import{O as n,Sa as G,be as d,ka as i,na as v,r,ta as c,x as s,xa as p}from"./chunk-WL5U2YIT.js";import{e as S}from"./chunk-ADEKKGI2.js";var W,A=S(()=>{v();x();G();d();f();y();P();W=(()=>{let o=class o extends h{constructor(t,e,R){super(e,t),this.assetService=R}getDataSourceLogReport(t){return this.assetService.GetDatasourceLogs(t).pipe(i(e=>this.handleGetApiResult(e)),s(e=>this.returnWhenSuccessful(e,()=>e.data)))}exportDataSourceLogReport(t){return this.assetService.GetDatasourceLogsExportFile(t).pipe(s(e=>new Blob([e],{type:"text/csv"})),n(()=>r(null)))}getPasswordAnalyzer(t,e=!1){return this.assetService.GetPasswordStrengthAnalysis(t,e)}getSystemPermissionsReport(t){return this.assetService.GetSystemPermissionsReport(t).pipe(i(e=>this.handleGetApiResult(e)),s(e=>this.returnWhenSuccessful(e,()=>e.data)))}exportSystemPermissionsReport(t){return this.assetService.GetSystemPermissionsReportExport(t).pipe(s(e=>new Blob([e],{type:"text/csv"})),n(()=>r(null)))}getUserCentricGatewayPermissionsReport(t){return this.assetService.GetGatewayPermissionsReport(t).pipe(i(e=>this.handleGetApiResult(e)),s(e=>this.returnWhenSuccessful(e,()=>e.data)))}exportUserCentricGatewayPermissionsReport(t){return this.assetService.GetGatewayPermissionsReportExport(t).pipe(s(e=>new Blob([e],{type:"text/csv"})),n(()=>r(null)))}getAdministratorPermissionsReport(t){return this.assetService.GetAdministratorPermissionsReport(t).pipe(i(e=>this.handleGetApiResult(e)),s(e=>this.returnWhenSuccessful(e,()=>e.data)))}exportAdministratorPermissionsReport(t){return this.assetService.GetAdministratorPermissionsReportExport(t).pipe(s(e=>new Blob([e],{type:"text/csv"})),n(()=>r(null)))}getVaultPermissionsReport(t){return t.repositoryIds.length===0?r(null):this.assetService.GetVaultPermissionsReport(t).pipe(i(e=>this.handleGetApiResult(e)),s(e=>this.returnWhenSuccessful(e,()=>e.data)))}exportVaultPermissionsReport(t){return this.assetService.GetVaultPermissionsReportExport(t).pipe(s(e=>new Blob([e],{type:"text/csv"})),n(()=>r(null)))}getConnectionsPermissionsReport(t){return t.vaultIds.length===0?r(null):this.assetService.GetConnectionsPermissionsReport(t).pipe(i(e=>this.handleGetApiResult(e)),s(e=>this.returnWhenSuccessful(e,()=>e.data)))}exportConnectionsPermissionsReport(t){return this.assetService.GetConnectionsPermissionsReportExport(t).pipe(s(e=>new Blob([e],{type:"text/csv"})),n(()=>r(null)))}getLicenseReport(t){return this.assetService.GetLicenseReport(t).pipe(i(e=>this.handleGetApiResult(e)),s(e=>this.returnWhenSuccessful(e,()=>e.data)))}exportLicenseReport(t){return this.assetService.GetLicenseReportExport(t).pipe(s(e=>new Blob([e],{type:"text/csv"})),n(()=>r(null)))}getLicensesByUsersReport(t){return this.assetService.GetLicensesByUsersReport(t).pipe(i(e=>this.handleGetApiResult(e)),s(e=>this.returnWhenSuccessful(e,()=>e.data)))}getLicensesByUsersLicenseUsers(t){return this.assetService.GetLicensesByUsersLicenseUsers(t).pipe(i(e=>this.handleGetApiResult(e)),s(e=>this.returnWhenSuccessful(e,()=>e.data)))}exportLicensesByUsersReport(t){return this.assetService.GetLicensesByUsersReportExport(t).pipe(s(e=>new Blob([e],{type:"text/csv"})),n(()=>r(null)))}};o.\u0275fac=function(e){return new(e||o)(p(l),p(u),p(m))},o.\u0275prov=c({token:o,factory:o.\u0275fac,providedIn:"root"});let a=o;return a})()});export{W as a,A as b};
