import{a as z,c as Y}from"./chunk-VM2L5ERO.js";import{q as j,r as G,s as U}from"./chunk-V2ECYACM.js";import{C as N,E as K,a as q,b as O,f as D,m as F,w as L}from"./chunk-JPHJ3OD7.js";import{K as X,r as P}from"./chunk-LDWBA6DZ.js";import{Cc as W,Db as d,Dc as h,Ea as a,Fa as s,Fd as k,Hc as M,Jc as r,Kc as A,Lc as B,Qb as v,Tc as R,Uc as C,Vc as x,Wb as T,Xc as f,b as I,be as E,cd as w,dd as y,ed as b,mc as m,na as Q,oc as g,od as S,sa as V,tc as u,uc as c,vc as _,yb as p}from"./chunk-WL5U2YIT.js";import{e as J}from"./chunk-ADEKKGI2.js";function $(o,l){if(o&1){let e=h();c(0,"input",6),b("ngModelChange",function(t){a(e);let i=r();return y(i.value,t)||(i.value=t),s(t)}),M("focus",function(t){a(e);let i=r();return s(i.onFocus(t))})("input",function(t){a(e);let i=r();return s(i.onInput(t))})("keyup",function(t){a(e);let i=r();return s(i.onKeyup(t))})("blur",function(t){a(e);let i=r();return s(i.onBlur(t))}),_()}if(o&2){let e=r();f(e.styleClass),C("border-top-right-radius",e.noBorderRight?"0":null)("border-bottom-right-radius",e.noBorderRight?"0":null),x("dwl-ignore",e.dwlIgnore),u("disabled",e.disabled)("readonly",e.readonly),w("ngModel",e.value)}}function ee(o,l){if(o&1){let e=h();c(0,"input",7),b("ngModelChange",function(t){a(e);let i=r();return y(i.value,t)||(i.value=t),s(t)}),M("focus",function(t){a(e);let i=r();return s(i.onFocus(t))})("input",function(t){a(e);let i=r();return s(i.onInput(t))})("keyup",function(t){a(e);let i=r();return s(i.onKeyup(t))})("blur",function(t){a(e);let i=r();return s(i.onBlur(t))}),_()}if(o&2){let e=r();f(e.styleClass),C("border-top-right-radius",e.noBorderRight?"0":null)("border-bottom-right-radius",e.noBorderRight?"0":null),x("dwl-ignore",e.dwlIgnore),u("disabled",e.disabled)("readonly",e.readonly),w("ngModel",e.value),u("required",e.required)}}function te(o,l){if(o&1){let e=h();c(0,"textarea",8),b("ngModelChange",function(t){a(e);let i=r();return y(i.value,t)||(i.value=t),s(t)}),_()}if(o&2){let e=r();f(e.styleClass),C("border-top-right-radius",e.noBorderRight?"0":null)("border-bottom-right-radius",e.noBorderRight?"0":null),x("dwl-ignore",e.dwlIgnore),u("disabled",e.disabled)("readonly",e.readonly),w("ngModel",e.value)}}function ne(o,l){o&1&&W(0)}function ie(o,l){o&1&&B(0)}var Z,Ce,oe=J(()=>{E();K();Q();X();U();Y();E();U();K();Z=["*"];Ce=(()=>{let l=class l{constructor(){this.required=!1,this.dwlIgnore=!1,this.noBorderRight=!1,this.focus=new d,this.input=new d,this.keyup=new d,this.blur=new d,this.onModelChange=I,this.onModelTouched=I,this._value=""}get value(){return this._value}set value(n){n!==this._value&&(this._value=n,this.onModelChange(this._value))}registerOnChange(n){this.onModelChange=n}registerOnTouched(n){this.onModelTouched=n}setDisabledState(n){}writeValue(n){n!=null&&(this.value=n)}onFocus(n){this.focus.emit(n)}onInput(n){this.input.emit(n)}onKeyup(n){this.keyup.emit(n)}onBlur(n){this.blur.emit(n)}};l.\u0275fac=function(t){return new(t||l)},l.\u0275cmp=v({type:l,selectors:[["dvl-input-with-action"]],inputs:{copyable:"copyable",sensitive:"sensitive",type:"type",readonly:"readonly",disabled:"disabled",styleClass:"styleClass",required:"required",dwlIgnore:"dwlIgnore",noBorderRight:"noBorderRight"},outputs:{focus:"focus",input:"input",keyup:"keyup",blur:"blur"},features:[S([{provide:q,useExisting:V(()=>l),multi:!0}])],ngContentSelectors:Z,decls:7,vars:4,consts:[["template",""],[1,"flex","w-full"],["autocomplete","new-password","pInputText","","type","text",1,"flex-1",3,"dwl-ignore","class","disabled","readonly","ngModel","border-top-right-radius","border-bottom-right-radius"],["autocomplete","new-password","pInputText","","type","password",1,"flex-1",3,"dwl-ignore","class","disabled","readonly","ngModel","border-top-right-radius","border-bottom-right-radius","required"],["pInputTextarea","",1,"flex-1",3,"class","dwl-ignore","disabled","readonly","ngModel","border-top-right-radius","border-bottom-right-radius"],[4,"ngTemplateOutlet"],["autocomplete","new-password","pInputText","","type","text",1,"flex-1",3,"ngModelChange","focus","input","keyup","blur","disabled","readonly","ngModel"],["autocomplete","new-password","pInputText","","type","password",1,"flex-1",3,"ngModelChange","focus","input","keyup","blur","disabled","readonly","ngModel","required"],["pInputTextarea","",1,"flex-1",3,"ngModelChange","disabled","readonly","ngModel"]],template:function(t,i){if(t&1&&(A(),c(0,"div",1),m(1,$,1,11,"input",2),m(2,ee,1,12,"input",3),m(3,te,1,11,"textarea",4),T(4,ne,1,0,"ng-container",5),_(),T(5,ie,1,0,"ng-template",null,0,k)),t&2){let H=R(6);p(),g(i.type==="text"?1:-1),p(),g(i.type==="password"?2:-1),p(),g(i.type==="textarea"?3:-1),p(),u("ngTemplateOutlet",H)}},dependencies:[G,j,N,O,D,L,F,z,P],encapsulation:2});let o=l;return o})()});export{Ce as a,oe as b};
