import{a as bt,b as pi}from"./chunk-VUNFKHFX.js";import{a as St,b as ci}from"./chunk-7WU3BKCA.js";import{a as yt,b as si}from"./chunk-AE2RVXWX.js";import{c as Ct,d as oi,e as wt,f as ai}from"./chunk-VQVDS7AR.js";import{a as vt,b as ri}from"./chunk-LOVLDBRW.js";import{a as mt,b as _t,c as ht}from"./chunk-4Z7Z6YAK.js";import{a as ut,b as ti,i as ft,j as ii}from"./chunk-Q2CF2JQV.js";import{a as gt,b as ni}from"./chunk-4EHH4FUQ.js";import{D as lt,E as Zt}from"./chunk-I7GW4F3B.js";import{a as dt,b as ei}from"./chunk-6POW7SSJ.js";import{cb as st,fb as ct,hb as pt,na as at,oa as Jt,q as nt,r as ot,s as rt,zb as Xt}from"./chunk-V2ECYACM.js";import{C as We,E as qe,b as Re,f as Le,m as Ne}from"./chunk-JPHJ3OD7.js";import{d as ye,e as Kt,j as Yt}from"./chunk-ZBM6BFOI.js";import{d as it,e as Ht,i as A,j as Gt}from"./chunk-AGRQYW7D.js";import{c as Qe,d as me,g as _e,h as he,i as Ce}from"./chunk-WFM63CSH.js";import{e as et,f as Wt,m as tt,n as qt}from"./chunk-SM7EQ7ST.js";import{Kb as P,Lb as Qt,e as ve,f as zt,kg as te,lg as Lt,mf as Ze,nf as Rt,qg as we,rg as Nt}from"./chunk-BPZQKZKD.js";import{a as He,b as Bt}from"./chunk-QGVT6DPT.js";import{Ha as ee,Ia as z,La as Xe,da as Ye,t as Ke,wa as Je,xa as jt}from"./chunk-5E3JCGAH.js";import{D as ze,I as Dt}from"./chunk-HTXYTVN4.js";import{b as Ge,c as $t}from"./chunk-YBNTOQCK.js";import{B as O,K as je,r as ge}from"./chunk-LDWBA6DZ.js";import{$c as De,Ad as g,Bd as $e,Cc as de,Db as H,Dc as y,Ea as m,Fa as _,H as ke,Hc as S,Jb as x,Jc as p,Jd as b,Kc as V,Kd as fe,Lc as D,Mc as G,Na as Ee,Nc as Ve,Oc as B,Od as se,Pc as $,Qb as T,Qc as j,Qd as ce,Rb as Ue,Rd as pe,Sa as Vt,Sc as re,Sd as Z,Ub as M,Vc as C,Wb as U,Xa as I,Xc as ae,Yc as v,Zc as w,be as le,cd as K,d as Ie,dd as Y,ed as J,ia as W,id as R,jc as k,mc as u,na as Ut,oc as f,od as Be,qd as X,rc as ne,sa as E,sc as oe,sd as ue,ta as Oe,tc as h,ua as Ae,uc as a,vc as s,wc as F,ya as q,yb as r,zd as d}from"./chunk-WL5U2YIT.js";import{e as Pe}from"./chunk-ADEKKGI2.js";function di(e,c){e&1&&F(0,"p-stepper-separator")}function ui(e,c){if(e&1){let t=y();a(0,"button",0),S("click",function(){m(t);let n=p();return _(n.onStepClick())}),a(1,"span",1),v(2),s(),a(3,"span",2),D(4),s()(),u(5,di,1,0,"p-stepper-separator")}if(e&2){let t=p();h("tabindex",t.isStepDisabled()?-1:void 0)("disabled",t.isStepDisabled()),k("id",t.id())("role","tab")("aria-controls",t.ariaControls()),r(2),w(t.value()),r(3),f(t.isSeparatorVisible()?5:-1)}}function fi(e,c){e&1&&de(0)}function gi(e,c){e&1&&F(0,"p-stepper-separator")}function mi(e,c){if(e&1&&(U(0,fi,1,0,"ng-container",3),u(1,gi,1,0,"p-stepper-separator")),e&2){let t=p();h("ngTemplateOutlet",t.content||t._contentTemplate)("ngTemplateOutletContext",ue(3,Mt,t.onStepClick.bind(t),t.value(),t.active())),r(),f(t.isSeparatorVisible()?1:-1)}}function Ci(e,c){e&1&&F(0,"p-stepper-separator")}function vi(e,c){e&1&&de(0)}function wi(e,c){if(e&1&&U(0,vi,1,0,"ng-container",1),e&2){let t=p();h("ngTemplateOutlet",t.contentTemplate||t._contentTemplate)("ngTemplateOutletContext",ue(2,Mt,t.updateValue.bind(t),t.value(),t.active()))}}var L,Tt,Mt,Ft,_i,hi,yi,Si,xt,Se,Fe,be,Q,ie,xe,N,Pt,Te=Pe(()=>{je();je();le();le();Yt();jt();Xe();Gt();Kt();Ht();L=["*"],Tt=["content"],Mt=(e,c,t)=>({activateCallback:e,value:c,active:t});Ft=e=>({transitionParams:e}),_i=e=>({value:"visible",params:e}),hi=e=>({value:"hidden",params:e});yi=({dt:e})=>`
.p-steplist {
    position: relative;
    display: flex;
    justify-content: space-between;
    align-items: center;
    margin: 0;
    padding: 0;
    list-style-type: none;
    overflow-x: auto;
}

.p-step {
    position: relative;
    display: flex;
    flex: 1 1 auto;
    align-items: center;
    gap: ${e("stepper.step.gap")};
    padding: ${e("stepper.step.padding")};
}

.p-step:last-of-type {
    flex: initial;
}

.p-step-header {
    border: 0 none;
    display: inline-flex;
    align-items: center;
    text-decoration: none;
    cursor: pointer;
    transition: background ${e("stepper.transition.duration")}, color ${e("stepper.transition.duration")}, border-color ${e("stepper.transition.duration")}, outline-color ${e("stepper.transition.duration")}, box-shadow ${e("stepper.transition.duration")};
    border-radius: ${e("stepper.step.header.border.radius")};
    outline-color: transparent;
    background: transparent;
    padding: ${e("stepper.step.header.padding")};
    gap: ${e("stepper.step.header.gap")};
}

.p-step-header:focus-visible {
    box-shadow: ${e("stepper.step.header.focus.ring.shadow")};
    outline: ${e("stepper.step.header.focus.ring.width")} ${e("stepper.step.header.focus.ring.style")} ${e("stepper.step.header.focus.ring.color")};
    outline-offset: ${e("stepper.step.header.focus.ring.offset")};
}

.p-stepper.p-stepper-readonly .p-step {
    cursor: auto;
}

.p-step-title {
    display: block;
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
    max-width: 100%;
    color: ${e("stepper.step.title.color")};
    font-weight: ${e("stepper.step.title.font.weight")};
    transition: background ${e("stepper.transition.duration")}, color ${e("stepper.transition.duration")}, border-color ${e("stepper.transition.duration")}, box-shadow ${e("stepper.transition.duration")}, outline-color ${e("stepper.transition.duration")};
}

.p-step-number {
    display: flex;
    align-items: center;
    justify-content: center;
    color: ${e("stepper.step.number.color")};
    border: 2px solid ${e("stepper.step.number.border.color")};
    background: ${e("stepper.step.number.background")};
    min-width: ${e("stepper.step.number.size")};
    height: ${e("stepper.step.number.size")};
    line-height: ${e("stepper.step.number.size")};
    font-size: ${e("stepper.step.number.font.size")};
    z-index: 1;
    border-radius: ${e("stepper.step.number.border.radius")};
    position: relative;
    font-weight: ${e("stepper.step.number.font.weight")};
}

.p-step-number::after {
    content: " ";
    position: absolute;
    width: 100%;
    height: 100%;
    border-radius: ${e("stepper.step.number.border.radius")};
    box-shadow: ${e("stepper.step.number.shadow")};
}

.p-step-active .p-step-header {
    cursor: default;
}

.p-step-active .p-step-number {
    background: ${e("stepper.step.number.active.background")};
    border-color: ${e("stepper.step.number.active.border.color")};
    color: ${e("stepper.step.number.active.color")};
}

.p-step-active .p-step-title {
    color: ${e("stepper.step.title.active.color")};
}

.p-step:not(.p-disabled):focus-visible {
    outline: ${e("focus.ring.width")} ${e("focus.ring.style")} ${e("focus.ring.color")};
    outline-offset: ${e("focus.ring.offset")};
}

.p-step:has(~ .p-step-active) .p-stepper-separator {
    background: ${e("stepper.separator.active.background")};
}

.p-stepper-separator {
    flex: 1 1 0;
    background: ${e("stepper.separator.background")};
    width: 100%;
    height: ${e("stepper.separator.size")};
    transition: background ${e("stepper.transition.duration")}, color ${e("stepper.transition.duration")}, border-color ${e("stepper.transition.duration")}, box-shadow ${e("stepper.transition.duration")}, outline-color ${e("stepper.transition.duration")};
}

.p-steppanels {
    padding: ${e("stepper.steppanels.padding")};
}

.p-steppanel {
    background: ${e("stepper.steppanel.background")};
    color: ${e("stepper.steppanel.color")};
}

.p-stepper:has(.p-stepitem) {
    display: flex;
    flex-direction: column;
}

.p-stepitem {
    display: flex;
    flex-direction: column;
    flex: initial;
}

.p-stepitem.p-stepitem-active {
    flex: 1 1 auto;
}

.p-stepitem .p-step {
    flex: initial;
}

.p-stepitem .p-steppanel-content {
    width: 100%;
    padding: ${e("stepper.steppanel.padding")};
    margin-inline-start: 1rem;
}

.p-stepitem .p-steppanel {
    display: flex;
    flex: 1 1 auto;
}

.p-stepitem .p-stepper-separator {
    flex: 0 0 auto;
    width: ${e("stepper.separator.size")};
    height: auto;
    margin: ${e("stepper.separator.margin")};
    position: relative;
    left: calc(-1 * ${e("stepper.separator.size")});
}

.p-stepitem .p-stepper-separator:dir(rtl) {
    left: calc(-9 * ${e("stepper.separator.size")});
}

.p-stepitem:has(~ .p-stepitem-active) .p-stepper-separator {
    background: ${e("stepper.separator.active.background")};
}

.p-stepitem:last-of-type .p-steppanel {
    padding-inline-start: ${e("stepper.step.number.size")};
}
/* For PrimeNG */
.p-steppanel {
    overflow: hidden;
}

.p-stepppanel:not(.ng-animating) {
    overflow: inherit;
}
`,Si={root:({props:e})=>["p-stepper p-component",{"p-readonly":e.linear}],separator:"p-stepper-separator"},xt=(()=>{class e extends it{name="stepper";theme=yi;classes=Si;static \u0275fac=(()=>{let t;return function(n){return(t||(t=I(e)))(n||e)}})();static \u0275prov=Oe({token:e,factory:e.\u0275fac})}return e})(),Se=(()=>{class e extends A{steps=pe(E(()=>Q));static \u0275fac=(()=>{let t;return function(n){return(t||(t=I(e)))(n||e)}})();static \u0275cmp=T({type:e,selectors:[["p-step-list"]],contentQueries:function(i,n,o){i&1&&j(o,n.steps,Q,4),i&2&&re()},hostVars:4,hostBindings:function(i,n){i&2&&C("p-steplist",!0)("p-component",!0)},features:[M],ngContentSelectors:L,decls:1,vars:0,template:function(i,n){i&1&&(V(),D(0))},dependencies:[O],encapsulation:2,changeDetection:0})}return e})(),Fe=(()=>{class e extends A{static \u0275fac=(()=>{let t;return function(n){return(t||(t=I(e)))(n||e)}})();static \u0275cmp=T({type:e,selectors:[["p-stepper-separator"]],hostVars:4,hostBindings:function(i,n){i&2&&C("p-stepper-separator",!0)("p-component",!0)},features:[M],ngContentSelectors:L,decls:1,vars:0,template:function(i,n){i&1&&(V(),D(0))},dependencies:[O],encapsulation:2,changeDetection:0})}return e})(),be=(()=>{class e extends A{pcStepper=q(E(()=>N));value=Z();isActive=b(()=>this.pcStepper.value()===this.value());step=ce(E(()=>Q));stepPanel=ce(E(()=>ie));constructor(){super(),fe(()=>{this.step().value.set(this.value())}),fe(()=>{this.stepPanel().value.set(this.value())})}static \u0275fac=function(i){return new(i||e)};static \u0275cmp=T({type:e,selectors:[["p-step-item"]],contentQueries:function(i,n,o){i&1&&(j(o,n.step,Q,5),j(o,n.stepPanel,ie,5)),i&2&&re(2)},hostVars:5,hostBindings:function(i,n){i&2&&(k("data-p-active",n.isActive()),C("p-stepitem",!0)("p-component",!0))},inputs:{value:[1,"value"]},outputs:{value:"valueChange"},features:[M],ngContentSelectors:L,decls:1,vars:0,template:function(i,n){i&1&&(V(),D(0))},dependencies:[O],encapsulation:2,changeDetection:0})}return e})(),Q=(()=>{class e extends A{pcStepper=q(E(()=>N));value=Z();disabled=se(!1,{transform:t=>ye(t)});active=b(()=>this.pcStepper.isStepActive(this.value()));isStepDisabled=b(()=>!this.active()&&(this.pcStepper.linear()||this.disabled()));id=b(()=>`${this.pcStepper.id()}_step_${this.value()}`);ariaControls=b(()=>`${this.pcStepper.id()}_steppanel_${this.value()}`);isSeparatorVisible=b(()=>{if(this.pcStepper.stepList()){let t=this.pcStepper.stepList().steps(),i=t.indexOf(this),n=t.length;return i!==n-1}else return!1});content;templates;_contentTemplate;ngAfterContentInit(){this.templates?.forEach(t=>{t.getType()==="content"&&(this._contentTemplate=t.template)})}onStepClick(){this.pcStepper.updateValue(this.value())}static \u0275fac=(()=>{let t;return function(n){return(t||(t=I(e)))(n||e)}})();static \u0275cmp=T({type:e,selectors:[["p-step"]],contentQueries:function(i,n,o){if(i&1&&(G(o,Tt,4),G(o,ee,4)),i&2){let l;B(l=$())&&(n.content=l.first),B(l=$())&&(n.templates=l)}},hostVars:13,hostBindings:function(i,n){i&2&&(k("aria-current",n.active()?"step":void 0)("role","presentation")("data-p-active",n.active())("data-p-disabled",n.isStepDisabled())("data-pc-name","step"),C("p-step",!0)("p-step-active",n.active())("p-disabled",n.isStepDisabled())("p-component",!0))},inputs:{value:[1,"value"],disabled:[1,"disabled"]},outputs:{value:"valueChange"},features:[M],ngContentSelectors:L,decls:2,vars:1,consts:[["type","button",1,"p-step-header",3,"click","tabindex","disabled"],[1,"p-step-number"],[1,"p-step-title"],[4,"ngTemplateOutlet","ngTemplateOutletContext"]],template:function(i,n){i&1&&(V(),u(0,ui,6,7)(1,mi,2,7)),i&2&&f(!n.content&&!n._contentTemplate?0:1)},dependencies:[O,ge,Fe,z],encapsulation:2,changeDetection:0})}return e})(),ie=(()=>{class e extends A{pcStepper=q(E(()=>N));transitionOptions=b(()=>this.pcStepper.transitionOptions());value=Z(void 0);active=b(()=>this.pcStepper.value()===this.value());ariaControls=b(()=>`${this.pcStepper.id()}_step_${this.value()}`);id=b(()=>`${this.pcStepper.id()}_steppanel_${this.value()}`);isVertical=b(()=>this.pcStepper.stepItems().length>0);isSeparatorVisible=b(()=>{if(this.pcStepper.stepItems()){let t=this.pcStepper.stepItems().length,i=Ke(this.pcStepper.el.nativeElement,'[data-pc-name="steppanel"]');return Ye(this.el.nativeElement,i)!==t-1}});contentTemplate;templates;_contentTemplate;ngAfterContentInit(){this.templates?.forEach(t=>{t.getType()==="content"&&(this._contentTemplate=t.template)})}updateValue(t){this.pcStepper.updateValue(t)}static \u0275fac=(()=>{let t;return function(n){return(t||(t=I(e)))(n||e)}})();static \u0275cmp=T({type:e,selectors:[["p-step-panel"]],contentQueries:function(i,n,o){if(i&1&&(G(o,Tt,5),G(o,ee,4)),i&2){let l;B(l=$())&&(n.contentTemplate=l.first),B(l=$())&&(n.templates=l)}},hostVars:11,hostBindings:function(i,n){i&2&&(k("role","tabpanel")("aria-controls",n.ariaControls())("id",n.id())("data-p-active",n.active())("data-pc-name","steppanel"),C("p-steppanel",!0)("p-component",!0)("p-steppanel-active",n.active()))},inputs:{value:[1,"value"]},outputs:{value:"valueChange"},features:[M],decls:3,vars:11,consts:[[1,"p-steppanel-content"],[4,"ngTemplateOutlet","ngTemplateOutletContext"]],template:function(i,n){i&1&&(u(0,Ci,1,0,"p-stepper-separator"),a(1,"div",0),u(2,wi,1,6,"ng-container"),s()),i&2&&(f(n.isSeparatorVisible()?0:-1),r(),h("@content",n.isVertical()?n.active()?X(5,_i,X(3,Ft,n.transitionOptions())):X(9,hi,X(7,Ft,n.transitionOptions())):void 0),r(),f(n.active()?2:-1))},dependencies:[O,ge,Fe,z],encapsulation:2,data:{animation:[Qe("content",[he("hidden",_e({height:"0",visibility:"hidden"})),he("visible",_e({height:"*",visibility:"visible"})),Ce("visible <=> hidden",[me("250ms cubic-bezier(0.86, 0, 0.07, 1)")]),Ce("void => *",me(0))])]},changeDetection:0})}return e})(),xe=(()=>{class e extends A{static \u0275fac=(()=>{let t;return function(n){return(t||(t=I(e)))(n||e)}})();static \u0275cmp=T({type:e,selectors:[["p-step-panels"]],hostVars:4,hostBindings:function(i,n){i&2&&C("p-steppanels",!0)("p-component",!0)},features:[M],ngContentSelectors:L,decls:1,vars:0,template:function(i,n){i&1&&(V(),D(0))},dependencies:[O,z],encapsulation:2,changeDetection:0})}return e})(),N=(()=>{class e extends A{value=Z(void 0);linear=se(!1,{transform:t=>ye(t)});transitionOptions=se("400ms cubic-bezier(0.86, 0, 0.07, 1)");_componentStyle=q(xt);id=Ee(Je("pn_id_"));stepItems=pe(be);steps=pe(Q);stepList=ce(Se);updateValue(t){this.value.set(t)}isStepActive(t){return this.value()===t}static \u0275fac=(()=>{let t;return function(n){return(t||(t=I(e)))(n||e)}})();static \u0275cmp=T({type:e,selectors:[["p-stepper"]],contentQueries:function(i,n,o){i&1&&(j(o,n.stepItems,be,4),j(o,n.steps,Q,4),j(o,n.stepList,Se,5)),i&2&&re(3)},hostVars:6,hostBindings:function(i,n){i&2&&(k("role","tablist")("id",n.id()),C("p-stepper",!0)("p-component",!0))},inputs:{value:[1,"value"],linear:[1,"linear"],transitionOptions:[1,"transitionOptions"]},outputs:{value:"valueChange"},features:[Be([xt]),M],ngContentSelectors:L,decls:1,vars:0,template:function(i,n){i&1&&(V(),D(0))},dependencies:[O,z],encapsulation:2,changeDetection:0})}return e})(),Pt=(()=>{class e{static \u0275fac=function(i){return new(i||e)};static \u0275mod=Ue({type:e});static \u0275inj=Ae({imports:[N,Se,xe,ie,be,Q,Fe,z,z]})}return e})()});function xi(e,c){if(e&1){let t=y();a(0,"dvl-button",5),d(1,"translate"),S("onClick",function(){m(t);let n=p(2);return _(n.navigateToTwoFactorSettings())}),s()}e&2&&h("label",R(g(1,2,"lblConfigure")))}function Ti(e,c){if(e&1&&(a(0,"div",1)(1,"div",2)(2,"span",3),v(3),d(4,"translate"),s(),u(5,xi,2,4,"dvl-button",4),s()()),e&2){let t=p();r(3),w(g(4,2,"ConnectionLogMessage_2FANotConfigured")),r(2),f(t.canConfigureMFA()?5:-1)}}function Mi(e,c){if(e&1){let t=y();a(0,"div",6)(1,"div",10)(2,"h5"),v(3),d(4,"translate"),s(),a(5,"div",11)(6,"dvl-button",12),d(7,"translate"),S("onClick",function(){m(t);let n=p(2);return _(n.reAuthenticate())}),s()()()()}e&2&&(r(3),w(g(4,4,"lblReAuthenticationIsRequired")),r(3),h("label",R(g(7,6,"lblReAuthenticate")))("warning",!0))}function Pi(e,c){if(e&1){let t=y();a(0,"div",6),d(1,"translate"),a(2,"label"),v(3),d(4,"translate"),s(),a(5,"div",15)(6,"input",16),d(7,"translate"),J("ngModelChange",function(n){m(t);let o=p(3);return Y(o.password,n)||(o.password=n),_(n)}),S("keyup.enter",function(){m(t);let n=p(3);return _(n.validatePassword())}),s(),a(8,"dvl-button",17),d(9,"translate"),S("onClick",function(){m(t);let n=p(3);return _(n.validatePassword())}),s()()()}if(e&2){let t=p(3);C("form-error",t.passwordValiationFailed),k("data-error",g(1,12,"lblInvalidPassword")),r(3),w(g(4,14,"lblEnterYourPasswordToContinue")),r(3),h("placeholder",R(g(7,16,"lblPassword"))),K("ngModel",t.password),h("autoFocus",!0)("disabled",t.passwordValidated),r(2),h("label",R(g(9,18,"lblSubmit")))("disabled",t.passwordValidated)}}function Ii(e,c){if(e&1&&(a(0,"div",13),u(1,Pi,10,20,"div",14),s()),e&2){let t=p(2);r(),f(t.isSingleSignOnUser?-1:1)}}function ki(e,c){e&1&&(a(0,"span",30),v(1),d(2,"translate"),s()),e&2&&(r(),w(g(2,1,"lblDefault")))}function Oi(e,c){if(e&1){let t=y();a(0,"div",26)(1,"div",27),F(2,"i",28),a(3,"h5",29),v(4),d(5,"translate"),s(),u(6,ki,3,3,"span",30),a(7,"div",31)(8,"dvl-button",32),S("onClick",function(n){let o=m(t).$implicit,l=p(4);return _(l.onActionMenuClick(o,n))}),s(),F(9,"p-menu",33,0),s()()()}if(e&2){let t=c.$implicit,i=p(4);C("disabled",i.disableMfaEdit),r(2),ae(t.icon),r(2),w(g(5,8,t.name)),r(2),f(t.isDefault?6:-1),r(3),h("popup",!0)("model",i.actionMenuItems)}}function Ai(e,c){if(e&1&&(a(0,"div",20)(1,"h4",23),v(2),d(3,"translate"),s(),a(4,"div",24),ne(5,Oi,11,10,"div",25,Me),s()()),e&2){let t=p(3);r(2),w(g(3,1,"lblConfigured")),r(3),oe(t.getConfiguredFactors())}}function Ei(e,c){e&1&&(a(0,"span",30),v(1),d(2,"translate"),s()),e&2&&(r(),w(g(2,1,"lblDefault")))}function Ui(e,c){if(e&1){let t=y();a(0,"div",36)(1,"div",27),F(2,"i",28),a(3,"h5",29),v(4),d(5,"translate"),s(),u(6,Ei,3,3,"span",30),a(7,"div",31)(8,"dvl-button",32),S("onClick",function(n){let o=m(t).$implicit,l=p(4);return _(l.onActionMenuClick(o,n))}),s(),F(9,"p-menu",33,0),s()()()}if(e&2){let t=c.$implicit,i=p(4);C("disabled",i.disableMfaEdit),r(2),ae(t.icon),r(2),w(g(5,8,t.name)),r(2),f(t.isDefault?6:-1),r(3),h("popup",!0)("model",i.actionMenuItems)}}function Vi(e,c){if(e&1&&(a(0,"div",34)(1,"h4",23),v(2),d(3,"translate"),s(),a(4,"div",24),ne(5,Ui,11,10,"div",35,Me),s()()),e&2){let t=p(3);C("mt-4",t.getConfiguredFactors().length>0),r(2),w(g(3,3,"lblPreConfigured")),r(3),oe(t.getPreConfiguredFactors())}}function Di(e,c){e&1&&(a(0,"div",40)(1,"span"),v(2),d(3,"translate"),s(),F(4,"i",41),s()),e&2&&(r(2),w(g(3,1,"lblConfigure")))}function Bi(e,c){if(e&1){let t=y();a(0,"div",39),S("click",function(){let n=m(t).$implicit,o=p(4);return _(o.onCardClick(n))}),a(1,"div",27),F(2,"i",28),a(3,"h5",29),v(4),d(5,"translate"),s(),u(6,Di,5,3,"div",40),s()()}if(e&2){let t=c.$implicit,i=p(4);C("disabled",i.disableMfaEdit)("clickable",!t.isConfigured&&!i.disableMfaEdit&&i.currentlyConfiguringFactor===null),r(2),ae(t.icon),r(2),w(g(5,8,t.name)),r(2),f(!i.disableMfaEdit&&i.currentlyConfiguringFactor===null?6:-1)}}function $i(e,c){if(e&1&&(a(0,"div",37)(1,"h4",23),v(2),d(3,"translate"),s(),a(4,"div",24),ne(5,Bi,7,10,"div",38,Me),s()()),e&2){let t=p(3);C("mt-4",t.getConfiguredFactors().length>0||t.getPreConfiguredFactors().length>0),r(2),w(g(3,3,"lblNotConfigured")),r(3),oe(t.getUnconfiguredFactors())}}function ji(e,c){if(e&1){let t=y();a(0,"div",13)(1,"div",6)(2,"dvl-messages",18),J("valueChange",function(n){m(t);let o=p(2);return Y(o.userMsgTwoFactor,n)||(o.userMsgTwoFactor=n),_(n)}),s()(),a(3,"div",19),u(4,Ai,7,3,"div",20),u(5,Vi,7,5,"div",21),u(6,$i,7,5,"div",22),s()()}if(e&2){let t=p(2);r(2),K("value",t.userMsgTwoFactor),r(2),f(t.getConfiguredFactors().length>0?4:-1),r(),f(t.getPreConfiguredFactors().length>0?5:-1),r(),f(t.getUnconfiguredFactors().length>0?6:-1)}}function zi(e,c){if(e&1&&(a(0,"h4"),v(1),d(2,"translate"),d(3,"translateEnum"),s()),e&2){let t=p(3);r(),De(" ",g(2,2,"lblConfiguring")," ",$e(3,4,t.currentlyConfiguringFactor,t.TwoFactorAuthenticationType)," ")}}function Qi(e,c){if(e&1){let t=y();a(0,"div",6)(1,"dvl-checkbox",46),d(2,"translate"),S("onChange",function(n){m(t);let o=p(4);return _(o.preConfiguredOnChange(n))}),J("ngModelChange",function(n){m(t);let o=p(4);return Y(o.twoFactorEntity.twoFactorInfo.isPreConfigured,n)||(o.twoFactorEntity.twoFactorInfo.isPreConfigured=n),_(n)}),s()()}if(e&2){let t=p(4);r(),h("label",R(g(2,4,"lblConfigureLaterByUser")))("disabled",t.currentlyConfiguringFactor===4&&!t.workingCopy.userProfile.cellPhone),K("ngModel",t.twoFactorEntity.twoFactorInfo.isPreConfigured)}}function Ri(e,c){if(e&1){let t=y();a(0,"div",47)(1,"sd-two-factor",48),S("onReloadTwoFactorConfiguration",function(){m(t);let n=p(4);return _(n.reloadTwoFactor())})("onSaveTwoFactor",function(n){m(t);let o=p(4);return _(o.saveTwoFactor(n))})("onUpdateDuoCapability",function(n){m(t);let o=p(4);return _(o.updateDuoCapability(n))}),s()()}if(e&2){let t=p(4);C("disabled",t.isPreConfiguredSaved),r(),h("password",t.password)("twoFactorInfo",t.twoFactorEntity.twoFactorInfo)("twoFactorEntity",t.twoFactorEntity)("username",t.workingCopy.userSecurity.name)("userId",t.workingCopy.userSecurity.id)("cellPhone",t.workingCopy.userProfile.cellPhone)("email",t.workingCopy.userAccount.email)("setupMode",!0)("setupOnInit",!1)}}function Li(e,c){if(e&1&&(a(0,"div",19)(1,"div",44),u(2,Qi,3,6,"div",6),a(3,"div",6),u(4,Ri,2,11,"div",45),s()()()),e&2){let t=p(3);r(2),f(t.hideConfigureLater?-1:2),r(2),f(t.reload2fa?-1:4)}}function Ni(e,c){if(e&1){let t=y();a(0,"div",13)(1,"div",42)(2,"dvl-button",43),d(3,"translate"),S("onClick",function(){m(t);let n=p(2);return _(n.cancelConfiguration())}),s(),u(4,zi,4,7,"h4"),a(5,"dvl-messages",18),J("valueChange",function(n){m(t);let o=p(2);return Y(o.userMsgTwoFactor,n)||(o.userMsgTwoFactor=n),_(n)}),s()(),u(6,Li,5,2,"div",19),s()}if(e&2){let t=p(2);r(2),h("label",g(3,4,"lblBack")),r(2),f(t.currentlyConfiguringFactor!==null?4:-1),r(),K("value",t.userMsgTwoFactor),r(),f(t.currentlyConfiguringFactor!==null&&t.twoFactorEntity?6:-1)}}function Wi(e,c){if(e&1){let t=y();u(0,Mi,8,8,"div",6),a(1,"p-stepper",7),S("valueChange",function(n){m(t);let o=p();return _(o.activeStepIndex=n)}),a(2,"p-step-panels")(3,"p-step-panel",8),U(4,Ii,2,1,"ng-template",9),s(),a(5,"p-step-panel",8),U(6,ji,7,4,"ng-template",9),s(),a(7,"p-step-panel",8),U(8,Ni,7,6,"ng-template",9),s()()()}if(e&2){let t=p();f(t.showReAuthButton?0:-1),r(),h("value",t.activeStepIndex),r(2),h("value",0),r(2),h("value",1),r(2),h("value",2)}}var Fi,Me,Gn,qi=Pe(()=>{le();Qt();Wt();Ut();qe();Vt();Bt();Lt();Rt();ti();zt();ei();ni();rt();Xt();Jt();Te();oi();ht();Nt();si();le();ii();ri();$t();ci();pi();qt();Zt();ai();Dt();rt();qe();Xe();Te();ht();Fi=["actionMenu"],Me=(e,c)=>c.type;Gn=(()=>{let c=class c extends He{constructor(i,n,o,l,It,kt,Ot,At,Et){super(),this.authService=i,this.accountService=n,this.translatorService=o,this.configurationService=l,this.emailConfigurationService=It,this.serverInformationService=kt,this.currentUserService=Ot,this.twoFactorUiService=At,this.router=Et,this.onAuthTypeChange=new H,this.onConfiguratedByUserChange=new H,this.onPasswordValidated=new H,this.workingCopyChange=new H,this.twoFactorAuthenticationType=P,this.twoFactorEntity=null,this.twoFactorInfo=null,this.resetTwoFactorConfiguaration=!1,this.userMsgTwoFactor=[],this.reload2fa=!1,this.emailEnabled=!1,this.password="",this.passwordValidated=!1,this.passwordValiationFailed=!1,this.isCurrentUser=!1,this.currentEditingFactorId=null,this.currentSecondFactors=[],this.currentlyConfiguringFactor=null,this.isPreConfiguredSaved=!1,this.showReAuthButton=!1,this.isSingleSignOnUser=!1,this.activeStepIndex=0,this.authorizedTwoFactor=[],this.actionMenuItems=[],this.TwoFactorAuthenticationType=P}get twoFactorType(){return this._twoFactorType}set twoFactorType(i){i!==this._twoFactorType&&(this._twoFactorType=i,this.onAuthTypeChange.emit(i))}get is2FATwilioActivated(){return!!this.serverInformationService.serverInformation&&this.serverInformationService.serverInformation.is2FATwilioActivated}get disableMfaEdit(){return this.isCurrentUser&&(this.isSingleSignOnUser?this.showReAuthButton:!this.passwordValidated)}ngOnInit(){this.isCurrentUser=this.currentUserService.currentUserId==this.workingCopy.userSecurity.id,this.getAuthorizedAuthenticationTypes(),this.initEmailConfiguration(),this.checkIfSingleSignOnUser(),this.initializeStepperState()}ngOnDestroy(){this.sessionTimerSubscription&&this.sessionTimerSubscription.unsubscribe()}initializeStepperState(){this.isCurrentUser&&(!this.isSingleSignOnUser||this.showReAuthButton)?this.activeStepIndex=0:this.activeStepIndex=1}canProceedToStep(i){if(!this.isCurrentUser)return i>=1;switch(i){case 0:return!0;case 1:return this.isSingleSignOnUser?!this.showReAuthButton:this.passwordValidated;case 2:return(this.isSingleSignOnUser?!this.showReAuthButton:this.passwordValidated)&&this.currentlyConfiguringFactor!==null;default:return!1}}nextStep(){this.activeStepIndex<2&&this.canProceedToStep(this.activeStepIndex+1)&&this.activeStepIndex++}previousStep(){this.activeStepIndex>0&&this.activeStepIndex--}goToStep(i){this.canProceedToStep(i)&&(this.activeStepIndex=i)}saveTwoFactor(i){this.currentEditingFactorId&&(i.id=this.currentEditingFactorId),i.id||(i.id=we.newGuid());let n=this.workingCopy.userAccount.twoFactorInfoArray.findIndex(o=>o.id===i.id);this.workingCopy.userAccount.twoFactorInfoArray.length===0&&(i.isDefault=!0),n>=0?this.workingCopy.userAccount.twoFactorInfoArray[n]=i:this.workingCopy.userAccount.twoFactorInfoArray.push(i),this.workingCopyChange.emit(this.workingCopy),this.currentlyConfiguringFactor=null,this.twoFactorEntity=null,this.updateSecondFactorBoxes(),this.userMsgTwoFactor.push({severity:"info",detail:this.translatorService.translate("OperationCompletedSuccessfully")}),this.goToStep(1)}reloadTwoFactor(){this.reload2fa=!0,this.currentlyConfiguringFactor&&this.getUserTwoFactorEntity(this.currentlyConfiguringFactor).pipe(W(this.destroyed$)).subscribe(()=>this.reload2fa=!1)}preConfiguredOnChange(i){if(this.currentlyConfiguringFactor===P.Email&&this.workingCopy.userAccount.email===""){this.setFormPristine();return}if(i){let n=new te;n.id=this.twoFactorEntity.twoFactorInfo.id||we.newGuid(),n.authenticationType=this.currentlyConfiguringFactor,n.isPreConfigured=!0,this.currentlyConfiguringFactor===P.Email?n.accountName=this.workingCopy.userAccount.email:n.accountName=this.workingCopy.userSecurity.name,this.twoFactorEntity.twoFactorInfo.key&&(n.key=this.twoFactorEntity.twoFactorInfo.key);let o=this.workingCopy.userAccount.twoFactorInfoArray.findIndex(l=>l.id===n.id);this.workingCopy.userAccount.twoFactorInfoArray.length===0&&(n.isDefault=!0),o>=0?this.workingCopy.userAccount.twoFactorInfoArray[o]=n:this.workingCopy.userAccount.twoFactorInfoArray.push(n),this.workingCopyChange.emit(this.workingCopy),this.twoFactorEntity.twoFactorInfo.id=n.id,this.twoFactorEntity.twoFactorInfo.isPreConfigured=!0,this.isPreConfiguredSaved=!0,this.updateSecondFactorBoxes(),this.userMsgTwoFactor.push({severity:"info",detail:this.translatorService.translate("OperationCompletedSuccessfully")})}else this.isPreConfiguredSaved=!1,this.onConfiguratedByUserChange.emit(i)}updateDuoCapability(i){let n=this.workingCopy.userAccount.twoFactorInfoArray.findIndex(o=>o.authenticationType===P.Duo);if(n>=0){this.workingCopy.userAccount.twoFactorInfoArray[n].duoAutoCapability=i;let o=this.workingCopy.userAccount.twoFactorInfoArray[n],l=new te;l.accountName=o.accountName,l.duoAutoCapability=i,l.authenticationType=o.authenticationType,l.isConfigured=o.isConfigured,l.alternateTwoFactorType=o.alternateTwoFactorType,l.duoSelectedCapability=o.duoSelectedCapability,l.key=o.key,l.duoSelectedDeviceID=o.duoSelectedDeviceID,l.isPreConfigured=o.isPreConfigured||o.isPreConfiguredByUser,l.validationCode=o.validationCode,l.phone=o.phone,this.saveTwoFactor(l)}}validatePassword(){let i=new ut;i.password=this.password,this.accountService.validatePassword(i).pipe(W(this.destroyed$)).subscribe(n=>{n?(this.passwordValidated=!0,this.passwordValiationFailed=!1,this.onPasswordValidated.emit(this.password),this.nextStep()):(this.passwordValidated=!1,this.passwordValiationFailed=!0)})}initEmailConfiguration(){this.emailConfigurationService.getEmailConfiguration().pipe(W(this.destroyed$)).subscribe(i=>this.emailEnabled=i.emailConfigurationType!==Ze.None)}checkIfSingleSignOnUser(){this.isSingleSignOnUser=this.workingCopy.userSecurity.authenticationType!==ve.Builtin&&this.workingCopy.userSecurity.authenticationType!==ve.Domain,this.isSingleSignOnUser&&this.isCurrentUser&&this.startSessionTimer()}startSessionTimer(){this.sessionStartTime=new Date(this.currentUserService.accessSnapshot.sessionCreationDate),this.sessionTimerSubscription=ke(1e3).subscribe(()=>{let n=Math.floor((new Date().getTime()-this.sessionStartTime.getTime())/1e3);this.showReAuthButton=n>300,this.showReAuthButton&&this.isSingleSignOnUser&&this.isCurrentUser&&this.goToStep(0)})}reAuthenticate(){window.sessionStorage.setItem("promptMFAConfig","true"),this.authService.promptExternalLogin(this.currentUserService.currentUsername).subscribe(i=>{this.authService.logout(!0),window.location.href=i.location})}configureSecondFactor(i,n){this.userMsgTwoFactor=[],this.currentlyConfiguringFactor=i,this.isPreConfiguredSaved=!1,this.currentEditingFactorId=n||null,this.getUserTwoFactorEntity(i).pipe(W(this.destroyed$)).subscribe(()=>{if(i===P.Email&&this.workingCopy.userAccount.email==="")this.setFormPristine();else if(i===P.Radius){let o=new te;o.authenticationType=P.Radius,o.accountName=this.workingCopy.userSecurity.name,o.isConfigured=!0,n&&(o.id=n),this.saveTwoFactor(o)}this.goToStep(2)})}onCardClick(i){!i.isConfigured&&!this.disableMfaEdit&&this.currentlyConfiguringFactor===null&&this.configureSecondFactor(i.type)}removeSecondFactor(i){let n=this.workingCopy.userAccount.twoFactorInfoArray.findIndex(o=>o.id===i);if(n>=0){if(!this.workingCopy.userAccount.twoFactorInfoArray.splice(n,1)[0]){this.userMsgTwoFactor.push({severity:"error",detail:this.translatorService.translate("FailedToRemoveFactor")});return}this.workingCopyChange.emit(this.workingCopy),this.updateSecondFactorBoxes(),this.userMsgTwoFactor.push({severity:"info",detail:this.translatorService.translate("FactorRemovedSuccessfully")}),this.currentForm&&(this.currentForm.form.markAsDirty(),this.currentForm.form.patchValue({}))}}cancelConfiguration(){this.currentlyConfiguringFactor=null,this.twoFactorEntity=null,this.userMsgTwoFactor=[],this.isPreConfiguredSaved=!1,this.previousStep()}getConfiguredFactorInfo(i){return this.workingCopy.userAccount.twoFactorInfoArray.find(n=>n.authenticationType===i&&(n.isConfigured||n.isPreConfigured))}getConfiguredFactors(){return this.currentSecondFactors.filter(i=>i.isConfigured&&!i.isPreConfigured)}getPreConfiguredFactors(){return this.currentSecondFactors.filter(i=>i.isPreConfigured)}getUnconfiguredFactors(){return this.currentSecondFactors.filter(i=>!i.isConfigured)}hasSecondFactors(){return this.getConfiguredFactors().length>0||this.getPreConfiguredFactors().length>0||this.getUnconfiguredFactors().length>0}canConfigureMFA(){return this.currentUserService.isAdministrator}onActionMenuClick(i,n){this.initActionMenuItems(i),this.actionMenu.toggle(n)}navigateToTwoFactorSettings(){this.router.navigate(["/administration","server-settings","two-factor"])}updateSecondFactorBoxes(){this.currentSecondFactors=this.authorizedTwoFactor.map(i=>{let n=this.getConfiguredFactorInfo(i);return{id:n?.id,type:i,name:this.twoFactorUiService.getFactorDisplayName(i),icon:this.twoFactorUiService.getFactorIcon(i),isConfigured:!!n,isDefault:n?.isDefault??!1,isPreConfigured:n?.isPreConfigured??!1}})}getUserTwoFactorEntity(i){return new Ie(n=>{this.onConfiguratedByUserChange.emit(!1),this.configurationService.getUserTwoFactorEntity(this.workingCopy.userSecurity.id,i).subscribe(o=>{o||(o=new et),o.twoFactorInfo||(o.twoFactorInfo=new te),o.twoFactorInfo.accountName=this.workingCopy.userAccount.email,o.twoFactorInfo.key=o.secretKey,this.twoFactorEntity=o,this.twoFactorType=i,this.onConfiguratedByUserChange.emit(this.twoFactorEntity.twoFactorInfo.isPreConfigured),n.next(!0),n.complete()})})}getAuthorizedAuthenticationTypes(){let i=[];this.serverInformationService.publicServerInformation.availabelTwoFactorAuthenticationTypes&&(i=i.concat(this.serverInformationService.publicServerInformation.availabelTwoFactorAuthenticationTypes)),this.authorizedTwoFactor=i,this.updateSecondFactorBoxes()}setFormPristine(){this.currentForm.form.markAsPristine(),this.currentForm.form.updateValueAndValidity()}initActionMenuItems(i){this.actionMenuItems=[],i.isDefault||this.actionMenuItems.push({label:this.translatorService.translate("lblSetAsDefault"),icon:"di dvl-icon-check-circle",command:()=>this.setDefaultFactor(i.id)}),this.actionMenuItems.push({label:this.translatorService.translate("lblReconfigureMFA"),icon:"di dvl-icon-edit",command:()=>this.configureSecondFactor(i.type,i.id)}),(this.currentSecondFactors.filter(n=>n.isConfigured).length>1||!(this.serverInformationService.publicServerInformation.disableSelfMFADelete&&!this.currentUserService.isAdministrator))&&this.actionMenuItems.push({label:this.translatorService.translate("lblRemove2FA"),icon:"di dvl-icon-delete",command:()=>this.removeSecondFactor(i.id)})}setDefaultFactor(i){this.workingCopy.userAccount.twoFactorInfoArray.forEach(n=>{n.isDefault=n.id===i}),this.workingCopyChange.emit(this.workingCopy),this.updateSecondFactorBoxes(),this.userMsgTwoFactor.push({severity:"info",detail:this.translatorService.translate("DefaultFactorSetSuccessfully")}),this.currentForm&&(this.currentForm.form.markAsDirty(),this.currentForm.form.patchValue({}))}};c.\u0275fac=function(n){return new(n||c)(x(ft),x(vt),x(Ge),x(St),x(bt),x(tt),x(lt),x(wt),x(ze))},c.\u0275cmp=T({type:c,selectors:[["dvls-user-two-factor-configuration"]],viewQuery:function(n,o){if(n&1&&Ve(Fi,5),n&2){let l;B(l=$())&&(o.actionMenu=l.first)}},inputs:{workingCopy:"workingCopy",currentForm:"currentForm",hideConfigureLater:"hideConfigureLater"},outputs:{onAuthTypeChange:"onAuthTypeChange",onConfiguratedByUserChange:"onConfiguratedByUserChange",onPasswordValidated:"onPasswordValidated",workingCopyChange:"workingCopyChange"},features:[M],decls:2,vars:1,consts:[["actionMenu",""],[1,"p-message","p-message-warn"],[1,"flex","items-center","w-full","gap-4"],[1,"flex-1"],["variant","primary",3,"label"],["variant","primary",3,"onClick","label"],[1,"col-span-12","form-group"],[3,"valueChange","value"],[3,"value"],["pTemplate","content"],[1,"session-info-container","p-card","p-3","mb-3"],[1,"reauth-button"],["variant","primary","size","sm","icon","pi pi-refresh",3,"onClick","warning","label"],[1,"grid","gap-4"],[1,"col-span-12","form-group",3,"form-error"],[1,"flex","flex-col","gap-4"],["type","password","sdAutoFocusInput","","pInputText","","autocomplete","off",1,"w-full",3,"ngModelChange","keyup.enter","ngModel","autoFocus","disabled","placeholder"],["variant","primary",3,"onClick","disabled","label"],["messageStyleClass","no-margin",3,"valueChange","value"],[1,"col-span-12"],[1,"configured-factors-region"],[1,"preconfigured-factors-region",3,"mt-4"],[1,"unconfigured-factors-region",3,"mt-4"],[1,"region-title"],[1,"second-factors-grid"],[1,"second-factor-card","p-card","configured",3,"disabled"],[1,"second-factor-card","p-card","configured"],[1,"factor-header"],[1,"factor-icon"],[1,"factor-name"],[1,"default-label"],[1,"factor-actions"],["variant","icon","icon","pi pi-ellipsis-v",3,"onClick"],["appendTo","body",3,"popup","model"],[1,"preconfigured-factors-region"],[1,"second-factor-card","p-card","preconfigured",3,"disabled"],[1,"second-factor-card","p-card","preconfigured"],[1,"unconfigured-factors-region"],[1,"second-factor-card","p-card",3,"disabled","clickable"],[1,"second-factor-card","p-card",3,"click"],[1,"configure-hint"],[1,"pi","pi-arrow-right"],[1,"col-span-12","form-group","flex","items-center","configuration-title"],["variant","secondary","icon","pi pi-chevron-left",3,"onClick","label"],[1,"p-card","p-3"],[1,"two-factor-form-wrapper",3,"disabled"],["binary","true","name","preconfiguredTwoFa",3,"onChange","ngModelChange","label","disabled","ngModel"],[1,"two-factor-form-wrapper"],[3,"onReloadTwoFactorConfiguration","onSaveTwoFactor","onUpdateDuoCapability","password","twoFactorInfo","twoFactorEntity","username","userId","cellPhone","email","setupMode","setupOnInit"]],template:function(n,o){n&1&&u(0,Ti,6,4,"div",1)(1,Wi,9,5),n&2&&f(o.hasSecondFactors()?1:0)},dependencies:[gt,ot,nt,We,Re,Le,Ne,pt,at,ee,ct,Ct,Pt,N,xe,ie,_t,mt,st,dt,yt],styles:['[_nghost-%COMP%]     .homeBox{margin:0}.row-button[_ngcontent-%COMP%]{display:flex;align-items:flex-end}.row-button[_ngcontent-%COMP%]   button[_ngcontent-%COMP%]{border-color:#cdcdcd;padding:3px 7px}.session-info-container[_ngcontent-%COMP%]{display:flex;flex-direction:row;border:1px solid var(--border-base-100);border-radius:6px;align-items:center;justify-content:center}.session-info-container[_ngcontent-%COMP%]   h5[_ngcontent-%COMP%]{font-weight:600}.session-info-container[_ngcontent-%COMP%]   .reauth-button[_ngcontent-%COMP%]{margin-left:auto}.second-factors-grid[_ngcontent-%COMP%]{display:flex;flex-direction:column;gap:1rem;margin-top:1rem}.second-factor-card[_ngcontent-%COMP%]{position:relative;transition:all .3s ease;border:2px solid transparent;border-radius:.5rem;display:flex;padding:1rem 1.5rem;min-width:0}.second-factor-card.configured[_ngcontent-%COMP%]{border-color:var(--blue-primary)}.second-factor-card.configured[_ngcontent-%COMP%]   .factor-header[_ngcontent-%COMP%]   .factor-icon[_ngcontent-%COMP%]{color:var(--blue-primary)}.second-factor-card.preconfigured[_ngcontent-%COMP%]{border-color:#7fbcec}.second-factor-card.preconfigured[_ngcontent-%COMP%]   .factor-header[_ngcontent-%COMP%]   .factor-icon[_ngcontent-%COMP%]{color:#7fbcec}.second-factor-card.preconfigured[_ngcontent-%COMP%]   .factor-actions[_ngcontent-%COMP%]     .p-button{color:#7fbcec}.second-factor-card[_ngcontent-%COMP%]   .default-label[_ngcontent-%COMP%]{background-color:var(--blue-500);color:var(--text-color-primary);border-radius:.375rem;padding:.25rem .5rem;font-size:.875rem;flex-shrink:0;white-space:nowrap}.second-factor-card.disabled[_ngcontent-%COMP%]{opacity:.6;pointer-events:none}.second-factor-card.clickable[_ngcontent-%COMP%]{cursor:pointer;border-color:var(--grey-300)}.second-factor-card.clickable[_ngcontent-%COMP%]:hover{border-color:var(--blue-primary);background-color:var(--blue-300);box-shadow:0 4px 12px #007bff26}.second-factor-card.clickable[_ngcontent-%COMP%]:hover   .factor-icon[_ngcontent-%COMP%], .second-factor-card.clickable[_ngcontent-%COMP%]:hover   .configure-hint[_ngcontent-%COMP%]{color:var(--blue-primary)}.second-factor-card.clickable[_ngcontent-%COMP%]:hover   .configure-hint[_ngcontent-%COMP%]   i[_ngcontent-%COMP%]{transform:scale(1.1)}.second-factor-card[_ngcontent-%COMP%]:hover:not(.disabled):not(.clickable){box-shadow:0 4px 12px #0000001a}.factor-header[_ngcontent-%COMP%]{display:flex;align-items:center;width:100%;gap:.75rem;min-height:2.5rem}.factor-header[_ngcontent-%COMP%]   .factor-icon[_ngcontent-%COMP%]{font-size:1.5rem;color:var(--grey-600);flex-shrink:0}.factor-header[_ngcontent-%COMP%]   .factor-name[_ngcontent-%COMP%]{margin:0;font-size:1.1rem;font-weight:600;flex:0 1 auto;min-width:0;word-break:break-word;overflow-wrap:break-word}.factor-header[_ngcontent-%COMP%]   .configure-hint[_ngcontent-%COMP%]{margin-left:auto}.factor-actions[_ngcontent-%COMP%]{display:flex;gap:.5rem;align-items:center;margin-left:auto;flex-shrink:0}.factor-actions[_ngcontent-%COMP%]     .p-button{border:0;border-radius:1rem;font-size:1rem}.configure-hint[_ngcontent-%COMP%]{display:flex;align-items:center;justify-content:center;gap:.5rem;color:var(--grey-600);font-size:.8rem;padding:.25rem .5rem;border-radius:.375rem;background-color:var(--grey-100);border:1px dashed var(--grey-300);transition:all .3s ease;text-align:center;white-space:nowrap}.configure-hint[_ngcontent-%COMP%]   i[_ngcontent-%COMP%]{font-size:.8rem;transition:transform .3s ease}.configure-hint[_ngcontent-%COMP%]   span[_ngcontent-%COMP%]{font-weight:500}.factor-warning[_ngcontent-%COMP%]     .p-messages{margin:0}.factor-warning[_ngcontent-%COMP%]     .p-messages .p-message{padding:.5rem;font-size:.8rem}.configuration-panel[_ngcontent-%COMP%]{margin-top:2rem}.configuration-panel[_ngcontent-%COMP%]   .p-card[_ngcontent-%COMP%]{border-left:4px solid var(--blue-primary)}.configuration-panel[_ngcontent-%COMP%]   h4[_ngcontent-%COMP%]{color:var(--blue-primary);margin-bottom:1rem;display:flex;align-items:center;gap:.5rem}.configuration-panel[_ngcontent-%COMP%]   h4[_ngcontent-%COMP%]:before{content:"";width:8px;height:8px;background-color:var(--blue-primary);border-radius:50%;animation:_ngcontent-%COMP%_pulse 2s infinite}@keyframes _ngcontent-%COMP%_pulse{0%{opacity:1}50%{opacity:.5}to{opacity:1}}.session-info-container[_ngcontent-%COMP%]{border-left:4px solid var(--yellow-primary)}.session-info-container[_ngcontent-%COMP%]   .reauth-button[_ngcontent-%COMP%]{margin-top:1rem}.configuration-title[_ngcontent-%COMP%]{gap:8px}.configuration-title[_ngcontent-%COMP%]     .p-button{background:transparent;border:none;padding:0}  .p-stepper-nav{display:none}.two-factor-form-wrapper[_ngcontent-%COMP%]{position:relative}.two-factor-form-wrapper.disabled[_ngcontent-%COMP%]{pointer-events:none;opacity:.5;-webkit-user-select:none;user-select:none}.two-factor-form-wrapper.disabled[_ngcontent-%COMP%]:after{content:"";position:absolute;inset:0;background-color:#8080801a;border-radius:.5rem;cursor:not-allowed}@media(max-width:768px){.factor-actions[_ngcontent-%COMP%]     .p-button{min-width:auto;flex:none}}']});let e=c;return e})()});export{Gn as a,qi as b};
