import{Tb as c,be as p}from"./chunk-WL5U2YIT.js";import{e as f}from"./chunk-ADEKKGI2.js";var u,m=f(()=>{p();u=(()=>{let e=class e{transform(r,i,o){let a=n=>n.toLocaleLowerCase().normalize("NFD").replace(/[\u0300-\u036f]/g,""),s=o?a(o):null;return s?r.filter(n=>a(n[i]).indexOf(s)!==-1):r}};e.\u0275fac=function(i){return new(i||e)},e.\u0275pipe=c({name:"entryFilter",type:e,pure:!0});let t=e;return t})()});export{u as a,m as b};
