import{a as w,b as S}from"./chunk-3E7FAEEN.js";import{a as o,b as D}from"./chunk-A22EQSF3.js";import{D as d,E as R,n as c,o as f}from"./chunk-I7GW4F3B.js";import{Db as t,J as s,Sa as l,Sb as a,Ub as h,be as m,ia as n}from"./chunk-WL5U2YIT.js";import{e as p}from"./chunk-ADEKKGI2.js";var I,v=p(()=>{m();f();D();S();l();R();m();I=(()=>{let i=class i extends w{constructor(){super(),this.onAdd=new t,this.onChangePasswordRow=new t,this.onRefresh=new t,this.onViewRow=new t,this.onEditRow=new t,this.onDeleteRow=new t,this.onDuplicateRow=new t,this.storageService=o.injector.get(c),this.currentUserService=o.injector.get(d)}ngAfterContentInit(){this.currentUserService.webSettingsChanged.pipe(n(this.destroyed$),s(e=>!!e)).subscribe(e=>{this.defaultPageSize=e.defaultPageSize,this.dateFormatToDisplay=this.currentUserService.displayDateFormat,this.timeFormatToDisplay=this.currentUserService.displayTimeFormat,this.dateTimeFormatToDisplay=this.currentUserService.displayDateTimeFormat})}add(){this.onAdd.emit(null)}changePassword(e){this.onChangePasswordRow.emit(e)}view(e){this.onViewRow.emit(e)}edit(e){this.onEditRow.emit(e)}delete(e){this.onDeleteRow.emit(e)}refresh(){this.onRefresh.emit(null)}};i.\u0275fac=function(u){return new(u||i)},i.\u0275dir=a({type:i,inputs:{items:"items"},outputs:{onEditRow:"onEditRow",onDeleteRow:"onDeleteRow"},features:[h]});let r=i;return r})()});export{I as a,v as b};
