import{a as z,b as q}from"./chunk-C5K3KYL5.js";import{a as k,b as j}from"./chunk-NAQVZCUC.js";import{a as Q,b as R}from"./chunk-6POW7SSJ.js";import{Ha as P,Ia as M,ta as F,wb as N,zb as A}from"./chunk-V2ECYACM.js";import{Ha as w,La as $}from"./chunk-5E3JCGAH.js";import{b as O,c as V}from"./chunk-YBNTOQCK.js";import{Ad as m,Bd as C,Fd as B,Jc as E,Nc as I,Oc as T,Pc as y,Qb as h,Wb as f,Yc as a,Zc as c,_c as p,be as D,qd as u,tc as _,uc as e,vc as n,wc as x,ya as v,yb as i,zd as o}from"./chunk-WL5U2YIT.js";import{e as U}from"./chunk-ADEKKGI2.js";function G(t,l){t&1&&(e(0,"tr",8),x(1,"th"),e(2,"th"),a(3),o(4,"translate"),n(),e(5,"th"),a(6),o(7,"translate"),n()()),t&2&&(i(3),c(m(4,2,"lblIssuedTo")),i(3),c(m(7,4,"lblIssuedBy")))}function H(t,l){if(t&1&&(e(0,"tr")(1,"td"),a(2),o(3,"translate"),n(),e(4,"td")(5,"p"),a(6),n()(),e(7,"td")(8,"p"),a(9),n()()(),e(10,"tr")(11,"td"),a(12),o(13,"translate"),n(),e(14,"td"),a(15),n(),e(16,"td"),a(17),n()(),e(18,"tr")(19,"td"),a(20),o(21,"translate"),n(),e(22,"td"),a(23),n(),e(24,"td"),a(25),n()()),t&2){let r=l.$implicit;i(2),p(" ",m(3,9,"lblCommonName")," "),i(4),c(r.issuedToCN),i(3),c(r.issuedByCN),i(3),p(" ",m(13,11,"lblOrganization")," "),i(3),p(" ",r.issuedToO," "),i(2),p(" ",r.issuedByO," "),i(3),p(" ",m(21,13,"lblOrganizationalUnit")," "),i(3),p(" ",r.issuedToOU," "),i(2),p(" ",r.issuedByOU," ")}}function J(t,l){t&1&&(e(0,"tr",8),x(1,"th"),e(2,"th"),a(3),o(4,"translate"),n(),e(5,"th"),a(6),o(7,"translate"),n()()),t&2&&(i(3),c(m(4,2,"lblExpiresOn")),i(3),c(m(7,4,"lblIssuedOn")))}function K(t,l){if(t&1&&(e(0,"tr")(1,"td"),a(2),o(3,"translate"),n(),e(4,"td"),a(5),o(6,"dateFormat"),n(),e(7,"td"),a(8),o(9,"dateFormat"),n()()),t&2){let r=l.$implicit;i(2),p(" ",m(3,3,"lblValidityPeriod")," "),i(3),p(" ",C(6,5,r.expiresOn,"datetime")," "),i(3),p(" ",C(9,8,r.issuedOn,"datetime")," ")}}function W(t,l){t&1&&(e(0,"tr",8),x(1,"th"),e(2,"th"),a(3),o(4,"translate"),n()()),t&2&&(i(3),c(m(4,1,"lblThumbprint")))}function X(t,l){if(t&1&&(e(0,"tr")(1,"td"),a(2),o(3,"translate"),n(),e(4,"td")(5,"p"),a(6),n()()()),t&2){let r=l.$implicit;i(2),p(" ",m(3,2,"lblThumbprint")," "),i(4),c(r.thumbprint)}}function Y(t,l){if(t&1&&(e(0,"div",1),x(1,"i",2),e(2,"h2",3),a(3),o(4,"translate"),n()(),e(5,"p-table",4),f(6,G,8,6,"ng-template",5)(7,H,26,15,"ng-template",6),n(),e(8,"div",7)(9,"p-table",4),f(10,J,8,6,"ng-template",5)(11,K,10,11,"ng-template",6),n()(),e(12,"div",7)(13,"p-table",4),f(14,W,5,3,"ng-template",5)(15,X,7,4,"ng-template",6),n()()),t&2){let r=E();i(3),c(m(4,4,"lblCertificateCouldNotBeVerified")),i(2),_("value",u(6,g,r.certificate)),i(4),_("value",u(8,g,r.certificate)),i(4),_("value",u(10,g,r.certificate))}}var L,g,se,Z=U(()=>{D();q();R();M();j();A();V();D();M();$();L=["certificateContent"],g=t=>[t];se=(()=>{let l=class l{constructor(){this.certificateConfirmationService=v(z),this.dvlConfirmationService=v(N),this.translatorService=v(O)}ngOnInit(){this.certificateConfirmationService.showCertificateDialogObservable.subscribe(s=>{this.certificate=s.certificate,this.dvlConfirmationService.confirm({intent:"warning",title:this.translatorService.translate("lblCertificate"),message:"",width:"580px",contentTemplate:this.certificateContent,acceptLabel:this.translatorService.translate("lblContinueAndSave"),accept:()=>s.acceptFunction(this.certificate)})})}};l.\u0275fac=function(d){return new(d||l)},l.\u0275cmp=h({type:l,selectors:[["dvls-certificate-confirmation-dialog"]],viewQuery:function(d,S){if(d&1&&I(L,7),d&2){let b;T(b=y())&&(S.certificateContent=b.first)}},decls:2,vars:0,consts:[["certificateContent",""],[1,"text-center","pb-5"],[1,"di","dvl-icon-warning","alert"],[1,"text-lg"],["styleClass","p-datatable-primary",3,"value"],["pTemplate","header"],["pTemplate","body"],[1,"mt-3"],[1,"header"]],template:function(d,S){d&1&&f(0,Y,16,12,"ng-template",null,0,B)},dependencies:[P,F,w,Q,k],styles:[".alert[_ngcontent-%COMP%]{color:gold;font-size:50px;display:block;margin-bottom:10px}  .certificat-dialog .header>th{background:var(--dialog-header-confirmation-background-color)}"]});let t=l;return t})()});export{se as a,Z as b};
