import{wh as s,xh as d}from"./chunk-BPZQKZKD.js";import{be as p,h as r,na as h,ta as c}from"./chunk-WL5U2YIT.js";import{e as u}from"./chunk-ADEKKGI2.js";var f,C=u(()=>{h();d();p();f=(()=>{let e=class e{constructor(){this.hasOtpSubject=new r(!1),this.currentConnectionSubject=new r(null),this.currentConnectionRequest=this.currentConnectionSubject.asObservable()}get hasOTP(){return this.hasOtpSubject.value}getCurrentConnection(){return this.currentConnectionRequest}getCurrentConnectionSnapshot(){return this.currentConnectionSubject.getValue()}setCurrentConnection(t,n=!1){let a=this.getCurrentConnectionSnapshot(),i=!n&&a?.connection&&t&&t.id===a?.connection.id;t&&this.setHasOTP(t),this.currentConnectionSubject.next({connection:t,isAnUpdate:i})}setHasOTP(t){let n=t.data.otpKeyItem?.hasSensitiveData||!!t.data.otpConnectionID||!!t.data.otpPrivateVaultSearchString||t.data.otpSourceMode===s.CurrentSession||t.data.otpSourceMode===s.Inherited;this.hasOtpSubject.next(n)}};e.\u0275fac=function(n){return new(n||e)},e.\u0275prov=c({token:e,factory:e.\u0275fac,providedIn:"root"});let o=e;return o})()});export{f as a,C as b};
