import{Qb as o,be as r}from"./chunk-WL5U2YIT.js";import{e as c}from"./chunk-ADEKKGI2.js";var m,p=c(()=>{r();m=(()=>{let e=class e{};e.\u0275fac=function(n){return new(n||e)},e.\u0275cmp=o({type:e,selectors:[["ng-component"]],decls:0,vars:0,template:function(n,s){},encapsulation:2});let t=e;return t})()});p();export{m as PamTreeContainerComponent};
