import{a as t,b as s}from"./chunk-4ERZBM5I.js";import{e as c}from"./chunk-ADEKKGI2.js";var p,r=c(()=>{s();p=(()=>{let i=class i{static getBuiltInTemplateIcon(l){switch(l?.toLowerCase()){case t.ciscoBuiltInTemplateId:return i.cisco;case t.mySqlUserBuiltInTemplateId:return i.mySQL;case t.oracleBuiltInTemplateId:return i.oracle;default:return null}}};i.domainUser="dvl-icon-domain-provider",i.localUser="dvl-icon-ssh-provider",i.sqlServer="dvl-icon-sql-provider",i.windowsLocalAccount="dvl-icon-windows-provider",i.azureADUser="dvl-icon-entralid-provider",i.awsIAMUser="dvl-icon-aws-provider",i.sshKey="dvl-icon-ssh-key-provider",i.postgreSQL="dvl-icon-postgres-provider",i.mongoDb="dvl-icon-mongodb-provider",i.cisco="dvl-icon-cisco-provider",i.mySQL="dvl-icon-mysql-provider",i.oracle="dvl-icon-oracle-provider";let e=i;return e})()});export{p as a,r as b};
