import{a as o,b as i}from"./chunk-UKCYLQ3R.js";import{be as a,ta as e}from"./chunk-WL5U2YIT.js";import{e as n}from"./chunk-ADEKKGI2.js";var u,s=n(()=>{i();a();u=(()=>{let t=class t extends o{constructor(){super()}};t.\u0275fac=function(c){return new(c||t)},t.\u0275prov=e({token:t,factory:t.\u0275fac,providedIn:"root"});let r=t;return r})()});export{u as a,s as b};
