import{a as c,d as J}from"./chunk-LOP76GWT.js";import{a as h,b as I}from"./chunk-VT6VEUJB.js";import{a as P,b as R,c as b,d as j}from"./chunk-P6VBQ2IK.js";import{c as S,d as O}from"./chunk-WEJDWTQW.js";import"./chunk-DJLFA677.js";import"./chunk-NEKDTWKR.js";import{a as l,b as w}from"./chunk-4DX65HLL.js";import"./chunk-Q2CF2JQV.js";import"./chunk-FAHXDSMM.js";import"./chunk-THQOQSZV.js";import"./chunk-4BLCQKUP.js";import"./chunk-J5QU44UY.js";import"./chunk-7YSPVYHZ.js";import"./chunk-LCZQRCKX.js";import"./chunk-MFW36WEU.js";import"./chunk-7PFZXDIW.js";import"./chunk-YKFXM3J7.js";import"./chunk-AVRBEEAA.js";import"./chunk-4ERZBM5I.js";import"./chunk-DJ546A6R.js";import"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-AJ7ODGYR.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import{cc as s,dc as g}from"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import{Sa as y,be as A,ha as v,ka as f,ta as u,x as d,xa as n}from"./chunk-WL5U2YIT.js";import{e as p}from"./chunk-ADEKKGI2.js";var m,C=p(()=>{y();A();O();R();m=(()=>{let e=class e{constructor(i,r){this.networkDiscoveryService=i,this.discoveryJobService=r}resolve(i,r){let D=i.paramMap.get("id"),o;return this.discoveryJobService.getJob(D).pipe(f(a=>o=a),v(()=>this.networkDiscoveryService.get(o.scanConfigurationID)),d(a=>({scanJob:o,scanConfiguration:a})))}};e.\u0275fac=function(r){return new(r||e)(n(S),n(P))},e.\u0275prov=u({token:e,factory:e.\u0275fac,providedIn:"root"});let t=e;return t})()});var q,V=p(()=>{w();I();C();j();J();g();q=[{path:"",canActivate:[l,h],children:[{path:"scan-list",loadComponent:()=>import("./chunk-CNE5BROJ.js").then(t=>t.ScansDashboardComponent),canActivate:[c],data:{permissions:[s.PamProvidersScanView],isPamProviderDependant:!0}},{path:"scan-result/:id",loadComponent:()=>import("./chunk-35DC3BQ3.js").then(t=>t.ScanResultListPageComponent),resolve:{scanResultElements:m},providers:[b,m],canActivate:[c],data:{permissions:[s.PamProvidersScanResultsView],isPamProviderDependant:!0}},{path:"",redirectTo:"scan-list",pathMatch:"full"}]}]});V();export{q as ACCOUNT_DISCOVERY_ROUTES};
