import{b as l,c as u}from"./chunk-YBNTOQCK.js";import{be as f,ta as s,xa as i}from"./chunk-WL5U2YIT.js";import{e as o}from"./chunk-ADEKKGI2.js";var m,h=o(()=>{f();u();m=(()=>{let t=class t{constructor(a){this.translatorService=a,this.translate=e=>this.translatorService.translate(e)}addDefaultValue(a,e,c=!1){return[{value:a.defaultValue,label:`${this.translate(c?"lblRoot":"lblDefault")} (${this.translate(a.resolvedDefaultValueKey)})`},...e.filter(n=>n.value!==a.defaultValue)]}};t.\u0275fac=function(e){return new(e||t)(i(l))},t.\u0275prov=s({token:t,factory:t.\u0275fac,providedIn:"root"});let r=t;return r})()});export{m as a,h as b};
