import{be as l,h as r,na as u,ta as c}from"./chunk-WL5U2YIT.js";import{e as i}from"./chunk-ADEKKGI2.js";var b,s=i(()=>{u();l();b=(()=>{let t=class t{constructor(){this.modelSubject=new r(null)}getModelSubject(){return this.modelSubject}setModelSubject(o){this.modelSubject.next(o)}};t.\u0275fac=function(n){return new(n||t)},t.\u0275prov=c({token:t,factory:t.\u0275fac,providedIn:"root"});let e=t;return e})()});export{b as a,s as b};
