import{a as f,b as g}from"./chunk-DJ546A6R.js";import{D as p,E as b}from"./chunk-I7GW4F3B.js";import{c as n,d}from"./chunk-RWCAFOHA.js";import{Gk as m,Hk as A}from"./chunk-BPZQKZKD.js";import{b as c,c as S}from"./chunk-YBNTOQCK.js";import{Sa as u,be as j,ta as a,x as o,xa as e}from"./chunk-WL5U2YIT.js";import{e as h}from"./chunk-ADEKKGI2.js";var F,C=h(()=>{u();g();j();A();S();b();d();F=(()=>{let t=class t extends f{constructor(i,r,l,v){super(r,v,l),this.assetServices=i}getAll(i=!1){return this.getCache(i,this.assetServices.AdministrativePermissionDefinitionsGetAll().pipe(o(r=>r.data)))}};t.\u0275fac=function(r){return new(r||t)(e(m),e(c),e(p),e(n))},t.\u0275prov=a({token:t,factory:t.\u0275fac,providedIn:"root"});let s=t;return s})()});export{F as a,C as b};
