import{a as h,b as v}from"./chunk-3E7FAEEN.js";import{D as d,E as S}from"./chunk-I7GW4F3B.js";import{a as c,b as f}from"./chunk-MOK7XOAA.js";import{B as a,I as b}from"./chunk-HTXYTVN4.js";import{Jb as e,Sa as p,Sb as n,Ub as u,be as g,ia as o}from"./chunk-WL5U2YIT.js";import{e as l}from"./chunk-ADEKKGI2.js";var L,P=l(()=>{v();p();g();S();b();f();L=(()=>{let t=class t extends h{constructor(i,s,m){super(),this.currentUserService=i,this.route=s,this.longOperationIndicatorService=m,this.defaultSortOrder=1}loadList(){this.subscription&&(this.subscription.unsubscribe(),this.subscription=null),this.longOperationIndicatorService.showIndicator(),this.getList()}buildParamsFromQueryParams(i){this.parameters=this.buildQueryParams(i),this.paging=this.buildPagingFromQueryParams(i)}subscribeToQueryParams(){this.route.queryParams.pipe(o(this.destroyed$)).subscribe(i=>{this.buildParamsFromQueryParams(i),this.loadList()})}buildPagingFromQueryParams(i){return{pageNumber:i.pagenumber&&(!this.totalCount||this.paging.pageSize<this.totalCount)?+i.pagenumber:1,pageSize:+i.pagesize||this.currentUserService.webSettingsSnapshot.defaultPageSize,sortOrder:i&&i.sortorder?+i.sortorder:this.defaultSortOrder,sortField:i.sortfield}}};t.\u0275fac=function(s){return new(s||t)(e(d),e(a),e(c))},t.\u0275dir=n({type:t,features:[u]});let r=t;return r})()});export{L as a,P as b};
