import{a as u,b as k}from"./chunk-6POW7SSJ.js";import{cb as f,zb as h}from"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-5E3JCGAH.js";import"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import{Ad as o,Hc as x,Qb as s,Yc as c,_c as d,be as y,tc as p,uc as t,vc as i,wc as m,yb as l,zd as r}from"./chunk-WL5U2YIT.js";import{e as g}from"./chunk-ADEKKGI2.js";var E,w=g(()=>{h();k();y();E=(()=>{let e=class e{goBack(){window.history.back()}};e.\u0275fac=function(n){return new(n||e)},e.\u0275cmp=s({type:e,selectors:[["sd-access-denied"]],decls:12,vars:9,consts:[[1,"flex","min-h-screen","w-full","items-center","justify-center","bg-[var(--bg-100)]","px-6","py-10"],[1,"flex","w-full","max-w-[520px]","flex-col","items-center","text-center"],["aria-hidden","true",1,"mb-5","flex","size-16","items-center","justify-center","rounded-full","border","border-[var(--border-color)]","bg-[var(--fill-200)]","text-[var(--text-danger)]"],[1,"di","dvl-icon-lock-bold","text-3xl"],[1,"text-xl","font-semibold","leading-tight","text-400"],[1,"mt-2","max-w-[420px]","text-sm","leading-5","text-200"],["variant","primary","size","md",1,"mt-6",3,"onClick","label"]],template:function(n,b){n&1&&(t(0,"main",0)(1,"section",1)(2,"div",2),m(3,"i",3),i(),t(4,"h1",4),c(5),r(6,"translate"),i(),t(7,"p",5),c(8),r(9,"translate"),i(),t(10,"dvl-button",6),r(11,"translate"),x("onClick",function(){return b.goBack()}),i()()()),n&2&&(l(5),d(" ",o(6,3,"AccessDenied")," "),l(3),d(" ",o(9,5,"ShowAccessDenied")," "),l(2),p("label",o(11,7,"lblBack")))},dependencies:[f,u],encapsulation:2});let a=e;return a})()});w();export{E as AccessDeniedComponent};
