import{a as v,b as h}from"./chunk-RJ7GQMQE.js";import{a as f,b}from"./chunk-UKCYLQ3R.js";import{be as a,g as p,na as m,ta as i,xa as n}from"./chunk-WL5U2YIT.js";import{a as c,e as s}from"./chunk-ADEKKGI2.js";var l,u=s(()=>{m();a();l=(()=>{let e=class e{constructor(){this.viewSubject=new p,this.viewRequest=this.viewSubject.asObservable()}view(t){this.viewSubject.next(t)}};e.\u0275fac=function(o){return new(o||e)},e.\u0275prov=i({token:e,factory:e.\u0275fac,providedIn:"root"});let r=e;return r})()});var x,S=s(()=>{b();h();a();u();x=(()=>{let e=class e extends f{constructor(t){super(),this.providerTypeSelectorService=t}create(t){t.type?super.create(c({data:t.type,options:{providerTemplate:t.providerTemplate}},t)):this.providerTypeSelectorService.view({acceptProvider:(o,d)=>super.create(c({data:o,options:{providerTemplate:d}},t)),selectorType:v.Provider})}};e.\u0275fac=function(o){return new(o||e)(n(l))},e.\u0275prov=i({token:e,factory:e.\u0275fac,providedIn:"root"});let r=e;return r})()});export{l as a,u as b,x as c,S as d};
