import{c as v,d as x}from"./chunk-3BAJ7JGB.js";import{a as f,b as k}from"./chunk-SM7EQ7ST.js";import{c as h,d as b}from"./chunk-RWCAFOHA.js";import{Gk as S,Hk as w}from"./chunk-BPZQKZKD.js";import{Da as d,La as A}from"./chunk-5E3JCGAH.js";import{b as m,c as T}from"./chunk-YBNTOQCK.js";import{Sa as y,be as G,ka as p,ta as u,x as c,xa as s}from"./chunk-WL5U2YIT.js";import{e as j}from"./chunk-ADEKKGI2.js";var q,C=j(()=>{y();x();k();G();b();T();w();A();q=(()=>{let r=class r extends f{constructor(i,e,t,a){super(e,i),this.assetServices=t,this.messageService=a}getAzureRoles(i,e){return this.assetServices.GetRoleTemplates(i||null,e.clientId||null,e.tenantId||null,e.secretClientKey||null).pipe(p(t=>this.handleGetApiResult(t)),c(t=>this.returnWhenSuccessful(t,()=>t.data)))}getPagedAzureGroups(i,e,t,a,g,I){let n=new v;return n.pageSize=a,n.nextPageToken=g||null,n.filter=I||null,this.assetServices.GetGroupsPaged(n,t,i||null,e.clientId||null,e.tenantId||null,e.secretClientKey||null,e.linkedCredentialId||null).pipe(p(o=>this.executeBasedOnResult(o,()=>void 0,()=>this.showErrorToast())),c(o=>this.returnWhenSuccessful(o,()=>o.data)))}showErrorToast(){this.messageService.add({key:"globalToast",severity:"error",summary:this.translatorService.translate("Failed"),detail:this.translatorService.translate("ConnectionFailed")})}};r.\u0275fac=function(e){return new(e||r)(s(h),s(m),s(S),s(d))},r.\u0275prov=u({token:r,factory:r.\u0275fac,providedIn:"root"});let l=r;return l})()});export{q as a,C as b};
