import{be as c,ta as h}from"./chunk-WL5U2YIT.js";import{e as i}from"./chunk-ADEKKGI2.js";var s,r=i(()=>{s=(function(e){return e[e.Unknown=0]="Unknown",e[e.Email=1]="Email",e[e.SecureMessage=2]="SecureMessage",e[e.Sms=3]="Sms",e[e.Syslog=4]="Syslog",e[e.User=5]="User",e[e.System=6]="System",e})(s||{});(function(e){function t(){return"SubscriberType"}e.getClass=t;function g(o){let l="";return typeof e.getClass=="function"&&(l=e.getClass()),l+"_"+e[o]}e.getEnumKey=g})(s||(s={}))});var n,m=i(()=>{n=class{constructor(t=null){t?(this.id=t.id,this.name=t.name,this.type=t.type,this.subscriptions=t.subscriptions||[],this.groups=t.groups||[]):(this.subscriptions=[],this.groups=[])}}});var a,f=i(()=>{m();r();a=class extends n{constructor(t=null){super(t),this.type=s.Syslog,t?this.syslogContent=t.syslogContent||{}:this.syslogContent={}}get hostname(){return this.syslogContent.host}set hostname(t){this.syslogContent.host=t}get port(){return this.syslogContent.port}set port(t){this.syslogContent.port=Number(t)}get protocol(){return this.syslogContent.protocol}set protocol(t){this.syslogContent.protocol=t}get useDefaultSettings(){return this.syslogContent.useDefaultSettings}set useDefaultSettings(t){this.syslogContent.useDefaultSettings=t}}});var u,p=i(()=>{m();r();u=class extends n{constructor(t=null){super(t),this.type=s.Email,t?this.emailContent=t.emailContent||{}:this.emailContent={}}get emailAddress(){return this.emailContent.email}set emailAddress(t){this.emailContent.email=t}get recipient(){return this.emailContent.recipientName}set recipient(t){this.emailContent.recipientName=t}}});var A,C=i(()=>{m();p();f();r();c();A=(()=>{let t=class t{toSubscriber(o){if(!o)return null;switch(o.type){case s.Email:return new u(o);case s.Syslog:return new a(o);default:return new n(o)}}toSubscribers(o){return(o||[]).map(this.toSubscriber)}};t.\u0275fac=function(l){return new(l||t)},t.\u0275prov=h({token:t,factory:t.\u0275fac,providedIn:"root"});let e=t;return e})()});export{s as a,r as b,a as c,f as d,A as e,C as f};
