import{be as u,g as s,na as a,ta as r}from"./chunk-WL5U2YIT.js";import{e as n}from"./chunk-ADEKKGI2.js";var l,c=n(()=>{a();u();l=(()=>{let e=class e{constructor(){this.responseRequestSource=new s,this.createRequestSource=new s,this.viewPermissionSetDetailsRequestSource=new s,this.responseRequest=this.responseRequestSource.asObservable(),this.createRequest=this.createRequestSource.asObservable(),this.viewPermissionSetDetailsRequest=this.viewPermissionSetDetailsRequestSource.asObservable()}editResponse(t){this.responseRequestSource.next(t)}create(t){this.createRequestSource.next(t)}viewPermissionSetDetails(t){this.viewPermissionSetDetailsRequestSource.next(t)}};e.\u0275fac=function(o){return new(o||e)},e.\u0275prov=r({token:e,factory:e.\u0275fac,providedIn:"root"});let i=e;return i})()});export{l as a,c as b};
