import{a as ee,b as de}from"./chunk-KREWYSBO.js";import{b as $,c as ce}from"./chunk-HIOAAE7A.js";import{a as Z,b as ue}from"./chunk-6POW7SSJ.js";import{ma as J,na as K,oa as X,q as H,s as me}from"./chunk-V2ECYACM.js";import{C as V,E as G,b as k,f as Q,m as R}from"./chunk-JPHJ3OD7.js";import{a as U,b as ae}from"./chunk-QGVT6DPT.js";import{Ca as Y,Ha as z,La as pe}from"./chunk-5E3JCGAH.js";import{b as q,c as se}from"./chunk-YBNTOQCK.js";import{K as oe,r as P}from"./chunk-LDWBA6DZ.js";import{Ad as d,Cc as B,Hc as u,Jb as S,Jc as E,Mc as O,Oc as j,Pc as W,Qb as w,R as M,Sa as le,Ub as A,Uc as D,W as F,Wb as I,Yc as b,Zc as f,be as N,cd as g,dd as h,ed as C,g as T,ia as y,mc as x,na as re,oc as L,tc as s,uc as p,vc as m,ya as v,yb as o,zd as c}from"./chunk-WL5U2YIT.js";import{e as ne}from"./chunk-ADEKKGI2.js";function be(r,l){r&1&&B(0)}function fe(r,l){if(r&1&&I(0,be,1,0,"ng-container",5),r&2){let ie=E();s("ngTemplateOutlet",ie.centerTemplate)}}var _,te,De,ge=ne(()=>{N();pe();le();re();ae();oe();ue();ce();G();X();me();de();N();se();G();X();_="boolean",te=!1,De=(()=>{let l=class l extends U{constructor(t){super(),this.translatorService=t,this.isMemberField="isMember",this.isMemberLabel="lblIsMember",this.filterSubject=new T,this.filterService=v(Y),te||(this.filterService.register(_,(n,e)=>e==null?!0:!!n===e),te=!0),this.isMemberOptions=[{label:this.translatorService.translate("lblYes"),value:"true"},{label:this.translatorService.translate("lblNo"),value:"false"}],this.subscribeToFilterValue()}ngAfterContentInit(){this.templates.forEach(t=>{t.getType()==="centerTemplate"&&(this.centerTemplate=t.template)})}onClearFilterClick(){this.textFilter="",this.table.filterGlobal(null,null)}onTextChange(t){this.filterSubject.next(t.target.value)}onIsMemberChange(t){t==null?this.table.filter(null,this.isMemberField,_):this.table.filter(t==="true",this.isMemberField,_)}subscribeToFilterValue(){this.filterSubject.pipe(F(),M(500),y(this.destroyed$)).subscribe(t=>this.table.filterGlobal(t,"contains"))}};l.\u0275fac=function(n){return new(n||l)(S(q))},l.\u0275cmp=w({type:l,selectors:[["dvls-table-filter-assignments"]],contentQueries:function(n,e,a){if(n&1&&O(a,z,4),n&2){let i;j(i=W())&&(e.templates=i)}},hostAttrs:["data-readonly-exempt","true"],inputs:{table:"table",isMemberField:"isMemberField",isMemberLabel:"isMemberLabel"},features:[A],decls:13,vars:18,consts:[[1,"flex","gap-4","mb-4"],[1,"form-group"],["pInputText","",3,"onClear","ngModelChange","input","showClear","fluid","ngModel"],[1,"form-group","flex-1"],["styleClass","form-control",3,"onChange","ngModelChange","options","showClear","ngModel","placeholder"],[4,"ngTemplateOutlet"]],template:function(n,e){n&1&&(p(0,"div",0)(1,"div",1)(2,"label"),b(3),c(4,"translate"),m(),p(5,"input",2),u("onClear",function(){return e.onClearFilterClick()}),C("ngModelChange",function(i){return h(e.textFilter,i)||(e.textFilter=i),i}),u("input",function(i){return e.onTextChange(i)}),m()(),x(6,fe,1,1,"ng-container"),p(7,"div",3)(8,"label"),b(9),c(10,"translate"),m(),p(11,"p-select",4),c(12,"translate"),u("onChange",function(i){return e.onIsMemberChange(i.value)}),C("ngModelChange",function(i){return h(e.isMember,i)||(e.isMember=i),i}),m()()()),n&2&&(o(),D("flex",e.centerTemplate?"1":"2"),o(2),f(d(4,12,"lblFilter")),o(2),s("showClear",!0)("fluid",!0),g("ngModel",e.textFilter),o(),L(e.centerTemplate?6:-1),o(3),f(d(10,14,e.isMemberLabel)),o(2),s("options",e.isMemberOptions)("showClear",!0),g("ngModel",e.isMember),s("placeholder",d(12,16,"lblSelect")))},dependencies:[$,V,k,Q,R,P,K,J,H,ee,Z],encapsulation:2});let r=l;return r})()});export{De as a,ge as b};
