import{Sa as m,be as d,ea as n,ka as h,ta as p}from"./chunk-WL5U2YIT.js";import{e as b}from"./chunk-ADEKKGI2.js";var v,u=b(()=>{m();d();v=(()=>{let e=class e{constructor(){this.cache=new Map}get(t,r,i=6e4){let s=Date.now(),o=this.cache.get(t);if(o&&o.expiry>s)return o.observable;{let a=r().pipe(n(1),h(()=>{let f=s+i;this.cache.set(t,{observable:a,expiry:f})})),l=s+i;return this.cache.set(t,{observable:a,expiry:l}),a}}clearCache(t){t?this.cache.delete(t):this.cache.clear()}};e.\u0275fac=function(r){return new(r||e)},e.\u0275prov=p({token:e,factory:e.\u0275fac,providedIn:"root"});let c=e;return c})()});export{v as a,u as b};
