import{a}from"./chunk-YBNTOQCK.js";import{Tb as m,be as l}from"./chunk-WL5U2YIT.js";import{e as c,h as p}from"./chunk-ADEKKGI2.js";var o,n,u,d=c(()=>{o=p(a());l();n=o.default,u=(()=>{let e=class e{transform(i,t,f=!1){let s="";return(!t||t?.trim().length===0)&&(t="dddd, MMMM Do YYYY, h:mm:ss a"),i&&i!==""&&(f?s=n(i).format(t):s=n.utc(i).local().format(t)),s}};e.\u0275fac=function(t){return new(t||e)},e.\u0275pipe=m({name:"date",type:e,pure:!1});let r=e;return r})()});export{u as a,d as b};
