import{cb as b,zb as y}from"./chunk-V2ECYACM.js";import{E as k,i as v}from"./chunk-JPHJ3OD7.js";import{Ac as u,Bc as d,Db as o,Hc as C,Jb as a,Qb as c,be as f,tc as s,uc as p,vc as m,yb as r}from"./chunk-WL5U2YIT.js";import{e as g}from"./chunk-ADEKKGI2.js";var H,E=g(()=>{f();y();f();k();H=(()=>{let e=class e{constructor(t){this.cancel=new o,this.onClick=new o,t&&(this.parent=t)}triggerCancel(t){this.cancel.emit(t),this.onClick.emit(t),this.parent&&this.parent.resetForm()}};e.\u0275fac=function(n){return new(n||e)(a(v,9))},e.\u0275cmp=c({type:e,selectors:[["sd-cancel-button"]],inputs:{parent:"parent",label:"label"},outputs:{cancel:"cancel",onClick:"onClick"},decls:2,vars:1,consts:[["type","button","variant","tertiary",3,"onClick","label"]],template:function(n,l){n&1&&(u(0),p(1,"dvl-button",0),C("onClick",function(h){return l.triggerCancel(h)}),m(),d()),n&2&&(r(),s("label",l.label))},dependencies:[b],encapsulation:2});let i=e;return i})()});export{H as a,E as b};
