import{a as o,b as w}from"./chunk-OREOSMUG.js";import{m as f,n as I}from"./chunk-SM7EQ7ST.js";import{Jb as m,Tb as p,be as S}from"./chunk-WL5U2YIT.js";import{e as u}from"./chunk-ADEKKGI2.js";var g,U,h=u(()=>{w();S();I();g={icon:"dvl-icon-account-owner",color:null},U=(()=>{let e=class e{constructor(r){this.serverInformationService=r}transform(r,i=24,a=[],l="di dvl-icon-entry-SampleUser"){let v=t=>this.serverInformationService.privateServerInformation.dataSourceOwner===t.id,c=t=>t.name===r.replace(/^(?:.*?\\)?(.+)$/,"$1"),d=t=>t.filter(c).map(s=>o.fromUserListItem(s,i,null,v(s)?g:null)).find(Boolean);return a.some(c)?d(a):new o({username:r,name:r,size:24,icon:l})}};e.\u0275fac=function(i){return new(i||e)(m(f,16))},e.\u0275pipe=p({name:"getUserAvatarSettings",type:e,pure:!0});let n=e;return n})()});export{g as a,U as b,h as c};
