import{be as i,h as a,na as n,ta as r}from"./chunk-WL5U2YIT.js";import{e as c}from"./chunk-ADEKKGI2.js";var u,g=c(()=>{n();i();u=(()=>{let t=class t{constructor(){this.toggleWhatsNewSubject=new a({visible:!1,section:"releaseNotes"}),this._sectionToShow=null,this.toggleWhatsNewIconSubject=new a(!1)}get toggleWhatsNew$(){return this.toggleWhatsNewSubject.asObservable()}toggleWhatsNew(e=!0,s){this.toggleWhatsNewSubject.next({visible:e,section:s})}get toggleWhatsNewIcon$(){return this.toggleWhatsNewIconSubject.asObservable()}toggleWhatsNewIcon(e=!0){this.toggleWhatsNewIconSubject.next(e)}};t.\u0275fac=function(s){return new(s||t)},t.\u0275prov=r({token:t,factory:t.\u0275fac,providedIn:"root"});let o=t;return o})()});export{u as a,g as b};
