import{a as c}from"./chunk-YBNTOQCK.js";import{Tb as n,be as m}from"./chunk-WL5U2YIT.js";import{e as s,h as a}from"./chunk-ADEKKGI2.js";var o,p,f=s(()=>{o=a(c());m();p=(()=>{let e=class e{transform(t){let r=this.parseDate(t);return r?this.getFromNow(r):""}parseDate(t){let r=o.default.utc(t);return r.isValid()?r:null}getFromNow(t){return t.diff(o.default.utc(),"seconds")>0?o.default.utc().local().fromNow():t.local().fromNow()}};e.\u0275fac=function(r){return new(r||e)},e.\u0275pipe=n({name:"fromNowNoFuture",type:e,pure:!0});let i=e;return i})()});export{p as a,f as b};
