import{be as r,ta as c}from"./chunk-WL5U2YIT.js";import{e as a}from"./chunk-ADEKKGI2.js";var s,i=a(()=>{r();s=(()=>{let e=class e{copy(n){let t=document.createElement("textarea");t.style.position="absolute",t.style.left="10000px",document.body.appendChild(t),t.value=n,t.select(),document.execCommand("copy"),document.body.removeChild(t)}};e.\u0275fac=function(t){return new(t||e)},e.\u0275prov=c({token:e,factory:e.\u0275fac,providedIn:"root"});let o=e;return o})()});export{s as a,i as b};
