import{be as n,g as o,na as c,ta as r}from"./chunk-WL5U2YIT.js";import{e as a}from"./chunk-ADEKKGI2.js";var b,h=a(()=>{c();n();b=(()=>{let t=class t{constructor(){this.showRequest=new o,this.showRequestObservable=this.showRequest.asObservable()}show(s){this.showRequest.next(s)}};t.\u0275fac=function(i){return new(i||t)},t.\u0275prov=r({token:t,factory:t.\u0275fac,providedIn:"root"});let e=t;return e})()});export{b as a,h as b};
