import{be as n,ta as r}from"./chunk-WL5U2YIT.js";import{e as i}from"./chunk-ADEKKGI2.js";var p,a=i(()=>{n();p=(()=>{let t=class t{};t.\u0275fac=function(c){return new(c||t)},t.\u0275prov=r({token:t,factory:t.\u0275fac,providedIn:"root"});let o=t;return o})()});export{p as a,a as b};
