import{$a as A,Y as u,Z as d,_a as m}from"./chunk-THQOQSZV.js";import{a as c,b as P}from"./chunk-6B6CBPYV.js";import{b as l,c as C}from"./chunk-YBNTOQCK.js";import{Sa as p,be as v,ta as n,x as o,xa as i}from"./chunk-WL5U2YIT.js";import{e as h}from"./chunk-ADEKKGI2.js";var j,b=h(()=>{p();d();P();v();A();C();j=(()=>{let s=class s{constructor(e,t){this.pamAssetServices=e,this.translatorService=t}getPamFolderCheckoutPoliciesAssignments(){return this.pamAssetServices.PamCheckoutPolicies_GetPamFolderCheckoutPoliciesAssignments().pipe(o(e=>e.result===c.Success?e.data:[]))}getFolderContentSummary(e){return this.pamAssetServices.PamFolders_GetPamFolderContentSummary(e)}buildDeleteFolderMessage(e,t=null){let r="";return t=new u(t),t.folderCount+t.credentialCount>0&&(r+="<p>"+this.translatorService.translate("PamFolderNotEmpty"),r+="<br />",r+="- "+this.translatorService.translate("PamXFolders",t.folderCount)+"<br />",r+="- "+this.translatorService.translate("PamXAccounts",t.credentialCount)+"<br />",r+="- "+this.translatorService.translate("PamXActiveCheckouts",t.checkoutActiveCount)+"<br />",r+="- "+this.translatorService.translate("PamXPendingCheckouts",t.checkoutPendingCount)+"<br />",r+="- "+this.translatorService.translate("PamXGrantedCheckouts",t.checkoutGrantedCount)+"<br /></p>"),r+=this.translatorService.translate("AreYouSureYouWantToDelete",e),r}};s.\u0275fac=function(t){return new(t||s)(i(m),i(l))},s.\u0275prov=n({token:s,factory:s.\u0275fac,providedIn:"root"});let a=s;return a})()});export{j as a,b};
