import{a as S,b as z}from"./chunk-6POW7SSJ.js";import{j as O}from"./chunk-ZBM6BFOI.js";import{c as B,d as f,g as b,h as v,i as y}from"./chunk-WFM63CSH.js";import{Ad as M,Ic as p,Kc as u,Lc as r,Od as h,Qb as l,Qc as E,Rd as P,Sc as w,Vc as a,Yc as k,Zc as A,be as g,tc as x,xc as n,ya as _,yb as m,yc as c,zd as H}from"./chunk-WL5U2YIT.js";import{e as C}from"./chunk-ADEKKGI2.js";var N,D,T=C(()=>{g();j();g();N=["*"],D=(()=>{let o=class o{constructor(){this.items=P(I),this.isFused=h(!1),this.multiple=h(!0)}setActiveItem(t){!this.multiple()&&t.isItemHidden?this.items().forEach(e=>e.setItemHidden(e!==t)):t.isItemHidden=!t.isItemHidden}setActiveItemByIndex(t){let e=this.items();t>=0&&t<e.length&&this.setActiveItem(e[t])}};o.\u0275fac=function(e){return new(e||o)},o.\u0275cmp=l({type:o,selectors:[["dvl-accordion"]],contentQueries:function(e,i,s){e&1&&E(s,i.items,I,4),e&2&&w()},hostVars:2,hostBindings:function(e,i){e&2&&a("fused",i.isFused())},inputs:{isFused:[1,"isFused"],multiple:[1,"multiple"]},ngContentSelectors:N,decls:1,vars:0,template:function(e,i){e&1&&(u(),r(0))},styles:["[_nghost-%COMP%]{display:block;margin-bottom:1.5em}.fused[_nghost-%COMP%]     .accordion-item{border:1px solid var(--border-brand-400);border-bottom:1px solid var(--border-200);box-shadow:none}.fused[_nghost-%COMP%]     .accordion-item:first-child{border-radius:8px 8px 0 0}.fused[_nghost-%COMP%]     .accordion-item:last-child{border-radius:0 0 8px 8px}.fused[_nghost-%COMP%]     .accordion-item .accordion-item-header{padding:.57em .86em}.fused[_nghost-%COMP%]     .accordion-item+.accordion-item{margin:0;border-radius:0;border-top:0 none}.fused[_nghost-%COMP%]     .accordion-item+.accordion-item:last-child{border-radius:0 0 8px 8px}"]});let d=o;return d})()});var Q,V,I,j=C(()=>{g();O();z();T();g();Q=[[["",8,"title-action"]],[["",8,"action-buttons"]],"*",[["footer",8,"inner-footer"]],[["footer"]]],V=[".title-action",".action-buttons","*","footer.inner-footer","footer"],I=(()=>{let o=class o{constructor(){this.accordion=_(D,{optional:!0,host:!0}),this.isAccordionItem=!0,this.isItemHidden=!0}toggleItem(){this.accordion?this.accordion.setActiveItem(this):this.isItemHidden=!this.isItemHidden}setItemHidden(t){this.isItemHidden=t}};o.\u0275fac=function(e){return new(e||o)},o.\u0275cmp=l({type:o,selectors:[["dvl-accordion-item"]],hostVars:2,hostBindings:function(e,i){e&2&&a("accordion-item",i.isAccordionItem)},inputs:{isItemHidden:"isItemHidden",title:"title"},ngContentSelectors:V,decls:15,vars:6,consts:[[1,"accordion-item-header","flex","items-center",3,"click"],[1,"header-title-action",3,"click"],[1,"header-title"],[1,"header-actions","ml-auto"],["tabindex","0",1,"di","dvl-icon-arrow-down-medium","toggle-button",3,"keydown.enter"],[1,"accordion-item-content"],[1,"accordion-item-footer"]],template:function(e,i){e&1&&(u(Q),n(0,"div",0),p("click",function(){return i.toggleItem()}),n(1,"div",1),p("click",function(F){return F.stopPropagation()}),r(2),c(),n(3,"div",2)(4,"span"),k(5),H(6,"translate"),c()(),n(7,"div",3),r(8,1),n(9,"i",4),p("keydown.enter",function(){return i.toggleItem()}),c()()(),n(10,"div",5),r(11,2),r(12,3),c(),n(13,"div",6),r(14,4),c()),e&2&&(m(5),A(M(6,4,i.title)),m(4),a("toggle-up",!i.isItemHidden),m(),x("@openClose",i.isItemHidden?"closed":"open"))},dependencies:[S],styles:[`.accordion-item{margin-top:1.4em;display:inline-block;width:100%;background-color:var(--bg-100);border-radius:.714em}.accordion-item:first-child{margin-top:.714em}.accordion-item-header{cursor:pointer;width:100%;padding:1.071em .714em 1.071em 1.428em;gap:var(--spacing-3, 12px)}.accordion-item-header .header-actions{display:flex;gap:5px;align-items:center}.accordion-item-header .header-actions .action-buttons{display:inline-flex;white-space:nowrap}.accordion-item-header .header-actions .action-buttons:hover{background-color:var(--accent-brand-100)}.accordion-item-header .header-actions .action-buttons ::ng-deep .p-button{height:auto;width:auto}.header-title{color:var(--text-300);font-size:1.286em;font-weight:600;line-height:1.2;flex:1 auto}.accordion-item-content{color:var(--card-txt-color);font-size:1em;overflow:hidden;padding:.5em 1em 1em}.accordion-item-content>*:first-child{margin-top:0}.header-title-action{display:flex;align-items:center}.header-title-action:empty{display:none}.accordion-item-footer{border-top:1px solid var(--security-box-border-color);font-size:1em;font-weight:600;line-height:1}.accordion-item-footer:empty{display:none}.inner-footer{margin-top:10px}.toggle-button{transition:background-color .2s;border-radius:50%;font-size:1.4em;padding:.3em}.toggle-button:before{transition:transform ease-in-out .3s;display:inline-block}.toggle-button.toggle-up:before{transform:rotate(-180deg)}.accordion-item-header:hover:not(:has(.p-button:hover)) .toggle-button,.toggle-button:hover{background-color:var(--dropdown-item-hover-background-color)}
`],encapsulation:2,data:{animation:[B("openClose",[v("open",b({height:"*",paddingTop:"*",paddingBottom:"*",margin:"*"})),v("closed",b({height:"0px",paddingTop:0,paddingBottom:0,marginTop:0,marginBottom:0})),y("open => closed",[f(".2s ease-in-out")]),y("closed => open",[f(".3s ease-in-out")])])]}});let d=o;return d})()});export{I as a,j as b,D as c,T as d};
