import{B as d,C as j}from"./chunk-I7GW4F3B.js";import{O as p,Sa as M,be as b,l,na as T,r as m,ta as S,x as u,xa as h}from"./chunk-WL5U2YIT.js";import{e as n}from"./chunk-ADEKKGI2.js";var s,g=n(()=>{s=class{constructor(){this.isValid=!0,this.fileSizeTooBig=!1,this.fileNameTooLong=!1}}});var F,x=n(()=>{T();g();M();b();j();F=(()=>{let e=class e{constructor(i){this.dataSourceSettingsService=i}validateFile(i,a,c,r){if(i instanceof Blob){let t=new s;return this.dataSourceSettingsService.get().pipe(u(f=>{let v=!!r;r??=f.maxFileSizeByte;let z=v?r/1024/1024:f.maxFileSizeMByte;return i.size>r&&(t.isValid=!1,t.fileSizeTooBig=!0,t.maxFileSize=z),c&&a.length>c&&(t.isValid=!1,t.fileNameTooLong=!0,t.maxFileNameLength=c),t}),p(f=>m(t)))}return l}};e.\u0275fac=function(a){return new(a||e)(h(d))},e.\u0275prov=S({token:e,factory:e.\u0275fac,providedIn:"root"});let o=e;return o})()});export{F as a,x as b};
