import{a as k,b as Y}from"./chunk-KREWYSBO.js";import{a as Z,b as X}from"./chunk-6POW7SSJ.js";import{Ma as N,Na as V,Oa as H,q as D,r as O,s as L}from"./chunk-V2ECYACM.js";import{C as x,E as B,b as j,f as F,m as G}from"./chunk-JPHJ3OD7.js";import{a as E,b as Q}from"./chunk-QGVT6DPT.js";import{b as W,c as R}from"./chunk-YBNTOQCK.js";import{K,k as A}from"./chunk-LDWBA6DZ.js";import{Ad as c,Db as w,Hc as m,Jb as v,Qb as M,R as g,Sa as J,Ub as P,W as T,Xc as U,Yc as C,Zc as b,be as I,cd as y,dd as _,ed as S,g as h,ia as f,na as z,tc as n,uc as o,vc as l,yb as a,zd as u}from"./chunk-WL5U2YIT.js";import{e as q}from"./chunk-ADEKKGI2.js";var be,$=q(()=>{I();Q();z();J();K();X();L();B();H();Y();I();R();L();B();H();be=(()=>{let i=class i extends E{constructor(r){super(),this.translatorService=r,this.parametersChange=new w,this.filterSubject=new h,this.parametersChangedSubject=new h,this.userTypeOptions=[{label:this.translatorService.translate("lblUser"),value:"User"},{label:this.translatorService.translate("lblUserGroup"),value:"UserGroup"},{label:this.translatorService.translate("lblApplication"),value:"Application"}]}ngOnInit(){this.subscribeToFilterValue(),this.subscribeToParametersChange()}onFilterChange(r){this.filterSubject.next(r.target.value)}clearUserType(){this.parameters.userType=null,this.onParametersChange()}onParametersChange(){this.parametersChangedSubject.next()}subscribeToParametersChange(){this.parametersChangedSubject.pipe(g(500),f(this.destroyed$)).subscribe(()=>this.parametersChange.emit(this.parameters))}subscribeToFilterValue(){this.filterSubject.pipe(T(),g(500),f(this.destroyed$)).subscribe(r=>{this.parameters.filter=r,this.onParametersChange()})}};i.\u0275fac=function(p){return new(p||i)(v(W))},i.\u0275cmp=M({type:i,selectors:[["dvls-gateway-user-access-parameters"]],inputs:{isScheduling:"isScheduling",parameters:"parameters"},outputs:{parametersChange:"parametersChange"},features:[P],decls:12,vars:21,consts:[[2,"padding-bottom","15px"],[3,"ngClass"],["pInputText","","id","filter",3,"onClear","ngModelChange","input","showClear","fluid","ngModel"],["appendTo","body","styleClass","form-control",3,"ngModelChange","onChange","onClear","options","showHeader","defaultLabel","ngModel","baseZIndex","showClear"]],template:function(p,e){p&1&&(o(0,"div",0)(1,"div",1)(2,"label"),C(3),u(4,"translate"),l(),o(5,"input",2),m("onClear",function(){return e.onParametersChange()}),S("ngModelChange",function(t){return _(e.parameters.filter,t)||(e.parameters.filter=t),t}),m("input",function(t){return e.onFilterChange(t)}),l()(),o(6,"div",1)(7,"label"),C(8),u(9,"translate"),l(),o(10,"p-multiSelect",3),u(11,"translate"),S("ngModelChange",function(t){return _(e.parameters.userType,t)||(e.parameters.userType=t),t}),m("onChange",function(){return e.onParametersChange()})("onClear",function(){return e.clearUserType()}),l()()()),p&2&&(U(e.isScheduling?"form parameters-form flex flex-col gap-4":"form parameters-form flex flex-row gap-4"),a(),n("ngClass",e.isScheduling?"form-group w-full":"form-group flex-1"),a(2),b(c(4,15,"lblFilter")),a(2),n("showClear",!0)("fluid",!0),y("ngModel",e.parameters.filter),a(),n("ngClass",e.isScheduling?"form-group w-full":"form-group flex-1"),a(2),b(c(9,17,"lblUserType")),a(2),n("options",e.userTypeOptions)("showHeader",!1)("defaultLabel",c(11,19,"lblSelect")),y("ngModel",e.parameters.userType),n("baseZIndex",3200)("showClear",!0))},dependencies:[A,O,D,x,j,F,G,V,N,k,Z],styles:["[_nghost-%COMP%]     .clear-icon-parent{position:relative}"]});let d=i;return d})()});export{be as a,$ as b};
