import{a as I,b as T}from"./chunk-K55QONHF.js";import"./chunk-B6MQW3JE.js";import"./chunk-NZJHSGMO.js";import"./chunk-AQH4BMGD.js";import{a as v,b as N}from"./chunk-VPC3Z52T.js";import"./chunk-OXFSVPFG.js";import"./chunk-5TSS7GVU.js";import"./chunk-JZBEKAHY.js";import"./chunk-GPOUKG47.js";import"./chunk-QJ5AQ5Q5.js";import"./chunk-FO6WX7GV.js";import"./chunk-WU6ZG2DN.js";import"./chunk-OMJ3HEST.js";import"./chunk-4Z7Z6YAK.js";import{a as k,b as _}from"./chunk-XQPMDC2I.js";import"./chunk-2DBYTWCP.js";import"./chunk-AX7GEE3B.js";import"./chunk-MY7TBNPQ.js";import"./chunk-PERPLZAX.js";import"./chunk-W3NBOZCE.js";import"./chunk-YQYH6YEK.js";import"./chunk-RGGXLS4X.js";import"./chunk-UPFEUXSY.js";import"./chunk-4EHH4FUQ.js";import"./chunk-JFZLN2FV.js";import"./chunk-A4G3YPXH.js";import"./chunk-ZZGEQSKV.js";import"./chunk-7YSPVYHZ.js";import"./chunk-MFW36WEU.js";import"./chunk-7PFZXDIW.js";import"./chunk-YKFXM3J7.js";import"./chunk-AVRBEEAA.js";import"./chunk-4ERZBM5I.js";import"./chunk-DJ546A6R.js";import"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-6POW7SSJ.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-KB7AZJFC.js";import"./chunk-AJ7ODGYR.js";import{o as f,p as M}from"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import{a as g,b as w}from"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import{B as u,I as S}from"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import{Hc as b,J as d,Jb as a,Qb as p,Sa as D,Ub as c,be as H,ia as t,tc as m,uc as h,vc as l,x as r}from"./chunk-WL5U2YIT.js";import{e as y}from"./chunk-ADEKKGI2.js";var R,E=y(()=>{D();N();w();T();H();S();M();_();R=(()=>{let i=class i extends g{constructor(e,n,o){super(),this.route=e,this.displayModeService=n,this.connectionHandbookNavigationService=o,this.permissions=new v,this.displayModeService.isKioskMode=!0}ngOnInit(){this.route.params.pipe(t(this.destroyed$),d(e=>!!e.id)).subscribe(e=>this.handbookId=e.id),this.route.queryParams.pipe(t(this.destroyed$)).subscribe(e=>this.pageId=e.page||this.handbookId),this.route.data.pipe(t(this.destroyed$),r(e=>e.permissions)).subscribe(e=>this.permissions=e)}onPageChange(e){this.connectionHandbookNavigationService.navigateToDocumentation(this.handbookId,e,!1)}};i.\u0275fac=function(n){return new(n||i)(a(u),a(f),a(k))},i.\u0275cmp=p({type:i,selectors:[["ng-component"]],features:[c],decls:1,vars:5,consts:[[3,"pageChange","handbookId","pageId","canEditHandbook","canDeleteHandbook","allowOpenInNewTab"]],template:function(n,o){n&1&&(h(0,"dvls-doc-handbook-dashboard",0),b("pageChange",function(C){return o.onPageChange(C)}),l()),n&2&&m("handbookId",o.handbookId)("pageId",o.pageId)("canEditHandbook",o.permissions==null?null:o.permissions.canEditHandbook)("canDeleteHandbook",o.permissions==null?null:o.permissions.canDeleteHandbook)("allowOpenInNewTab",!1)},dependencies:[I],encapsulation:2});let s=i;return s})()});E();export{R as ConnectionDocumentationComponent};
