import{G as c,I as u,Sa as j,U as s,W as d,X as o,be as v,ea as p,ga as h,h as l,ia as b,na as m,ta as f}from"./chunk-WL5U2YIT.js";import{e as g}from"./chunk-ADEKKGI2.js";var I,R=g(()=>{m();j();v();I=(()=>{let e=class e{constructor(){this.longOperationRunningSubject=new l({visible:!1,indicatorType:"standard"}),this.longOperationRunning=this.longOperationRunningSubject.asObservable()}showIndicator(t="standard"){this.longOperationRunningSubject.next({visible:!0,indicatorType:t})}hideIndicator(t="standard"){this.longOperationRunningSubject.next({visible:!1,indicatorType:t})}indicate(t,n=1e3){return i=>i.pipe(p(1),this.prepare(r=>t.next(r),n),o(()=>t.next(!1)))}observe(t="standard",n=1e3){return i=>i.pipe(p(1),this.prepare(r=>this.longOperationRunningSubject.next({visible:r,indicatorType:t}),n),o(()=>this.hideIndicator(t)))}prepare(t,n=1e3){return i=>(u(c(n).pipe(s(!0),b(i)),i.pipe(s(!1))).pipe(h(!1),d()).subscribe(r=>t(r)),i)}};e.\u0275fac=function(n){return new(n||e)},e.\u0275prov=f({token:e,factory:e.\u0275fac,providedIn:"root"});let a=e;return a})()});export{I as a,R as b};
