import{a as p,b as v}from"./chunk-R5HXMUGB.js";import{a as s,b as l}from"./chunk-QGVT6DPT.js";import{C as m,I as d}from"./chunk-HTXYTVN4.js";import"./chunk-LDWBA6DZ.js";import{Qb as n,Ub as r,be as f,od as a,wc as i}from"./chunk-WL5U2YIT.js";import{e as u}from"./chunk-ADEKKGI2.js";var F,g=u(()=>{l();v();d();f();F=(()=>{let e=class e extends s{constructor(){super()}};e.\u0275fac=function(o){return new(o||e)},e.\u0275cmp=n({type:e,selectors:[["ng-component"]],features:[a([p]),r],decls:1,vars:0,template:function(o,h){o&1&&i(0,"router-outlet")},dependencies:[m],encapsulation:2});let t=e;return t})()});g();export{F as PamOnboardingDashboardPageComponent};
