import{a as h,b as g}from"./chunk-DJ546A6R.js";import{D as l,E as b}from"./chunk-I7GW4F3B.js";import{c as p,d as A}from"./chunk-RWCAFOHA.js";import{Gk as f,Hk as C}from"./chunk-BPZQKZKD.js";import{b as m,c as j}from"./chunk-YBNTOQCK.js";import{Sa as S,be as d,ka as c,ta as n,x as o,xa as r}from"./chunk-WL5U2YIT.js";import{e as v}from"./chunk-ADEKKGI2.js";var E,I=v(()=>{S();g();d();C();b();j();A();E=(()=>{let t=class t extends h{constructor(s,i,e,u){super(e,u,i),this.assetServices=s}getAllRoleSummaries(s=!1){let i=this.assetServices.GetRolesBasic().pipe(c(e=>this.handleGetApiResult(e)),o(e=>this.returnWhenSuccessful(e,()=>e.data)));return this.getCache(s,i)}};t.\u0275fac=function(i){return new(i||t)(r(f),r(l),r(m),r(p))},t.\u0275prov=n({token:t,factory:t.\u0275fac,providedIn:"root"});let a=t;return a})()});export{E as a,I as b};
