import{a as d,b as u}from"./chunk-6POW7SSJ.js";import{Ad as c,Qb as r,Ya as o,Yc as p,_c as s,be as l,zd as a}from"./chunk-WL5U2YIT.js";import{e as f}from"./chunk-ADEKKGI2.js";var h,y=f(()=>{u();l();h=(()=>{let t=class t{constructor(n){this.key=n}};t.\u0275fac=function(e){return new(e||t)(o("key"))},t.\u0275cmp=r({type:t,selectors:[["sd-text"]],decls:2,vars:3,template:function(e,m){e&1&&(p(0),a(1,"translate")),e&2&&s("",c(1,1,m.key),`
`)},dependencies:[d],encapsulation:2});let i=t;return i})()});export{h as a,y as b};
