import{D as s,E as o}from"./chunk-I7GW4F3B.js";import{Jb as i,Tb as c,be as a}from"./chunk-WL5U2YIT.js";import{e as u}from"./chunk-ADEKKGI2.js";var h,f=u(()=>{a();o();h=(()=>{let r=class r{constructor(e){this.currentUserService=e}transform(e){switch(this.currentUserService.currentUserSnapshot.culture){case"fr":return e+"?l=fr";case"de":return e+"?l=de";default:return e}}};r.\u0275fac=function(n){return new(n||r)(i(s,16))},r.\u0275pipe=c({name:"languageQueryParam",type:r,pure:!0});let t=r;return t})()});export{h as a,f as b};
