import{be as a,d as s,g as n,na as l,ta as c}from"./chunk-WL5U2YIT.js";import{e as i}from"./chunk-ADEKKGI2.js";var f,m=i(()=>{l();a();f=(()=>{let e=class e{constructor(){this.selectTreeElement=new s,this.selectTreeElementSource=new n,this.selectTreeElement=this.selectTreeElementSource.asObservable()}select(t){return t.key=t.key||"global_tree_selector",this.selectTreeElementSource.next(t),this}};e.\u0275fac=function(o){return new(o||e)},e.\u0275prov=c({token:e,factory:e.\u0275fac,providedIn:"root"});let r=e;return r})()});export{f as a,m as b};
