import{e as l}from"./chunk-ADEKKGI2.js";var a,m=l(()=>{a=(function(u){return u[u.Default=0]="Default",u[u.Manual=1]="Manual",u[u.ApplicationClose=2]="ApplicationClose",u})(a||{});(function(u){function f(){return"LogConnectionClosedMode"}u.getClass=f;function r(p){let t="";return typeof u.getClass=="function"&&(t=u.getClass()),t+"_"+u[p]}u.getEnumKey=r})(a||(a={}))});export{a,m as b};
