import{be as a,ta as s}from"./chunk-WL5U2YIT.js";import{e as i}from"./chunk-ADEKKGI2.js";var d,e=i(()=>{a();d=(()=>{let t=class t{generatePreview(n){let r=n.commands?.join(", ")||"ALL",c=n.tags?.length>0?n.tags.join(": ")+": ":"";return`${n.hostList}=${n.runasSpec} ${c}${r}`}};t.\u0275fac=function(r){return new(r||t)},t.\u0275prov=s({token:t,factory:t.\u0275fac,providedIn:"root"});let o=t;return o})()});export{d as a,e as b};
