import{D as c,E as f}from"./chunk-I7GW4F3B.js";import{a as h}from"./chunk-YBNTOQCK.js";import{Jb as m,Tb as n,be as l}from"./chunk-WL5U2YIT.js";import{e as u,h as p}from"./chunk-ADEKKGI2.js";var a,F,d=u(()=>{a=p(h());l();f();F=(()=>{let r=class r{constructor(e){this.currentUserService=e}get displayDateFormat(){return this.currentUserService.webSettingsSnapshot&&(this.currentUserService.displayDateFormat||"").trim().length>0?this.currentUserService.displayDateFormat:"M/D/YYYY"}get displayTimeFormat(){return this.currentUserService.webSettingsSnapshot&&(this.currentUserService.displayTimeFormat||"").trim().length>0?this.currentUserService.displayTimeFormat:"HH:mm"}get displayDateTimeFormat(){return this.currentUserService.webSettingsSnapshot&&(this.currentUserService.displayDateTimeFormat||"").trim().length>0?this.currentUserService.displayDateTimeFormat:"M/D/YYYY HH:mm"}transform(e,t,o){if(!e)return"";let i;return o?i=a.default.unix(Number.parseInt(e,10)).local():i=a.default.utc(e).local(),i.isValid()?this.formatDate(t,i):""}formatDate(e,t){switch(e){case"date":return t.format(this.displayDateFormat);case"time":return t.format(this.displayTimeFormat);case"datetime":return t.format(this.displayDateTimeFormat)}return""}};r.\u0275fac=function(t){return new(t||r)(m(c,16))},r.\u0275pipe=n({name:"dateFormat",type:r,pure:!0});let s=r;return s})()});export{F as a,d as b};
