import{a as I,b as B}from"./chunk-6POW7SSJ.js";import{tb as w,zb as z}from"./chunk-V2ECYACM.js";import{f as H,g as M,h}from"./chunk-ZBM6BFOI.js";import{Ad as c,Dc as C,Ea as m,Fa as d,Hc as T,Jc as g,Kc as x,Lc as y,Qb as u,Tc as D,be as j,mc as v,oc as _,sb as f,tc as p,uc as l,vc as r,wc as s,yb as o,zd as a}from"./chunk-WL5U2YIT.js";import{e as V}from"./chunk-ADEKKGI2.js";function L(e,n){e&1&&y(0)}function O(e,n){if(e&1&&(s(0,"span",2),a(1,"translate")),e&2){let K=g();p("innerHTML",c(1,1,K.translationKey),f)}}var E,R,F=V(()=>{z();B();h();j();h();E=["*"];R=(()=>{let n=class n{};n.\u0275fac=function(t){return new(t||n)},n.\u0275cmp=u({type:n,selectors:[["dvls-inline-help"]],inputs:{translationKey:"translationKey"},ngContentSelectors:E,decls:8,vars:4,consts:[["op",""],[2,"padding","5px"],[3,"innerHTML"],[1,"help-button",3,"click","pTooltip"],[1,"di","dvl-icon-info"]],template:function(t,b){if(t&1){let i=C();x(),l(0,"dvl-popover",null,0)(2,"div",1),v(3,L,1,0)(4,O,2,3,"span",2),r()(),l(5,"span",3),a(6,"translate"),T("click",function(k){m(i);let S=D(1);return d(S.toggle(k))}),s(7,"i",4),r()}if(t&2){let i;o(3),_((i=b.translationKey)===null?3:4),o(2),p("pTooltip",c(6,2,"lblHelp"))}},dependencies:[w,M,H,I],styles:["[_nghost-%COMP%]   .help-button[_ngcontent-%COMP%]{font-size:20px;margin-left:5px;color:var(--icon-color);text-decoration:none;cursor:pointer}"]});let e=n;return e})()});export{R as a,F as b};
