import{f as r,h as f}from"./chunk-ZBM6BFOI.js";import{Hc as p,Jb as n,Sb as l,Za as s,be as m}from"./chunk-WL5U2YIT.js";import{e as h}from"./chunk-ADEKKGI2.js";var v,a=h(()=>{m();f();v=(()=>{let i=class i{constructor(o,t){this.tooltip=o,this.elementRef=t,this.initialTooltipPosition=this.tooltip._tooltipOptions.tooltipPosition}setTooltipState(){let t=this.elementRef.nativeElement.getBoundingClientRect();(this.tooltip._tooltipOptions.tooltipPosition===void 0||this.tooltip._tooltipOptions.tooltipPosition==="right"||this.tooltip._tooltipOptions.tooltipPosition!==this.initialTooltipPosition)&&window.innerWidth-t.right<200?this.tooltip._tooltipOptions.tooltipPosition="left":this.tooltip._tooltipOptions.tooltipPosition=this.initialTooltipPosition??"right"}};i.\u0275fac=function(t){return new(t||i)(n(r),n(s))},i.\u0275dir=l({type:i,selectors:[["","pTooltip","","dvlsTooltipPositionAdjustment",""],["","dvlTooltip","","dvlsTooltipPositionAdjustment",""]],hostBindings:function(t,c){t&1&&p("mouseenter",function(d){return c.setTooltipState(d)})}});let e=i;return e})()});export{v as a,a as b};
