import{a as B,b as L}from"./chunk-AYHVMOCO.js";import{a as T,b as j,c as V,d as D}from"./chunk-A6MCRJS5.js";import{a as w,b as N}from"./chunk-6POW7SSJ.js";import{cb as b,zb as I}from"./chunk-V2ECYACM.js";import{Bd as y,Db as x,Dc as f,Ea as C,Fa as u,Hc as v,Jb as h,Jc as r,Qb as S,Yc as k,Zc as A,be as g,mc as p,oc as d,tb as K,tc as _,uc as s,vc as c,wc as E,yb as l,zd as m}from"./chunk-WL5U2YIT.js";import{e as P}from"./chunk-ADEKKGI2.js";function O(e,o){if(e&1&&(E(0,"img",1),m(1,"translate")),e&2){let t=r();_("src",t.illustration,K)("alt",t.altKey?y(1,2,t.altKey,t.translateArgs):"")}}function M(e,o){if(e&1&&(s(0,"span",4),k(1),m(2,"translate"),c()),e&2){let t=r();l(),A(y(2,1,t.descriptionKey,t.translateArgs))}}function $(e,o){if(e&1){let t=f();s(0,"dvl-button",10),m(1,"translate"),v("onClick",function(a){C(t);let i=r(3);return u(i.onPrimaryClick(a))}),c()}if(e&2){let t=r(3);_("label",y(1,1,t.primaryActionKey,t.translateArgs))}}function z(e,o){if(e&1){let t=f();s(0,"dvl-button",11),m(1,"translate"),v("onClick",function(a){C(t);let i=r(3);return u(i.onSecondaryClick(a))}),c()}if(e&2){let t=r(3);_("label",y(1,1,t.secondaryActionKey,t.translateArgs))}}function U(e,o){if(e&1&&(s(0,"div",6),p(1,$,2,4,"dvl-button",8),p(2,z,2,4,"dvl-button",9),c()),e&2){let t=r(2);l(),d(t.primaryActionKey?1:-1),l(),d(t.secondaryActionKey?2:-1)}}function q(e,o){if(e&1){let t=f();s(0,"dvl-button",12),m(1,"translate"),v("onClick",function(a){C(t);let i=r(2);return u(i.onLinkClick(a))}),c()}if(e&2){let t=r(2);_("label",y(1,1,t.linkActionKey,t.translateArgs))}}function G(e,o){if(e&1&&(s(0,"div",5),p(1,U,3,2,"div",6),p(2,q,2,4,"dvl-button",7),c()),e&2){let t=r();l(),d(t.primaryActionKey||t.secondaryActionKey?1:-1),l(),d(t.linkActionKey?2:-1)}}var F,nt,H=P(()=>{g();N();I();j();L();g();D();F=new Set,nt=(()=>{let o=class o{get translateArgs(){return this.productName?[this.productName]:[]}constructor(n){this.telemetryFactory=n,this.altKey="",this.primaryAction=new x,this.secondaryAction=new x,this.linkAction=new x}ngOnInit(){this.telemetryKey&&!F.has(this.telemetryKey)&&(F.add(this.telemetryKey),this.track("Opened"))}onPrimaryClick(n){this.track("PrimaryClicked"),this.primaryAction.emit(n)}onSecondaryClick(n){this.track("SecondaryClicked"),this.secondaryAction.emit(n)}onLinkClick(n){this.track("LinkClicked"),this.linkAction.emit(n)}track(n){if(!this.telemetryKey)return;let i=B.EmptyState[`${this.telemetryKey}EmptyState${n}`];i&&this.telemetryFactory.createFeatureEvent(T.EmptyState,i)}};o.\u0275fac=function(a){return new(a||o)(h(V))},o.\u0275cmp=S({type:o,selectors:[["dvls-empty-state"]],hostAttrs:[1,"flex","flex-1","items-center","justify-center","min-h-[60vh]","w-full"],inputs:{illustration:"illustration",altKey:"altKey",titleKey:"titleKey",descriptionKey:"descriptionKey",primaryActionKey:"primaryActionKey",secondaryActionKey:"secondaryActionKey",linkActionKey:"linkActionKey",productName:"productName",telemetryKey:"telemetryKey"},outputs:{primaryAction:"primaryAction",secondaryAction:"secondaryAction",linkAction:"linkAction"},decls:8,vars:7,consts:[[1,"flex","flex-col","items-center","gap-4","max-w-[560px]","mx-auto","p-4","text-center"],[1,"max-h-[180px]","w-auto",3,"src","alt"],[1,"flex","flex-col","items-center","gap-2","w-full"],[1,"font-semibold","text-lg","leading-[1.2]","text-400"],[1,"font-normal","text-sm","leading-[1.3]","break-words","text-200"],[1,"flex","flex-col","items-center","gap-6"],[1,"flex","gap-3","items-center","justify-center"],["variant","link","styleClass","empty-state-link-icon","icon","dvl-icon dvl-icon-link-external","iconPos","right",3,"label"],["variant","primary",3,"label"],["variant","secondary",3,"label"],["variant","primary",3,"onClick","label"],["variant","secondary",3,"onClick","label"],["variant","link","styleClass","empty-state-link-icon","icon","dvl-icon dvl-icon-link-external","iconPos","right",3,"onClick","label"]],template:function(a,i){a&1&&(s(0,"div",0),p(1,O,2,5,"img",1),s(2,"div",2)(3,"span",3),k(4),m(5,"translate"),c(),p(6,M,3,4,"span",4),c(),p(7,G,3,2,"div",5),c()),a&2&&(l(),d(i.illustration?1:-1),l(3),A(y(5,4,i.titleKey,i.translateArgs)),l(2),d(i.descriptionKey?6:-1),l(),d(i.primaryActionKey||i.secondaryActionKey||i.linkActionKey?7:-1))},dependencies:[b,w],encapsulation:2});let e=o;return e})()});export{nt as a,H as b};
