import{a,b,c,d}from"./chunk-UNSTD625.js";import"./chunk-RP5THUPB.js";import"./chunk-CPNLMJTS.js";import"./chunk-DBYP5577.js";import"./chunk-LOP76GWT.js";import"./chunk-VT6VEUJB.js";import"./chunk-4QXDGE5P.js";import"./chunk-4DX65HLL.js";import"./chunk-Q2CF2JQV.js";import"./chunk-DUQZGOF7.js";import"./chunk-4FYFA554.js";import"./chunk-Y3SKC4HP.js";import"./chunk-LCZQRCKX.js";import"./chunk-MFW36WEU.js";import"./chunk-7PFZXDIW.js";import"./chunk-YKFXM3J7.js";import"./chunk-AVRBEEAA.js";import"./chunk-4ERZBM5I.js";import"./chunk-DJ546A6R.js";import"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-AJ7ODGYR.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import"./chunk-WL5U2YIT.js";import"./chunk-ADEKKGI2.js";d();export{a as PAM_ADMIN_SECTION_ROOT_PERMISSIONS,b as PAM_ADMIN_SECTION_ROUTES,c as PAM_ROUTES};
