import{c as m,d as b}from"./chunk-RWCAFOHA.js";import{Gk as h,Hk as j}from"./chunk-BPZQKZKD.js";import{a as n,b as d}from"./chunk-6B6CBPYV.js";import{b as f,c as S}from"./chunk-YBNTOQCK.js";import{J as o,Sa as u,be as v,ta as c,x as a,xa as i}from"./chunk-WL5U2YIT.js";import{e as p}from"./chunk-ADEKKGI2.js";var x,g=p(()=>{u();d();v();j();b();S();x=(()=>{let t=class t{constructor(r,e,l){this.assetsService=r,this.errorService=e,this.translatorService=l}getPassphraseDictionaries(){return this.assetsService.GetPassphraseDictionaries(!1).pipe(o(r=>!!r),a(r=>{if(r.result!==n.Success){this.errorService.pushErrorMessage(r.errorMessage);return}return r.data.forEach(e=>{e.name=this.translatorService.translate(e.name)}),r.data}))}};t.PassphraseDictionaryIdEnglish="5ec83fd8-3e08-443d-bd95-b4f5edf123c2",t.\u0275fac=function(e){return new(e||t)(i(h),i(m),i(f))},t.\u0275prov=c({token:t,factory:t.\u0275fac,providedIn:"root"});let s=t;return s})()});export{x as a,g as b};
