import{D as x,E as u}from"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import{Ic as p,Qb as l,Yc as d,be as g,mc as m,oc as s,xc as i,ya as a,yc as o,zc as r}from"./chunk-WL5U2YIT.js";import{e as h}from"./chunk-ADEKKGI2.js";function v(e,t){e&1&&(i(0,"div",2)(1,"div",3)(2,"a",4),r(3,"i",5),o()()(),r(4,"div",6))}var O,b=h(()=>{g();u();g();O=(()=>{let t=class t{constructor(){this.currentUserService=a(x)}get isLogged(){return this.currentUserService.isLogged()}goBack(){window.history.back()}};t.\u0275fac=function(n){return new(n||t)},t.\u0275cmp=l({type:t,selectors:[["sd-error-404"]],decls:8,vars:1,consts:[[1,"Box"],[3,"click"],["id","header"],["id","mm-devo"],["href","https://devolutions.net"],[1,"di","dvl-icon-devolutions"],[1,"dvls-homeLogo","dvl-icon"]],template:function(n,c){n&1&&(m(0,v,5,0),i(1,"div",0)(2,"h2")(3,"b"),d(4,"404"),o(),d(5," PAGE NOT FOUND"),o(),i(6,"button",1),p("click",function(){return c.goBack()}),d(7,"Back"),o()()),n&2&&s(c.isLogged?-1:0)},styles:['.Box[_ngcontent-%COMP%]{box-sizing:border-box;margin:0 auto;max-width:600px;overflow:hidden;padding:10px;text-align:center}.Box[_ngcontent-%COMP%]   h2[_ngcontent-%COMP%]{color:#0068c3;font-family:var(--font-open-sans);font-size:34px;font-weight:400;letter-spacing:-.06em;line-height:76px;margin:0;padding:0}.dvls-homeLogo[_ngcontent-%COMP%]{box-sizing:border-box;margin:0 auto;max-width:600px;overflow:hidden;padding:25px;position:relative;width:100%}#header[_ngcontent-%COMP%]{color:#fff;left:0;margin:0 auto;min-width:700px;top:0;width:100%;background:#0068c3;box-shadow:0 2px 10px -2px #66666673}i.dvl-icon-devolutions[_ngcontent-%COMP%]{font-size:40px;opacity:.95}#mm-devo[_ngcontent-%COMP%]{height:50px;margin:0 auto;max-width:1024px}#mm-devo[_ngcontent-%COMP%]   a[_ngcontent-%COMP%]{box-sizing:border-box;color:#fff;display:block;height:50px;line-height:1;padding:4px 0 0 16px;text-align:left}button[_ngcontent-%COMP%]{background:#0068c3;border:1px solid #0068c3;-ms-border-radius:3px;border-radius:3px;color:#fff;text-decoration:none;font-family:var(--font-open-sans);font-size:1.15em;padding:.2em 1.2em;cursor:pointer;position:relative;vertical-align:middle}button[_ngcontent-%COMP%]:after{box-shadow:0 8px 5px -8px #dcdcdc;content:"";display:inline-block;height:100%;left:0;overflow:hidden;position:absolute;top:1px;width:100%;z-index:0}']});let e=t;return e})()});b();export{O as Error404Component};
