import{g as h,h as T}from"./chunk-QNHB4F4C.js";import{O as d,P as N}from"./chunk-A4G3YPXH.js";import{a as f,b as A}from"./chunk-SM7EQ7ST.js";import{c as m,d as g}from"./chunk-RWCAFOHA.js";import{Gk as l,Hk as M}from"./chunk-BPZQKZKD.js";import{b as p,c as S}from"./chunk-YBNTOQCK.js";import{Sa as j,be as C,ka as s,ta as c,x as a,xa as o}from"./chunk-WL5U2YIT.js";import{e as v}from"./chunk-ADEKKGI2.js";var F,b=v(()=>{A();j();N();C();g();S();T();M();F=(()=>{let e=class e extends f{constructor(r,t,i,u){super(t,r),this.treeNodeConnectionManager=i,this.assetServices=u}get(r,t=null){return this.assetServices.GetPartialConnectionTree(r,t,!1).pipe(s(i=>this.handleGetApiResult(i)),a(i=>this.returnWhenSuccessful(i,()=>this.treeNodeConnectionManager.mapConnectionsToTreeNodes(new d(i.data),r,t))))}};e.\u0275fac=function(t){return new(t||e)(o(m),o(p),o(h),o(l))},e.\u0275prov=c({token:e,factory:e.\u0275fac,providedIn:"root"});let n=e;return n})()});export{F as a,b};
