import{c as d,d as T}from"./chunk-XXAXP2UE.js";import"./chunk-TMFXITIU.js";import"./chunk-QYFLYRVD.js";import"./chunk-7HE3DR3X.js";import"./chunk-2ZWT2NP5.js";import"./chunk-UUHGBBUI.js";import"./chunk-AZF77PS6.js";import"./chunk-NZJHSGMO.js";import"./chunk-AQH4BMGD.js";import"./chunk-4QXDGE5P.js";import{c as f,d as S}from"./chunk-DHD27AAT.js";import"./chunk-AV3L7ROS.js";import"./chunk-KLLD5HHC.js";import"./chunk-KREWYSBO.js";import"./chunk-6N2FFKSD.js";import"./chunk-DJLFA677.js";import"./chunk-NEKDTWKR.js";import"./chunk-5TSS7GVU.js";import"./chunk-OMJ3HEST.js";import"./chunk-YL26OJYM.js";import"./chunk-VM2L5ERO.js";import"./chunk-ODPQPCQE.js";import"./chunk-WBO6MOWK.js";import"./chunk-AX7GEE3B.js";import"./chunk-NAQVZCUC.js";import"./chunk-PERPLZAX.js";import"./chunk-W3NBOZCE.js";import"./chunk-OREOSMUG.js";import"./chunk-IKZ22DPI.js";import"./chunk-Z3FSQ5UV.js";import"./chunk-4YXISON2.js";import"./chunk-YVVVIZWY.js";import"./chunk-RGGXLS4X.js";import"./chunk-UPFEUXSY.js";import"./chunk-DUQZGOF7.js";import"./chunk-QNHB4F4C.js";import"./chunk-E6ILSVIA.js";import"./chunk-PRC4K7KM.js";import"./chunk-4FYFA554.js";import"./chunk-Y3SKC4HP.js";import"./chunk-FAHXDSMM.js";import"./chunk-THQOQSZV.js";import"./chunk-4BLCQKUP.js";import"./chunk-J5QU44UY.js";import"./chunk-KZ3OQNYD.js";import"./chunk-A4G3YPXH.js";import"./chunk-ZZGEQSKV.js";import"./chunk-7YSPVYHZ.js";import"./chunk-MFW36WEU.js";import"./chunk-7PFZXDIW.js";import"./chunk-YKFXM3J7.js";import"./chunk-AVRBEEAA.js";import"./chunk-4ERZBM5I.js";import"./chunk-DJ546A6R.js";import"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-6POW7SSJ.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-ZIBMIZ5S.js";import"./chunk-IWXVOQCF.js";import"./chunk-6YAACY5H.js";import"./chunk-KB7AZJFC.js";import"./chunk-J5DDNCDX.js";import"./chunk-AJ7ODGYR.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import{a,b as g}from"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import{C as p,I as h,r as s,t as C}from"./chunk-HTXYTVN4.js";import{b as l,c as D}from"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import{Jb as r,Qb as n,Ub as c,be as v,wc as m}from"./chunk-WL5U2YIT.js";import{e as u}from"./chunk-ADEKKGI2.js";var A,x=u(()=>{g();h();S();T();v();C();D();A=(()=>{let e=class e extends a{constructor(i,t){super(),this.titleService=i,this.translatorService=t}};e.\u0275fac=function(t){return new(t||e)(r(s),r(l))},e.\u0275cmp=n({type:e,selectors:[["ng-component"]],features:[c],decls:3,vars:0,template:function(t,y){t&1&&m(0,"router-outlet")(1,"dps-connection-comment")(2,"dvls-ticket-selector")},dependencies:[p,f,d],encapsulation:2});let o=e;return o})()});x();export{A as WebClientComponent};
