import{Qb as i,be as c,xc as n,yc as d,zc as l}from"./chunk-WL5U2YIT.js";import{e as a}from"./chunk-ADEKKGI2.js";var v,m=a(()=>{c();v=(()=>{let e=class e{};e.\u0275fac=function(o){return new(o||e)},e.\u0275cmp=i({type:e,selectors:[["dvl-redirecting"]],decls:3,vars:0,consts:[["id","dvl-loading",1,"loader"],[1,"loader-10x"],[1,"di","dvl-icon-logo-dvls"]],template:function(o,s){o&1&&(n(0,"div",0),l(1,"div",1)(2,"i",2),d())},encapsulation:2});let t=e;return t})()});m();export{v as RedirectingComponent};
