import{Gk as o,Hk as u}from"./chunk-BPZQKZKD.js";import{be as d,ta as i,xa as n}from"./chunk-WL5U2YIT.js";import{e as c}from"./chunk-ADEKKGI2.js";var m,f=c(()=>{d();u();m=(()=>{let t=class t{constructor(e){this.assetServices=e}addLog(e,s=null,a=null){return this.assetServices.AddLogEntry(e,s,a)}updateLogEnd(e){return this.assetServices.UpdateLogEntryEnd(e)}};t.\u0275fac=function(s){return new(s||t)(n(o))},t.\u0275prov=i({token:t,factory:t.\u0275fac,providedIn:"root"});let r=t;return r})()});export{m as a,f as b};
