import{be as c,g as i,na as l,ta as o}from"./chunk-WL5U2YIT.js";import{e as s}from"./chunk-ADEKKGI2.js";var b,d,r=s(()=>{b=[{name:"lblGeneral",section:"general"},{name:"lblApplicationAccess",section:"application-access"},{name:"lblDvlsUser",section:"devolutions-server-user"},{name:"lblSystemMessage",section:"system-message"},{name:"lblSecureMessage",section:"secure-message"},{name:"lblPasswordManagement",section:"password-management"},{name:"lblForbiddenPassword",section:"forbidden-password"},{name:"lblTypeAvailability",section:"type-availability"},{name:"lblLogs",section:"logs"},{name:"lblUsers",section:"users"},{name:"lblNotification",section:"notification"},{name:"lblRecordingServer",section:"recording-server"},{name:"lblVersionManagement",section:"version-management"},{name:"lblRDMAndCompanionTools",section:"rdm"},{name:"lblTicketingService",section:"ticketing-service"},{name:"lblVaultManagement",section:"vault-management"},{name:"lblPAMVaultManagement",section:"pam-vault-management"},{name:"lblApplicationSpecific",section:"application-specific"},{name:"lblAdvanced",section:"advanced"}],d=[{labelKey:"lblFunctionKeysCommon",icon:"di dvl-icon-settings",sections:["logs","system-message","notification","secure-message","ticketing-service","type-availability","advanced"]},{labelKey:"lblApplication",icon:"di dvl-icon-advanced-settings",sections:["general","application-access","application-specific","recording-server","rdm","version-management"]},{labelKey:"lblVaultManagement",icon:"di dvl-icon-vault",sections:["vault-management","pam-vault-management"]},{labelKey:"lblPasswordManagement",icon:"di dvl-icon-password-management",sections:["password-management","forbidden-password"]},{labelKey:"lblUserManagement",icon:"di dvl-icon-user",sections:["users","devolutions-server-user"]}]});var u,m=s(()=>{l();c();u=(()=>{let e=class e{constructor(){this.sectionSelectionSubject=new i,this.sectionSelection$=this.sectionSelectionSubject.asObservable(),this.searchCatalog=[]}selectSection(n,t){this.sectionSelectionSubject.next({section:n,fragment:t})}registerSearchCatalog(n){this.searchCatalog=n}getSearchCatalog(){return this.searchCatalog}};e.\u0275fac=function(t){return new(t||e)},e.\u0275prov=o({token:e,factory:e.\u0275fac,providedIn:"root"});let a=e;return a})()});export{b as a,d as b,r as c,u as d,m as e};
