import{a as E,b as G}from"./chunk-DBYP5577.js";import{b as P,c as F}from"./chunk-G3KW4TER.js";import{a as R,b as B}from"./chunk-MIKVP5QF.js";import"./chunk-KZ3OQNYD.js";import"./chunk-YKFXM3J7.js";import"./chunk-AVRBEEAA.js";import"./chunk-4ERZBM5I.js";import"./chunk-DJ546A6R.js";import{D as g,E as x,c as A,e as D,l as U,m as y,n as O,o as _}from"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-AJ7ODGYR.js";import{m as T,n as k}from"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import{D as m,I}from"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import{J as u,Sa as M,be as d,ha as v,ka as C,na as w,r as l,ta as s,x as S,xa as n,ya as h}from"./chunk-WL5U2YIT.js";import{e as p}from"./chunk-ADEKKGI2.js";var b,L=p(()=>{M();d();I();F();x();D();y();b=(()=>{let e=class e{constructor(r,i,a,o,c){this.router=r,this.urlService=i,this.currentUserService=a,this.oauthService=o,this.baseUrlService=c}canActivate(r,i){return this.currentUserService.currentUserChanged.pipe(u(a=>!!a),v(()=>this.urlService.getDefaultUrl().pipe(C(a=>{let o=decodeURIComponent(this.oauthService.state);if(this.oauthService.state="",o){let c=new URL(this.baseUrlService.getCompletePathForRoute(o)),N=this.baseUrlService.getParamsAsObject(c.searchParams);o=o.split("?")[0],this.router.navigate([o],{queryParams:N})}else this.router.navigateByUrl(a)}),S(()=>!0))))}};e.\u0275fac=function(i){return new(i||e)(n(m),n(P),n(g),n(A),n(U))},e.\u0275prov=s({token:e,factory:e.\u0275fac,providedIn:"root"});let t=e;return t})()});var f,j=p(()=>{d();I();w();_();k();d();f=(()=>{let e=class e{constructor(){this.router=h(m),this.storageService=h(O),this.serverInformationService=h(T)}canActivate(r,i){return this.checkLicenseManagement(i)}canActivateChild(r,i){return this.checkLicenseManagement(i)}checkLicenseManagement(r){return this.serverInformationService.privateServerInformation?.limitAccessToLicensePage&&!["/administration/licenses","/logout"].some(c=>r.url.startsWith(c))?(this.router.navigate(["/administration/licenses"]),l(!1)):l(!0)}};e.\u0275fac=function(i){return new(i||e)},e.\u0275prov=s({token:e,factory:e.\u0275fac,providedIn:"root"});let t=e;return t})()});var st,W=p(()=>{L();G();B();j();st=[{path:"",loadComponent:()=>import("./chunk-FQLGZZKA.js").then(t=>t.ApplicationComponent),canActivate:[f],canActivateChild:[f],children:[{path:"",loadComponent:()=>import("./chunk-2L552L5N.js").then(t=>t.LandingPageComponent),canActivate:[b],pathMatch:"full"},{path:"connections",loadChildren:()=>import("./chunk-5Y4DBCFU.js").then(t=>t.CONNECTIONS_ROUTES),providers:[R]},{path:"dashboard",redirectTo:""},{path:"administration",loadChildren:()=>import("./chunk-HWXFZ7IA.js").then(t=>t.ADMINISTRATIONS_ROUTES)},{path:"pam",loadChildren:()=>import("./chunk-EJ72GU7Z.js").then(t=>t.PAM_ROUTES)},{path:"privileged-session-monitoring",loadChildren:()=>import("./chunk-GGJ6D5H5.js").then(t=>t.PRIVILEGED_SESSIONS_MONITORING)},{path:"reports",loadChildren:()=>import("./chunk-G6LCOXAZ.js").then(t=>t.REPORTS_ROUTES)},{path:"api-documentation",loadComponent:()=>import("./chunk-MMGJUCJQ.js").then(t=>t.ApiDocumentationComponent)},{path:"tools",loadChildren:()=>import("./chunk-WNFP735T.js").then(t=>t.TOOLS_ROUTES)},{path:"ui",loadChildren:()=>import("./chunk-GWSADJPG.js").then(t=>t.UI_ROUTES)},{path:"system-dashboard",redirectTo:"admin-dashboard",pathMatch:"full"},{path:"admin-dashboard",loadChildren:()=>import("./chunk-PDQ3VO26.js").then(t=>t.SYSDASHBOARD_ROUTES)},{path:"web-client",loadChildren:()=>import("./chunk-CID73SPC.js").then(t=>t.WEB_CLIENT_ROUTES)},{path:"ai-chat/:connectionId",loadComponent:()=>import("./chunk-IBPREZC5.js").then(t=>t.AiChatSessionComponent)},{path:"notification-preferences",loadComponent:()=>import("./chunk-HYA7YTR4.js").then(t=>t.NotificationPreferencesDashboardComponent),canDeactivate:[E]}]}]});W();export{st as APPLICATION_ROUTES};
