import{gd as e,hd as a}from"./chunk-BPZQKZKD.js";import{e as r}from"./chunk-ADEKKGI2.js";function u(t){switch(t){case e.OpenAI:return{supportsApiKey:!0,supportsEndpoint:!0};case e.Gemini:case e.Claude:return{supportsApiKey:!0,supportsEndpoint:!1};case e.Mistral:return{supportsApiKey:!0,supportsEndpoint:!0};case e.Ollama:return{supportsApiKey:!1,supportsEndpoint:!0,endpointPlaceholder:"http://localhost:11434"};case e.AzureAIInference:return{supportsApiKey:!0,supportsEndpoint:!0};default:return s}}function p(t){switch(t){case e.OpenAI:return"OpenAI";case e.AzureOpenAI:return"Azure OpenAI";case e.AzureAIInference:return"Azure AI Inference";case e.Ollama:return"Ollama";case e.Gemini:return"Google Gemini";case e.Claude:return"Claude (Anthropic)";case e.Mistral:return"Mistral";case e.HuggingFace:return"HuggingFace";case e.ONNX:return"ONNX";case e.Copilot:return"GitHub Copilot";case e.Devolutions:return"Devolutions";case e.Other:return"Other";default:return""}}var i,s,n=r(()=>{a();i={[e.OpenAI]:["gpt-5.5","gpt-5.4","gpt-5.3-codex","gpt-5-mini","gpt-5-nano","gpt-4.1"],[e.Gemini]:["gemini-2.5-pro","gemini-2.5-flash","gemini-2.5-flash-lite"],[e.Claude]:["claude-opus-4-6","claude-sonnet-4-6","claude-opus-4-5","claude-sonnet-4-5","claude-opus-4-1","claude-sonnet-4","claude-haiku-4-5"],[e.Ollama]:["llama3.3","llama3.2","qwen2.5","gemma2","mistral","phi4"],[e.Mistral]:["mistral-large-latest","mistral-medium-latest","mistral-small-latest","mistral-tiny-latest","ministral-8b-latest","ministral-3b-latest","ministral-14b-latest","devstral-medium-latest","devstral-small-latest","magistral-medium-latest","magistral-small-latest","open-mistral-nemo","open-mistral-7b"],[e.AzureAIInference]:["Cohere-embed-v3-english","Cohere-embed-v3-multilingual","gpt-4o","gpt-4o-mini","Meta-Llama-3.1-405B-Instruct","Meta-Llama-3.1-8B-Instruct","text-embedding-3-large","text-embedding-3-small"]},s={supportsApiKey:!1,supportsEndpoint:!1}});export{i as a,u as b,p as c,n as d};
