import{i as u,j as E}from"./chunk-Q2CF2JQV.js";import"./chunk-LCZQRCKX.js";import"./chunk-MFW36WEU.js";import"./chunk-7PFZXDIW.js";import"./chunk-YKFXM3J7.js";import"./chunk-AVRBEEAA.js";import"./chunk-4ERZBM5I.js";import"./chunk-DJ546A6R.js";import{n as f,o as C}from"./chunk-I7GW4F3B.js";import"./chunk-MOK7XOAA.js";import"./chunk-U46PHU2W.js";import{a as b,b as S}from"./chunk-6POW7SSJ.js";import"./chunk-V2ECYACM.js";import"./chunk-JPHJ3OD7.js";import"./chunk-ZBM6BFOI.js";import"./chunk-AGRQYW7D.js";import"./chunk-WFM63CSH.js";import"./chunk-SM7EQ7ST.js";import"./chunk-RWCAFOHA.js";import"./chunk-BPZQKZKD.js";import"./chunk-6B6CBPYV.js";import"./chunk-QGVT6DPT.js";import"./chunk-5E3JCGAH.js";import"./chunk-HTXYTVN4.js";import"./chunk-YBNTOQCK.js";import"./chunk-LDWBA6DZ.js";import{Ad as p,Ec as v,Jb as a,Qb as g,Yc as d,_c as c,be as _,tb as m,xc as i,yb as o,yc as n,zc as x,zd as l}from"./chunk-WL5U2YIT.js";import{e as h}from"./chunk-ADEKKGI2.js";var z,P=h(()=>{S();_();E();C();z=(()=>{let e=class e{constructor(s,t){this.authService=s,this.storage=t}ngOnInit(){this.authService.clearLoginInformationAfterExternalLoginSuccess(),this.storage.removeApplicationStorage("oauth")}};e.\u0275fac=function(t){return new(t||e)(a(u),a(f))},e.\u0275cmp=g({type:e,selectors:[["dvls-login-success"]],decls:10,vars:7,consts:[[1,"box"],[1,"box__logo"],["alt","Devolutions Server",1,"dvls-home-logo",3,"src"],[1,"box__title"],[1,"box__message"]],template:function(t,M){t&1&&(i(0,"div")(1,"div",0)(2,"div",1),x(3,"img",2),n(),i(4,"div",3),d(5),l(6,"translate"),n(),i(7,"div",4),d(8),l(9,"translate"),n()()()),t&2&&(o(3),v("src","assets/images/devolutions-password-server-logo.svg",m),o(2),c(" ",p(6,3,"lblSuccess")," "),o(3),c(" ",p(9,5,"YouCanNowCloseThisPage")," "))},dependencies:[b],styles:[".box[_ngcontent-%COMP%]{color:#424242;text-align:center;width:460px;box-shadow:10px 10px 115px 40px #00336624;border-radius:4px;padding:31px 44px 12px;z-index:1;background-color:#fff;margin-top:10vh;position:fixed;left:50%;transform:translate(-50%)}.box[_ngcontent-%COMP%]   .box__logo[_ngcontent-%COMP%]   .dvls-home-logo[_ngcontent-%COMP%]{box-sizing:border-box;margin:0 auto;max-width:300px;overflow:hidden;padding:25px;position:relative;width:100%}.box[_ngcontent-%COMP%]   .box__title[_ngcontent-%COMP%]{font-size:1.4rem;color:#0068c3;font-weight:700}.box[_ngcontent-%COMP%]   .box__message[_ngcontent-%COMP%]{margin:25px;color:#406900;background-color:#f8fbf4;padding:12px;border-radius:4px;border-left:#78b41b 2px solid}"]});let r=e;return r})()});P();export{z as LoginSuccessComponent};
