import{a as S,t as M}from"./chunk-HTXYTVN4.js";import{b as g,c as F}from"./chunk-YBNTOQCK.js";import{Ja as v,Tb as y,be as s,d as h,na as E,ta as d,xa as m,ya as b}from"./chunk-WL5U2YIT.js";import{a,e as l}from"./chunk-ADEKKGI2.js";var i,p=l(()=>{i=()=>["Mac","iPhone","iPad","iPhone"].some(r=>navigator.platform.includes(r))?"apple":"pc"});function f(r){return i()!=="apple"&&r==="meta"&&(r="control"),r}var k,P=l(()=>{s();E();p();s();M();k=(()=>{let t=class t{constructor(e,o){this.eventManager=e,this.document=o}addShortcut({element:e,keys:o}){let c=`keydown.${o}`.split(".").map(n=>f(n)).join(".");return new h(n=>{let w=u=>{u.preventDefault(),document.querySelectorAll(".p-dialog.p-component, .p-drawer-active, .p-drawer").length||n.next(u)},x=this.eventManager.addEventListener(e??this.document.documentElement,c,w);return()=>x()})}};t.\u0275fac=function(o){return new(o||t)(m(S),m(v))},t.\u0275prov=d({token:t,factory:t.\u0275fac,providedIn:"root"});let r=t;return r})()});var j,O,A,R,C=l(()=>{s();p();P();F();s();j={shift:"\u21E7",backspace:"\u232B",tab:"\u21E5",space:"\u2423",left:"\u2190",right:"\u2192",up:"\u2191",down:"\u2193",enter:"\u23CE"},O={meta:"\u2318",altleft:"\u2325",control:"\u2303",escape:"\u238B"},A={control:"lblCtrl",altleft:"lblAlt",escape:"Esc"},R=(()=>{let t=class t{constructor(){this.translatorService=b(g),this.symbols=this.getPlatformSymbols(i())}transform(e,o=" + "){return e?e.split(">").map(c=>c.split(".").map(n=>f(n.toLowerCase())).map(n=>this.translatorService.translate(this.symbols[n])||n).join(o)):""}getPlatformSymbols(e){return e==="apple"?a(a({},j),O):a(a({},j),A)}};t.\u0275fac=function(o){return new(o||t)},t.\u0275pipe=y({name:"hotkeysShortcut",type:t,pure:!0});let r=t;return r})()});export{k as a,P as b,R as c,C as d};
