import{Tb as t,be as h}from"./chunk-WL5U2YIT.js";import{e as f}from"./chunk-ADEKKGI2.js";function A(r,o,c="id"){if(o!==null){let p=new Map(o.map(a=>[a[c],a]));r=r.filter(a=>p.has(a[c])),p.forEach(a=>{r.some(e=>e[c]===a[c])||r.push(a)})}return r}function n(r){return r==null?[]:Array.isArray(r)?r:[r]}var u=f(()=>{});var w,s=f(()=>{u();h();w=(()=>{let o=class o{transform(p){return n(p)}};o.\u0275fac=function(a){return new(a||o)},o.\u0275pipe=t({name:"toArray",type:o,pure:!0});let r=o;return r})()});export{A as a,n as b,u as c,w as d,s as e};
