import{Tb as s,be as o}from"./chunk-WL5U2YIT.js";import{e as n}from"./chunk-ADEKKGI2.js";var c,p=n(()=>{o();c=(()=>{let r=class r{transform(t){return t=t.replace(/(?!^)[A-Z]/g,i=>`-${i.toLowerCase()}`),t.replace(/[\s\.]/g,"-")}};r.\u0275fac=function(i){return new(i||r)},r.\u0275pipe=s({name:"sanitizeCSSClass",type:r,pure:!0});let e=r;return e})()});export{c as a,p as b};
