import{a as E,b as _}from"./chunk-DJLFA677.js";import{a as T,b as x}from"./chunk-NEKDTWKR.js";import{$a as I,A as p,B as h,C as m,D as u,E as S,F as g,_a as f}from"./chunk-THQOQSZV.js";import{O as i,Sa as b,be as w,na as A,r as v,ta as P,x as s,xa as d}from"./chunk-WL5U2YIT.js";import{e as l}from"./chunk-ADEKKGI2.js";var N,j=l(()=>{A();b();g();_();h();u();w();I();x();N=(()=>{let t=class t extends E{constructor(e,r){super(),this.pamAssetServices=e,this.pamErrorService=r,this.propertyIdsBasedOnType=new Map([[p.Password,"05799f12-c6d9-4266-94f7-42b50e3d4a6b"],[p.Username,"c24049c5-9ec4-4f26-832c-86f283067c73"],[p.UniqueIdentifier,"54b6d680-0b89-4ce6-a512-bc98e0008fd7"]])}create(e){return new S(e)}get(e){return this.pamAssetServices.PamProviderTemplate_Get(e).pipe(i(r=>this.pamErrorService.handleError(r)))}createNewProperty(e,r,n,c){let a=new m;return a.id=e,a.name=r,a.type=n,a.isMandatory=c,a}getAll(){return this.pamAssetServices.PamProviderTemplate_GetProviderTemplates().pipe(i(e=>this.pamErrorService.handleError(e)))}getAllSummaries(e=!1,r=null,n=!1){return this.pamAssetServices.PamProviderTemplate_GetProviderTemplateSummaries(e,r,n).pipe(i(c=>this.pamErrorService.handleError(c)))}delete(e){return this.pamAssetServices.PamProviderTemplate_DeleteProviderTemplate(e).pipe(s(()=>!0),i(r=>this.pamErrorService.handleError(r)))}save(e){return e.id?this.update(e).pipe(s(r=>r?.id)):this.createTemplate(e).pipe(s(r=>r?.id))}export(e){return this.pamAssetServices.PamProviderTemplate_Export(e).pipe(s(r=>new Blob([r],{type:"application/json"})),i(r=>(this.pamErrorService.handleError(r),v(null))))}analyze(e){return this.pamAssetServices.PamProviderTemplate_Analyze(e).pipe(i(r=>this.pamErrorService.handleError(r)))}import(e){return this.pamAssetServices.PamProviderTemplate_Import(e).pipe(i(r=>this.pamErrorService.handleError(r)))}testScript(e){return this.pamAssetServices.PamProviderTemplate_TestCommandScript(e).pipe(i(r=>this.pamErrorService.handleError(r)))}createTemplate(e){return this.pamAssetServices.PamProviderTemplate_PostPamProviderTemplate(e)}update(e){return this.pamAssetServices.PamProviderTemplate_PutProviderTemplates(e).pipe(i(r=>this.pamErrorService.handleError(r)))}};t.\u0275fac=function(r){return new(r||t)(d(f),d(T))},t.\u0275prov=P({token:t,factory:t.\u0275fac,providedIn:"root"});let o=t;return o})()});var y,U=l(()=>{u();h();y=class extends m{constructor(t=null){super(t)}isStringType(){return[p.String,p.Description,p.Username,p.UniqueIdentifier].includes(this.type)}}});export{N as a,j as b,y as c,U as d};
