import{a as _,b as B}from"./chunk-MOK7XOAA.js";import{j as P,t as b,u as w,v as T}from"./chunk-ZBM6BFOI.js";import{c as C,d as v,g as t,i as u}from"./chunk-WFM63CSH.js";import{K as M,s as h}from"./chunk-LDWBA6DZ.js";import{Ad as g,J as r,Jb as S,Qb as I,Sa as x,be as L,mc as d,oc as p,tc as l,uc as c,vc as s,wc as m,x as a,yb as O,zd as f}from"./chunk-WL5U2YIT.js";import{e as $}from"./chunk-ADEKKGI2.js";function D(e,n){e&1&&(c(0,"div",0),m(1,"p-progressSpinner"),s()),e&2&&l("@fadeInOut",void 0)}function E(e,n){e&1&&(c(0,"div",1),m(1,"div",2)(2,"i",3),s()),e&2&&l("@fadeInOut",void 0)}var H,G=$(()=>{x();P();T();M();L();B();T();H=(()=>{let n=class n{constructor(i){this.longOperationIndicatorService=i}get showGlobal$(){return this.longOperationIndicatorService.longOperationRunning.pipe(r(i=>i.indicatorType==="global"),a(i=>i.visible))}get showStandard$(){return this.longOperationIndicatorService.longOperationRunning.pipe(r(i=>i.indicatorType==="standard"),a(i=>i.visible))}};n.\u0275fac=function(o){return new(o||n)(S(_))},n.\u0275cmp=I({type:n,selectors:[["dvl-long-operation-indicator"]],decls:4,vars:6,consts:[[1,"standard-loader"],["id","dvl-loading",1,"loader"],[1,"loader-10x"],[1,"di","dvl-icon-logo-dvls"]],template:function(o,y){o&1&&(d(0,D,2,1,"div",0),f(1,"async"),d(2,E,3,1,"div",1),f(3,"async")),o&2&&(p(g(1,2,y.showStandard$)?0:-1),O(2),p(g(3,4,y.showGlobal$)?2:-1))},dependencies:[w,b,h],encapsulation:2,data:{animation:[C("fadeInOut",[u(":enter",[t({opacity:"0"}),v(".5s ease-out",t({opacity:"1"}))]),u(":leave",[t({opacity:"1"}),v(".5s ease-out",t({opacity:"0"}))])])]}});let e=n;return e})()});export{H as a,G as b};
